@@ -25,7 +25,7 @@
 #include <glib/gi18n.h>
 
 #include "cairo-dock-keyfile-utilities.h"
-#include "cairo-dock-gui-main.h"
+#include "cairo-dock-gui-advanced.h"
 #include "cairo-dock-gui-simple.h"
 #include "cairo-dock-gui-manager.h"
 #include "cairo-dock-desklet-manager.h"
@@ -33,20 +33,20 @@
 #include "cairo-dock-module-manager.h"
 #include "cairo-dock-module-factory.h"
 #include "cairo-dock-notifications.h"
+#include "cairo-dock-gui-simple.h"
 #include "cairo-dock-gui-backend.h"
 
 extern gchar *g_cCairoDockDataDir;
 extern CairoDock *g_pMainDock;
 
 static CairoDockMainGuiBackend *s_pMainGuiBackend = NULL;
-static CairoDockItemsGuiBackend *s_pItemsGuiBackend = NULL;
 static int s_iCurrentMode = 0;
 
 void cairo_dock_load_user_gui_backend (int iMode)  // 0 = simple
 {
 	if (iMode == 1)
 	{
-		cairo_dock_register_main_gui_backend ();
+		cairo_dock_register_advanced_gui_backend ();
 	}
 	else
 	{
@@ -55,7 +55,12 @@ void cairo_dock_load_user_gui_backend (int iMode)  // 0 = simple
 	s_iCurrentMode = iMode;
 }
 
-static void on_click_switch_mode (GtkButton *button, gpointer data)
+int cairo_dock_gui_backend_get_mode ()
+{
+	return s_iCurrentMode;
+}
+
+static void on_click_switch_mode (G_GNUC_UNUSED GtkButton *button, G_GNUC_UNUSED gpointer data)
 {
 	cairo_dock_close_gui ();
 	
@@ -83,110 +88,30 @@ GtkWidget *cairo_dock_make_switch_gui_button (void)
 	return pSwitchButton;
 }
 
-gboolean cairo_dock_theme_manager_is_integrated (void)
-{
-	return (s_pMainGuiBackend && s_pMainGuiBackend->bCanManageThemes);
-}
 
 
-
-static guint s_iSidUpdateDesklet = 0;
-static CairoDesklet *s_DeskletToUpdate = NULL;
-static gboolean _update_desklet_params (gpointer data)
-{
-	if (s_DeskletToUpdate != NULL)
-	{
-		if (s_pMainGuiBackend && s_pMainGuiBackend->update_desklet_params)
-			s_pMainGuiBackend->update_desklet_params (s_DeskletToUpdate);
-		s_DeskletToUpdate = NULL;
-	}
-	s_iSidUpdateDesklet = 0;
-	return FALSE;
-}
-static gboolean _on_desklet_destroyed (gpointer pUserData, CairoDesklet *pDesklet)
-{
-	if (s_DeskletToUpdate == pDesklet)  // the desklet we were about to update has been destroyed, cancel.
-	{
-		if (s_iSidUpdateDesklet != 0)
-		{
-			g_source_remove (s_iSidUpdateDesklet);
-			s_iSidUpdateDesklet = 0;
-		}
-		s_DeskletToUpdate = NULL;
-	}
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-}
-void cairo_dock_gui_trigger_update_desklet_params (CairoDesklet *pDesklet)
+void cairo_dock_gui_update_desklet_params (CairoDesklet *pDesklet)
 {
 	g_return_if_fail (pDesklet != NULL);
-	if (s_DeskletToUpdate != pDesklet)  // new desklet to update, let's forget the previous one.
-	{
-		if (s_iSidUpdateDesklet != 0)
-		{
-			g_source_remove (s_iSidUpdateDesklet);
-			s_iSidUpdateDesklet = 0;
-		}
-		s_DeskletToUpdate = NULL;
-	}
-	if (s_iSidUpdateDesklet == 0)  // no update scheduled yet, let's schedule it.
-	{
-		s_iSidUpdateDesklet = g_idle_add_full (G_PRIORITY_LOW,
-			(GSourceFunc) _update_desklet_params,
-			NULL,
-			NULL);
-		s_DeskletToUpdate = pDesklet;
-		cairo_dock_register_notification_on_object (pDesklet,
-			NOTIFICATION_DESTROY,
-			(CairoDockNotificationFunc) _on_desklet_destroyed,
-			CAIRO_DOCK_RUN_AFTER, NULL);
-	}
+	if (s_pMainGuiBackend && s_pMainGuiBackend->update_desklet_params)
+		s_pMainGuiBackend->update_desklet_params (pDesklet);
 }
 
 
-static guint s_iSidUpdateVisiDesklet = 0;
-static gboolean _update_desklet_visibility_params (gpointer data)
-{
-	if (s_DeskletToUpdate != NULL)
-	{
-		if (s_pMainGuiBackend && s_pMainGuiBackend->update_desklet_visibility_params)
-			s_pMainGuiBackend->update_desklet_visibility_params (s_DeskletToUpdate);
-		s_DeskletToUpdate = NULL;
-	}
-	s_iSidUpdateVisiDesklet = 0;
-	return FALSE;
-}
-void cairo_dock_gui_trigger_update_desklet_visibility (CairoDesklet *pDesklet)
+void cairo_dock_gui_update_desklet_visibility (CairoDesklet *pDesklet)
 {
 	g_return_if_fail (pDesklet != NULL);
-	if (s_DeskletToUpdate != pDesklet)  // new desklet to update, let's forget the previous one.
-	{
-		if (s_iSidUpdateVisiDesklet != 0)
-		{
-			g_source_remove (s_iSidUpdateVisiDesklet);
-			s_iSidUpdateVisiDesklet = 0;
-		}
-		s_DeskletToUpdate = NULL;
-	}
-	if (s_iSidUpdateVisiDesklet == 0)  // no update scheduled yet, let's schedule it.
-	{
-		s_iSidUpdateVisiDesklet = g_idle_add_full (G_PRIORITY_LOW,
-			(GSourceFunc) _update_desklet_visibility_params,
-			NULL,
-			NULL);
-		s_DeskletToUpdate = pDesklet;
-		cairo_dock_register_notification_on_object (pDesklet,
-			NOTIFICATION_DESTROY,
-			(CairoDockNotificationFunc) _on_desklet_destroyed,
-			CAIRO_DOCK_RUN_AFTER, NULL);
-	}
+	if (s_pMainGuiBackend && s_pMainGuiBackend->update_desklet_visibility_params)
+		s_pMainGuiBackend->update_desklet_visibility_params (pDesklet);
 }
 
 
 static guint s_iSidReloadItems = 0;
-static gboolean _reload_items (gpointer data)
+static gboolean _reload_items (G_GNUC_UNUSED gpointer data)
 {
-	if (s_pItemsGuiBackend && s_pItemsGuiBackend->reload_items)
-		s_pItemsGuiBackend->reload_items ();
+	if (s_pMainGuiBackend && s_pMainGuiBackend->reload_items)
+		s_pMainGuiBackend->reload_items ();
+	
 	s_iSidReloadItems = 0;
 	return FALSE;
 }
@@ -229,7 +154,7 @@ void cairo_dock_gui_trigger_update_module_state (const gchar *cModuleName)
 
 
 static guint s_iSidReloadModulesList = 0;
-static gboolean _update_modules_list (gpointer data)
+static gboolean _update_modules_list (G_GNUC_UNUSED gpointer data)
 {
 	if (s_pMainGuiBackend && s_pMainGuiBackend->update_module_state)
 		s_pMainGuiBackend->update_modules_list ();
@@ -250,7 +175,7 @@ void cairo_dock_gui_trigger_update_modules_list (void)
 
 
 static guint s_iSidReloadShortkeys = 0;
-static gboolean _update_shortkeys (gpointer data)
+static gboolean _update_shortkeys (G_GNUC_UNUSED gpointer data)
 {
 	if (s_pMainGuiBackend && s_pMainGuiBackend->update_shortkeys)
 		s_pMainGuiBackend->update_shortkeys ();
@@ -284,18 +209,9 @@ void cairo_dock_register_config_gui_backend (CairoDockMainGuiBackend *pBackend)
 	s_pMainGuiBackend = pBackend;
 }
 
-void cairo_dock_register_items_gui_backend (CairoDockItemsGuiBackend *pBackend)
+static void _display_window (GtkWidget *pWindow)
 {
-	g_free (s_pItemsGuiBackend);
-	s_pItemsGuiBackend = pBackend;
-}
-
-
-GtkWidget *cairo_dock_show_main_gui (void)
-{
-	GtkWidget *pWindow = NULL;
-	if (s_pMainGuiBackend && s_pMainGuiBackend->show_main_gui)
-		pWindow = s_pMainGuiBackend->show_main_gui ();
+	// place it on the current desktop, and avoid overlapping the main dock
 	if (pWindow && g_pMainDock != NULL)  // evitons d'empieter sur le main dock.
 	{
 		if (g_pMainDock->container.bIsHorizontal)
@@ -314,19 +230,29 @@ GtkWidget *cairo_dock_show_main_gui (void)
 		}
 	}
 	
+	// take focus
+	gtk_window_present (GTK_WINDOW (pWindow));
+}
+
+GtkWidget * cairo_dock_show_main_gui (void)
+{
+	// create the window
+	GtkWidget *pWindow = NULL;
+	if (s_pMainGuiBackend && s_pMainGuiBackend->show_main_gui)
+		pWindow = s_pMainGuiBackend->show_main_gui ();
+	
+	_display_window (pWindow);
+	
 	return pWindow;
 }
 
-/*void cairo_dock_show_module_instance_gui (CairoDockModuleInstance *pModuleInstance, int iShowPage)
-{
-	if (s_pMainGuiBackend && s_pMainGuiBackend->show_module_instance_gui)
-		s_pMainGuiBackend->show_module_instance_gui (pModuleInstance, iShowPage);
-}*/
-
 void cairo_dock_show_module_gui (const gchar *cModuleName)
 {
+	GtkWidget *pWindow = NULL;
 	if (s_pMainGuiBackend && s_pMainGuiBackend->show_module_gui)
-		s_pMainGuiBackend->show_module_gui (cModuleName);
+		pWindow = s_pMainGuiBackend->show_module_gui (cModuleName);
+		
+	_display_window (pWindow);
 }
 
 void cairo_dock_close_gui (void)
@@ -337,7 +263,29 @@ void cairo_dock_close_gui (void)
 
 void cairo_dock_show_items_gui (Icon *pIcon, CairoContainer *pContainer, CairoDockModuleInstance *pModuleInstance, int iShowPage)
 {
-	//g_print ("%s (%x)\n", __func__, pIcon);
-	if (s_pItemsGuiBackend && s_pItemsGuiBackend->show_gui)
-		s_pItemsGuiBackend->show_gui (pIcon, pContainer, pModuleInstance, iShowPage);
+	GtkWidget *pWindow = NULL;
+	if (s_pMainGuiBackend && s_pMainGuiBackend->show_gui)
+		pWindow = s_pMainGuiBackend->show_gui (pIcon, pContainer, pModuleInstance, iShowPage);
+		
+	_display_window (pWindow);
+}
+
+void cairo_dock_reload_gui (void)
+{
+	if (s_pMainGuiBackend && s_pMainGuiBackend->reload)
+		s_pMainGuiBackend->reload ();
+}
+
+void cairo_dock_show_themes (void)
+{
+	GtkWidget *pWindow = NULL;
+	if (s_pMainGuiBackend && s_pMainGuiBackend->show_themes)
+		pWindow = s_pMainGuiBackend->show_themes ();
+		
+	_display_window (pWindow);
+}
+
+gboolean cairo_dock_can_manage_themes (void)
+{
+	return (s_pMainGuiBackend && s_pMainGuiBackend->show_themes);
 }
