@@ -1,3 +1,4 @@
+
 /*
 * This file is a part of the Cairo-Dock project
 *
@@ -16,7 +17,6 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
-
 /*****************************************************************************************************
 **
 ** Program:
@@ -49,20 +49,13 @@
 /// http://www.siteduzero.com/tutoriel-3-307309-le-systeme-de-micro-paiement-flattr.html
 /// http://www.cyber-junk.de/wp-content/cache/supercache/cyber-junk.de/entwickelt/flattr-button-im-eigenbau-mittels-curl-und-mini-api/index.html
 
-#include <math.h>
-#include <string.h>
-#include <stdlib.h>
-#include <signal.h> 
-#include <unistd.h>
+#include <unistd.h> // sleep, execl
+#include <signal.h>
 
 #define __USE_POSIX
 #include <time.h>
 
-#include <glib.h>
 #include <glib/gstdio.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-
 
 #include "config.h"
 #include "cairo-dock-icon-facility.h"  // cairo_dock_get_first_icon
@@ -77,15 +70,14 @@
 #include "cairo-dock-file-manager.h"
 #include "cairo-dock-log.h"
 #include "cairo-dock-keybinder.h"
-#include "cairo-dock-draw-opengl.h"
+#include "cairo-dock-opengl.h"
 #include "cairo-dock-launcher-manager.h"  // cairo_dock_launch_command
+#include "cairo-dock-core.h"
 
 #include "cairo-dock-gui-manager.h"
-#include "cairo-dock-gui-items.h"
 #include "cairo-dock-gui-backend.h"
 #include "cairo-dock-user-interaction.h"
 #include "help/cairo-dock-help.h"
-#include "cairo-dock-core.h"
 
 //#define CAIRO_DOCK_THEME_SERVER "http://themes.glx-dock.org"
 #define CAIRO_DOCK_THEME_SERVER "http://download.tuxfamily.org/glxdock/themes"
@@ -94,10 +86,6 @@
 #define CAIRO_DOCK_CURRENT_THEME_NAME "current_theme"
 // Nom du repertoire des themes extras.
 #define CAIRO_DOCK_EXTRAS_DIR "extras"
-// Nom du repertoire des themes de dock.
-#define CAIRO_DOCK_THEMES_DIR "themes"
-// Nom du repertoire des themes de dock sur le serveur
-#define CAIRO_DOCK_DISTANT_THEMES_DIR "themes3.0"
 
 extern gchar *g_cCairoDockDataDir;
 extern gchar *g_cCurrentThemePath;
@@ -112,6 +100,7 @@ extern gboolean g_bUseOpenGL;
 extern gboolean g_bEasterEggs;
 
 extern CairoDockModuleInstance *g_pCurrentModule;
+extern GtkWidget *cairo_dock_build_simple_gui_window (void);
 
 gboolean g_bForceCairo = FALSE;
 gboolean g_bLocked;
@@ -152,12 +141,12 @@ static gboolean _cairo_dock_successful_launch (gpointer data)
 	}
 	return FALSE;
 }
-static gboolean _cairo_dock_first_launch_setup (gpointer data)
+static gboolean _cairo_dock_first_launch_setup (G_GNUC_UNUSED gpointer data)
 {
 	cairo_dock_launch_command (CAIRO_DOCK_SHARE_DATA_DIR"/scripts/initial-setup.sh");
 	return FALSE;
 }
-static void _cairo_dock_quit (int signal)
+static void _cairo_dock_quit (G_GNUC_UNUSED int signal)
 {
 	gtk_main_quit ();
 }
@@ -166,6 +155,8 @@ static void _cairo_dock_intercept_signal (int signal)
 	cd_warning ("Cairo-Dock has crashed (sig %d).\nIt will be restarted now.\nFeel free to report this bug on glx-dock.org to help improving the dock!", signal);
 	g_print ("info on the system :\n");
 	int r = system ("uname -a");
+	if (r < 0)
+		cd_warning ("Not able to launch this command: uname");
 	
 	// if a module is responsible, expose it to public shame.
 	if (g_pCurrentModule != NULL)
@@ -203,7 +194,7 @@ static void _cairo_dock_set_signal_interception (void)
 	signal (SIGTERM, _cairo_dock_quit);  // Term // kill -15 (system)
 }
 
-static gboolean on_delete_maintenance_gui (GtkWidget *pWidget, GdkEvent *event, GMainLoop *pBlockingLoop)
+static gboolean on_delete_maintenance_gui (G_GNUC_UNUSED GtkWidget *pWidget, GMainLoop *pBlockingLoop)
 {
 	cd_debug ("%s ()", __func__);
 	if (pBlockingLoop != NULL && g_main_loop_is_running (pBlockingLoop))
@@ -213,7 +204,7 @@ static gboolean on_delete_maintenance_gui (GtkWidget *pWidget, GdkEvent *event,
 	return FALSE;  // TRUE <=> ne pas detruire la fenetre.
 }
 
-static void PrintMuteFunc(const gchar *string) {}
+static void PrintMuteFunc (G_GNUC_UNUSED const gchar *string) {}
 
 static void _cairo_dock_get_global_config (const gchar *cCairoDockDataDir)
 {
@@ -261,15 +252,10 @@ static void _cairo_dock_get_global_config (const gchar *cCairoDockDataDir)
 }
 
 
-static void _on_shortkey (const gchar *cShortkey, gpointer data)
-{
-	g_print ("pouet\n");
-}
 int main (int argc, char** argv)
 {
 	//\___________________ build the command line used to respawn, and check if we have been launched from another life.
 	s_pLaunchCommand = g_string_new (argv[0]);
-	gchar *cDisableApplet = NULL;
 	int i;
 	for (i = 1; i < argc; i ++)
 	{
@@ -314,7 +300,7 @@ int main (int argc, char** argv)
 	textdomain (CAIRO_DOCK_GETTEXT_PACKAGE);
 	
 	//\___________________ get app's options.
-	gboolean bSafeMode = FALSE, bMaintenance = FALSE, bNoSticky = FALSE, bNormalHint = FALSE, bCappuccino = FALSE, bPrintVersion = FALSE, bTesting = FALSE, bForceIndirectRendering = FALSE, bForceOpenGL = FALSE, bToggleIndirectRendering = FALSE, bKeepAbove = FALSE, bForceColors = FALSE, bAskBackend = FALSE;
+	gboolean bSafeMode = FALSE, bMaintenance = FALSE, bNoSticky = FALSE, bCappuccino = FALSE, bPrintVersion = FALSE, bTesting = FALSE, bForceOpenGL = FALSE, bToggleIndirectRendering = FALSE, bKeepAbove = FALSE, bForceColors = FALSE, bAskBackend = FALSE, bMetacityWorkaround = FALSE;
 	gchar *cEnvironment = NULL, *cUserDefinedDataDir = NULL, *cVerbosity = 0, *cUserDefinedModuleDir = NULL, *cExcludeModule = NULL, *cThemeServerAdress = NULL;
 	int iDelay = 0;
 	GOptionEntry pOptionsTable[] =
@@ -353,10 +339,13 @@ int main (int argc, char** argv)
 		{"safe-mode", 'f', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
 			&bSafeMode,
 			_("Don't load any plug-ins."), NULL},
+		{"metacity-workaround", 'W', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&bMetacityWorkaround,
+			_("Work around some bugs in Metacity Window-Manager (invisible dialogs or sub-docks)"), NULL},
 		{"log", 'l', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING,
 			&cVerbosity,
 			_("Log verbosity (debug,message,warning,critical,error); default is warning."), NULL},
-		{"colors", 'A', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+		{"colors", 'F', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
 			&bForceColors,
 			_("Force to display some output messages with colors."), NULL},
 		{"version", 'v', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
@@ -405,7 +394,7 @@ int main (int argc, char** argv)
 	}
 	
 	if (g_bLocked)
-		cd_warning ("Cairo-Dock will be locked.\n");
+		cd_warning ("Cairo-Dock will be locked.");
 	
 	if (cVerbosity != NULL)
 	{
@@ -483,6 +472,9 @@ int main (int argc, char** argv)
 	if (bNoSticky)
 		cairo_dock_set_containers_non_sticky ();
 	
+	if (bMetacityWorkaround)
+		cairo_dock_disable_containers_opacity ();
+	
 	if (iDesktopEnv != CAIRO_DOCK_UNKNOWN_ENV)
 		cairo_dock_fm_force_desktop_env (iDesktopEnv);
 	
@@ -496,7 +488,7 @@ int main (int argc, char** argv)
 	cairo_dock_set_paths (cRootDataDirPath, cExtraDirPath, cThemesDirPath, cCurrentThemeDirPath, (gchar*)CAIRO_DOCK_SHARE_THEMES_DIR, (gchar*)CAIRO_DOCK_DISTANT_THEMES_DIR, cThemeServerAdress ? cThemeServerAdress : g_strdup (CAIRO_DOCK_THEME_SERVER));
 	
 	//\___________________ Check that OpenGL is safely usable, if not ask the user what to do.
-	if (g_bUseOpenGL && ! bForceOpenGL && ! bToggleIndirectRendering && ! cairo_dock_opengl_is_safe ())  // opengl disponible sans l'avoir force mais pas safe => on demande confirmation.
+	if (bAskBackend || (g_bUseOpenGL && ! bForceOpenGL && ! bToggleIndirectRendering && ! cairo_dock_opengl_is_safe ()))  // opengl disponible sans l'avoir force mais pas safe => on demande confirmation.
 	{
 		if (s_cDefaulBackend == NULL)  // pas de backend par defaut defini.
 		{
@@ -590,7 +582,6 @@ int main (int argc, char** argv)
 	
 	//\___________________ define GUI backend.
 	cairo_dock_load_user_gui_backend (s_iGuiMode);
-	cairo_dock_register_default_items_gui_backend ();
 	
 	//\___________________ register to the useful notifications.
 	cairo_dock_register_notification_on_object (&myContainersMgr,
@@ -680,20 +671,24 @@ int main (int argc, char** argv)
 	{
 		if (cExcludeModule != NULL)
 		{
-			cd_warning ("The module '%s' has been deactivated because it may have caused some problems.\nYou can reactivate it, if it happens again thanks to report it at http://glx-dock.org\n", cExcludeModule);
+			cd_warning (_("The module '%s' has been deactivated because it may have caused some problems.\nYou can reactivate it, if it happens again thanks to report it at http://glx-dock.org"), cExcludeModule);
 			gchar *cCommand = g_strdup_printf ("sed -i \"/modules/ s/%s//g\" \"%s\"", cExcludeModule, g_cConfFile);
 			int r = system (cCommand);
+			if (r < 0)
+				cd_warning ("Not able to launch this command: %s", cCommand);
 			g_free (cCommand);
 		}
 		
+		cairo_dock_load_user_gui_backend (1);  // force the advanced GUI, it can display the config before the theme is loaded.
+		
 		GtkWidget *pWindow = cairo_dock_show_main_gui ();
 		gtk_window_set_title (GTK_WINDOW (pWindow), _("< Maintenance mode >"));
 		if (cExcludeModule != NULL)
-			cairo_dock_set_status_message_printf (pWindow, "Something went wrong with the applet '%s'...", cExcludeModule);
+			cairo_dock_set_status_message_printf (pWindow, "%s '%s'...", _("Something went wrong with this applet:"), cExcludeModule);
 		gtk_window_set_modal (GTK_WINDOW (pWindow), TRUE);
 		GMainLoop *pBlockingLoop = g_main_loop_new (NULL, FALSE);
 		g_signal_connect (G_OBJECT (pWindow),
-			"delete-event",
+			"destroy",
 			G_CALLBACK (on_delete_maintenance_gui),
 			pBlockingLoop);
 		
@@ -702,6 +697,7 @@ int main (int argc, char** argv)
 		cd_warning ("end of the maintenance mode.");
 		
 		g_main_loop_unref (pBlockingLoop);
+		cairo_dock_load_user_gui_backend (s_iGuiMode);  // go back to the user GUI.
 	}
 	
 	//\___________________ load the current theme.
@@ -718,6 +714,8 @@ int main (int argc, char** argv)
 		gchar *cCommand = g_strdup_printf ("/bin/cp -r \"%s/%s\"/* \"%s\"", CAIRO_DOCK_SHARE_DATA_DIR"/themes", cThemeName, g_cCurrentThemePath);
 		cd_message (cCommand);
 		int r = system (cCommand);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", cCommand);
 		g_free (cCommand);
 		
 		cairo_dock_mark_current_theme_as_modified (FALSE);  // on ne proposera pas de sauvegarder ce theme.
@@ -734,8 +732,8 @@ int main (int argc, char** argv)
 	if (!bSafeMode && cairo_dock_get_nb_modules () <= 1)  // 1 en comptant l'aide
 	{
 		Icon *pIcon = cairo_dock_get_dialogless_icon ();
-		cairo_dock_ask_question_and_wait (("No plug-in were found.\nPlug-ins provide most of the functionnalities of Cairo-Dock (animations, applets, views, etc).\nSee http://glx-dock.org for more information.\nSince there is almost no meaning in running the dock without them, the application will quit now."), pIcon, CAIRO_CONTAINER (g_pMainDock));
-		return 0;
+		///cairo_dock_ask_question_and_wait (_("No plug-in were found.\nPlug-ins provide most of the functionalities of Cairo-Dock (animations, applets, views, etc).\nSee http://glx-dock.org for more information.\nSince there is almost no meaning in running the dock without them, the application will quit now."), pIcon, CAIRO_CONTAINER (g_pMainDock));
+		cairo_dock_show_temporary_dialog_with_icon (_("No plug-in were found.\nPlug-ins provide most of the functionalities (animations, applets, views, etc).\nSee http://glx-dock.org for more information.\nThere is almost no meaning in running the dock without them and it's probably due to a problem with the installation of these plug-ins.\nBut if you really want to use the dock without these plug-ins, you can launch the dock with the '-f' option to no longer have this message.\n"), pIcon, CAIRO_CONTAINER (g_pMainDock), 0., CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON);
 	}
 	
 	//\___________________ display the changelog in case of a new version.
@@ -766,9 +764,13 @@ int main (int argc, char** argv)
 			if (cChangeLogMessage != NULL)
 			{
 				Icon *pFirstIcon = cairo_dock_get_first_icon (g_pMainDock->icons);
-				myDialogsParam.dialogTextDescription.bUseMarkup = TRUE;
-				cairo_dock_show_temporary_dialog_with_default_icon (gettext (cChangeLogMessage), pFirstIcon, CAIRO_CONTAINER (g_pMainDock), 0);
-				myDialogsParam.dialogTextDescription.bUseMarkup = FALSE;
+				
+				CairoDialogAttribute attr;
+				memset (&attr, 0, sizeof (CairoDialogAttribute));
+				attr.cText = gettext (cChangeLogMessage);
+				attr.cImageFilePath = CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON;
+				attr.bUseMarkup = TRUE;
+				cairo_dock_build_dialog (&attr, pFirstIcon, CAIRO_CONTAINER (g_pMainDock));
 				g_free (cChangeLogMessage);
 			}
 			g_key_file_free (pKeyFile);
@@ -782,7 +784,7 @@ int main (int argc, char** argv)
 		if (s_iNbCrashes < 2)
 			cMessage = g_strdup_printf (_("The module '%s' may have encountered a problem.\nIt has been restored successfully, but if it happens again, please report it at http://glx-dock.org"), cExcludeModule);
 		else
-			cMessage = g_strdup_printf ("The module '%s' has been deactivated because it may have caused some problems.\nYou can reactivate it, if it happens again thanks to report it at http://glx-dock.org", cExcludeModule);
+			cMessage = g_strdup_printf (_("The module '%s' has been deactivated because it may have caused some problems.\nYou can reactivate it, if it happens again thanks to report it at http://glx-dock.org"), cExcludeModule);
 		
 		CairoDockModule *pModule = cairo_dock_find_module_from_name (cExcludeModule);
 		Icon *icon = cairo_dock_get_dialogless_icon ();
@@ -793,42 +795,7 @@ int main (int argc, char** argv)
 	if (! bTesting)
 		g_timeout_add_seconds (5, _cairo_dock_successful_launch, GINT_TO_POINTER (bFirstLaunch));
 	
-	/*g_print ("\n\nTODO (3.0):\n"
-	"** Must-Be-Done **\n"
-	"- crash: Unity-4 -> DustSand -> Clear -> Humanity -> Unity-4\n"
-	"- add a parameter for sub-dock icon size?\n"
-	"- fix quick-info size/drawing/blurry\n"
-	"- cairo-dock-gui-themes.c:111 -> cairo-dock-gui-manager.c:414\n"
-	"- cairo-dock-applications-manager.c:1663 -> cairo-dock-class-manager.c:66\n"
-	"- indicators on different icon sizes\n"
-	"- slide view view: separator & scrollbar in vertical mode, last line out of the dock in horizontal mode\n"
-	"- cairo_dock_get_pixbuf_from_pixmap: assertion `pIconPixbuf != NULL' failed\n"
-	"- drop/hover indicators on different icon sizes\n"
-	"- Sys-monitor: ... and 0.0 on quick-info\n"
-	"- MP: empty icon on startup (audacious)\n"
-	"- cairo_dock_get_max_scale & fMagnitudeMax must die\n"
-	"- check Notification Area, there might be a bug (bitecoin, litecoin, skype)\n"
-	"- make some tests with the Dbus API and sub-docks / tmp launcher\n"
-	"- PM: crash when no battery is plugged ?\n"
-	"** That-Would-Be-Nice **\n"
-	"- redirection texture: make it per-container, or use the container gl buffer instead\n"
-	"- Slide view: allow to use the same borders as default (radius, color, width)\n"
-	"- Dialogs: allow to use the same borders as default (radius, color)\n"
-	"- let the view place the X thumbnail\n"
-	"- get rid of CAIRO_DOCK_IS_DOCK\n"
-	"- Icon bg: add ratio\n"
-	"- Default theme more consistent\n"
-	"- Recent Events: handle recent apps\n"
-	"- Firefox launcher: handle recent URLs\n"
-	"- check for config panel (g_object_unref assertion)\n"
-	"- review Help hints\n"
-	"- find Kwin/XFCE versions of gnome-control-center and KWin config tool for Composite-manager\n"
-	"- draw a preview of the dock in opengl\n"
-	"- display Help GUI in simple mode\n"
-	"- kde integration ++\n"
-	"- stack: enable iSubdockViewType\n"
-	"- link launchers with class+command\n"
-	"\n");*/
+	// TODO list in the 'TODO' file ;)
 	
 	gtk_main ();
 	
@@ -838,8 +805,10 @@ int main (int argc, char** argv)
 	signal (SIGABRT, NULL);
 	signal (SIGTERM, NULL);
 	gldi_free_all ();
-	
+
+	#if (LIBRSVG_MAJOR_VERSION == 2 && LIBRSVG_MINOR_VERSION < 36)
 	rsvg_term ();
+	#endif
 	xmlCleanupParser ();
 	g_string_free (s_pLaunchCommand, TRUE);
 	
