@@ -121,7 +121,7 @@ static void _on_change_desktop_geometry (void)
 	cairo_dock_notify_on_object (&myDesktopMgr, NOTIFICATION_SCREEN_GEOMETRY_ALTERED);
 }
 
-static gboolean _cairo_dock_unstack_Xevents (gpointer data)
+static gboolean _cairo_dock_unstack_Xevents (G_GNUC_UNUSED gpointer data)
 {
 	static XEvent event;
 	
@@ -137,7 +137,7 @@ static gboolean _cairo_dock_unstack_Xevents (gpointer data)
 		Xid = event.xany.window;
 		//g_print ("  type : %d; atom : %s; window : %d\n", event.type, XGetAtomName (s_XDisplay, event.xproperty.atom), Xid);
 		//if (event.type == ClientMessage)
-		//cd_message ("\n\n\n >>>>>>>>>>>< event.type : %d\n\n", event.type);
+		//cd_message ("\n\n\n >>>>>>>>>>>< event.type : %d\n", event.type);
 		if (Xid == root)
 		{
 			if (event.type == PropertyNotify)  // PropertyNotify sur root
@@ -199,7 +199,7 @@ static gboolean _cairo_dock_unstack_Xevents (gpointer data)
 			/*else if (event.type == g_iDamageEvent + XDamageNotify)
 			{
 				XDamageNotifyEvent *e = (XDamageNotifyEvent *) &event;
-				cd_debug ("window %s has been damaged (%d;%d %dx%d)\n", e->drawable, e->area.x, e->area.y, e->area.width, e->area.height);
+				cd_debug ("window %s has been damaged (%d;%d %dx%d)", e->drawable, e->area.x, e->area.y, e->area.width, e->area.height);
 				// e->drawable is the window ID of the damaged window
 				// e->geometry is the geometry of the damaged window	
 				// e->area     is the bounding rect for the damaged area	
@@ -208,7 +208,7 @@ static gboolean _cairo_dock_unstack_Xevents (gpointer data)
 				XDamageSubtract (s_XDisplay, e->damage, None, None);
 			}
 			else
-				cd_debug ("  type : %d (%d); window : %d\n", event.type, XDamageNotify, Xid);*/
+				cd_debug ("  type : %d (%d); window : %d", event.type, XDamageNotify, Xid);*/
 		}  // fin d'evenement sur une fenetre.
 	}
 	if (XEventsQueued (s_XDisplay, QueuedAlready) != 0)
@@ -235,7 +235,7 @@ void cairo_dock_get_current_desktop_and_viewport (int *iCurrentDesktop, int *iCu
  /// WINDOW MANAGER BACKEND ///
 //////////////////////////////
 
-static gboolean _set_desklets_on_widget_layer (CairoDesklet *pDesklet, gpointer data)
+static gboolean _set_desklets_on_widget_layer (CairoDesklet *pDesklet, G_GNUC_UNUSED gpointer data)
 {
 	Window Xid = gldi_container_get_Xid (CAIRO_CONTAINER (pDesklet));
 	if (pDesklet->iVisibility == CAIRO_DESKLET_ON_WIDGET_LAYER)
