@@ -33,7 +33,8 @@
 //#include <X11/extensions/Xdamage.h>
 #include <X11/extensions/XTest.h>
 #include <X11/extensions/Xinerama.h>
-#include <X11/extensions/shape.h>
+#include <X11/extensions/Xrandr.h>
+///#include <X11/extensions/shape.h>
 #endif
 
 #include "cairo-dock-container.h"  // CAIRO_DOCK_HORIZONTAL
@@ -50,6 +51,8 @@ extern CairoDockDesktopGeometry g_desktopGeometry;
 static gboolean s_bUseXComposite = TRUE;
 static gboolean s_bUseXTest = TRUE;
 static gboolean s_bUseXinerama = TRUE;
+static gboolean s_bUseXrandr = TRUE;
+static gint s_iXrandrMajor = 0,  s_iXrandrMinor = 0;
 //extern int g_iDamageEvent;
 
 static Display *s_XDisplay = NULL;
@@ -83,7 +86,7 @@ static Atom s_aWmName;
 static Atom s_aUtf8String;
 static Atom s_aString;
 
-static int _cairo_dock_xerror_handler (Display * pDisplay, XErrorEvent *pXError)
+static int _cairo_dock_xerror_handler (G_GNUC_UNUSED Display * pDisplay, XErrorEvent *pXError)
 {
 	cd_debug ("Error (%d, %d, %d) during an X request on %d", pXError->error_code, pXError->request_code, pXError->minor_code, pXError->resourceid);
 	return 0;
@@ -189,7 +192,7 @@ gboolean cairo_dock_update_screen_geometry (void)
 	int i;
 	for (i = 0; i < iBufferNbElements/4; i ++)
 	{
-		cd_message ("work area : (%d;%d) %dx%d\n", pXWorkArea[4*i], pXWorkArea[4*i+1], pXWorkArea[4*i+2], pXWorkArea[4*i+3]);
+		cd_message ("work area : (%d;%d) %dx%d", pXWorkArea[4*i], pXWorkArea[4*i+1], pXWorkArea[4*i+2], pXWorkArea[4*i+3]);
 	}
 	XFree (pXWorkArea);*/
 }
@@ -289,7 +292,6 @@ void cairo_dock_get_nb_viewports (int *iNbViewportX, int *iNbViewportY)
 	XGetWindowProperty (s_XDisplay, root, s_aNetDesktopGeometry, 0, G_MAXULONG, False, XA_CARDINAL, &aReturnedType, &aReturnedFormat, &iBufferNbElements, &iLeftBytes, (guchar **)&pVirtualScreenSizeBuffer);
 	if (iBufferNbElements > 0)
 	{
-		Screen *scr = XDefaultScreenOfDisplay (s_XDisplay);
 		cd_debug ("pVirtualScreenSizeBuffer : %dx%d ; screen : %dx%d", pVirtualScreenSizeBuffer[0], pVirtualScreenSizeBuffer[1], g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL], g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
 		*iNbViewportX = pVirtualScreenSizeBuffer[0] / g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];
 		*iNbViewportY = pVirtualScreenSizeBuffer[1] / g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
@@ -332,7 +334,7 @@ void cairo_dock_show_hide_desktop (gboolean bShow)
 	xClientMessage.xclient.data.l[3] = 2;
 	xClientMessage.xclient.data.l[4] = 0;
 	
-	cd_debug ("%s (%d)\n", __func__, bShow);
+	cd_debug ("%s (%d)", __func__, bShow);
 	XSendEvent (s_XDisplay,
 		root,
 		False,
@@ -399,7 +401,6 @@ Pixmap cairo_dock_get_window_background_pixmap (Window Xid)
 	g_return_val_if_fail (Xid > 0, None);
 	//cd_debug ("%s (%d)", __func__, Xid);
 	
-	Pixmap iPixmapID;
 	Atom aReturnedType = 0;
 	int aReturnedFormat = 0;
 	unsigned long iLeftBytes, iBufferNbElements;
@@ -548,6 +549,7 @@ void cairo_dock_set_nb_desktops (gulong iNbDesktops)
 gboolean cairo_dock_support_X_extension (void)
 {
 #ifdef HAVE_XEXTEND
+	// check for XComposite >= 1.2
 	int event_base, error_base, major, minor;
 	if (! XCompositeQueryExtension (s_XDisplay, &event_base, &error_base))  // on regarde si le serveur X supporte l'extension.
 	{
@@ -556,11 +558,11 @@ gboolean cairo_dock_support_X_extension (void)
 	}
 	else
 	{
-		major = 0, minor = 2;  // La version minimale requise pour avoir XCompositeNameWindowPixmap().
-		XCompositeQueryVersion (s_XDisplay, &major, &minor);  // on regarde si on est au moins dans cette version.
-		if (! (major > 0 || minor >= 2))
+		major = 0, minor = 0;
+		XCompositeQueryVersion (s_XDisplay, &major, &minor);
+		if (! (major > 0 || minor >= 2))  // 0.2 is required to have XCompositeNameWindowPixmap().
 		{
-			cd_warning ("XComposite extension too old.");
+			cd_warning ("XComposite extension is too old (%d.%d)", major, minor);
 			s_bUseXComposite = FALSE;
 		}
 	}
@@ -571,6 +573,7 @@ gboolean cairo_dock_support_X_extension (void)
 		return FALSE;
 	}*/
 	
+	// check for XTest
 	major = 0, minor = 0;
 	if (! XTestQueryExtension (s_XDisplay, &event_base, &error_base, &major, &minor))
 	{
@@ -578,27 +581,36 @@ gboolean cairo_dock_support_X_extension (void)
 		s_bUseXTest = FALSE;
 	}
 	
+	// check for Xinerama
 	if (! XineramaQueryExtension (s_XDisplay, &event_base, &error_base))
 	{
 		cd_warning ("Xinerama extension not supported");
 		s_bUseXinerama = FALSE;
 	}
+	
+	// check for Xrandr >= 1.3
+	if (! XRRQueryExtension (s_XDisplay, &event_base, &error_base))
+	{
+		cd_warning ("Xrandr extension not available.");
+		s_bUseXrandr = FALSE;
+	}
 	else
 	{
-		major = 0, minor = 0;
-		if (XineramaQueryVersion (s_XDisplay, &major, &minor) == 0)
+		XRRQueryVersion (s_XDisplay, &s_iXrandrMajor, &s_iXrandrMinor);
+		if (! cairo_dock_check_xrandr (1, 3))  // 1.3 is required to have XRRGetCrtcInfo
 		{
-			cd_warning ("Xinerama extension too old");
-			s_bUseXinerama = FALSE;
+			cd_warning ("Xrandr extension is too old (%d.%d) to use XRRGetCrtcInfo", s_iXrandrMajor, s_iXrandrMinor);
+			s_bUseXrandr = FALSE;
 		}
 	}
 	
 	return TRUE;
 #else
-	cd_warning ("The dock was not compiled with the X extensions (XComposite, xinerama, xtst, XDamage, etc).");
+	cd_warning ("The dock was not compiled with the X extensions (XComposite, Xinerama, Xtest, Xrandr, etc).");
 	s_bUseXComposite = FALSE;
 	s_bUseXTest = FALSE;
 	s_bUseXinerama = FALSE;
+	s_bUseXrandr = FALSE;
 	return FALSE;
 #endif
 }
@@ -618,42 +630,100 @@ gboolean cairo_dock_xinerama_is_available (void)
 	return s_bUseXinerama;
 }
 
+gboolean cairo_dock_check_xrandr (int major, int minor)
+{
+	return (s_iXrandrMajor > major || (s_iXrandrMajor == major && s_iXrandrMinor >= minor));  // if XRandr is not available, the version will stay at 0.0 and therefore the function will always return FALSE.
+}
+
 
 void cairo_dock_get_screen_offsets (int iNumScreen, int *iScreenOffsetX, int *iScreenOffsetY)
 {
 #ifdef HAVE_XEXTEND
-	g_return_if_fail (s_bUseXinerama);
-	int iNbScreens = 0;
-	XineramaScreenInfo *pScreens = XineramaQueryScreens (s_XDisplay, &iNbScreens);
-	if (pScreens != NULL)
+	if (s_bUseXrandr)  // we place Xrandr first to get more tests :) (and also because it will deprecate Xinerama).
 	{
-		if (iNumScreen >= iNbScreens)
+		cd_debug ("Using Xrandr to determine the screen's position and size ...");
+		XRRScreenResources *res = XRRGetScreenResources (s_XDisplay, DefaultRootWindow (s_XDisplay));  // Xrandr >= 1.3
+		if (res != NULL)
 		{
-			cd_warning ("the number of screen where to place the dock is too big, we'll choose the last one.");
-			iNumScreen = iNbScreens - 1;
+			cd_debug (" number of screen(s): %d", res->ncrtc);
+			if (iNumScreen >= res->ncrtc)
+			{
+				cd_warning ("the number of screen where to place the dock is too big, we'll choose the last one.");
+				iNumScreen = res->ncrtc - 1;
+			}
+			for (int i = 0; i < res->ncrtc; i++)
+			{
+				int j = (iNumScreen + i) % res->ncrtc;
+				XRRCrtcInfo *info = XRRGetCrtcInfo (s_XDisplay, res, res->crtcs[j]);
+				if (info == NULL)
+				{
+					cd_warning ("This screen (%d) has no info. Let's try the next one.", j);
+					continue;
+				}
+
+				if (info->width == 0 || info->height == 0)
+				{
+					cd_warning ("This screen (%d) has a null dimensions. Let's try the next one.", j);
+					XRRFreeCrtcInfo (info);
+					continue;
+				}
+				
+				*iScreenOffsetX = info->x;
+				*iScreenOffsetY = info->y;
+				g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL] = info->width;
+				g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL] = info->height;
+				
+				g_desktopGeometry.iScreenWidth[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL];
+				g_desktopGeometry.iScreenHeight[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL];
+				cd_message (" * screen %d => (%d;%d) %dx%d", j, *iScreenOffsetX, *iScreenOffsetY, g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL], g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+				
+				XRRFreeCrtcInfo (info);
+				XRRFreeScreenResources (res);
+				return;
+			}
+			XRRFreeScreenResources (res);
 		}
-		*iScreenOffsetX = pScreens[iNumScreen].x_org;
-		*iScreenOffsetY = pScreens[iNumScreen].y_org;
-		g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL] = pScreens[iNumScreen].width;
-		g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL] = pScreens[iNumScreen].height;
-		
-		g_desktopGeometry.iScreenWidth[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL];
-		g_desktopGeometry.iScreenHeight[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL];
-		cd_message (" * screen %d => (%d;%d) %dx%d\n", iNumScreen, *iScreenOffsetX, *iScreenOffsetY, g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL], g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL]);
-		
-		XFree (pScreens);
+		else
+			cd_warning ("No screen found from Xrandr, is it really active ?");
 	}
-	else
+
+	if (cairo_dock_xinerama_is_available () && XineramaIsActive (s_XDisplay))
 	{
-		cd_warning ("No screen found from Xinerama, is it really active ?");
-		*iScreenOffsetX = *iScreenOffsetY = 0;
-		g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL] = g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];
-		g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL] = g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
-		g_desktopGeometry.iScreenWidth[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL];
-		g_desktopGeometry.iScreenHeight[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL];
+		cd_debug ("Using Xinerama to determine the screen's position and size ...");
+		int iNbScreens = 0;
+		XineramaScreenInfo *pScreens = XineramaQueryScreens (s_XDisplay, &iNbScreens);
+		if (pScreens != NULL)
+		{
+			if (iNumScreen >= iNbScreens)
+			{
+				cd_warning ("the number of screen where to place the dock is too big, we'll choose the last one.");
+				iNumScreen = iNbScreens - 1;
+			}
+			*iScreenOffsetX = pScreens[iNumScreen].x_org;
+			*iScreenOffsetY = pScreens[iNumScreen].y_org;
+			g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL] = pScreens[iNumScreen].width;
+			g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL] = pScreens[iNumScreen].height;
+			
+			g_desktopGeometry.iScreenWidth[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL];
+			g_desktopGeometry.iScreenHeight[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL];
+			cd_message (" * screen %d => (%d;%d) %dx%d", iNumScreen, *iScreenOffsetX, *iScreenOffsetY, g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL], g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+			
+			XFree (pScreens);
+			return;
+		}
+		else
+			cd_warning ("No screen found from Xinerama, is it really active ?");
 	}
+
+	cd_warning ("Xrandr and Xinerama are not available, can't determine the screen's position/size");
+
+	*iScreenOffsetX = *iScreenOffsetY = 0;
+	g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL] = g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];
+	g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL] = g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
+	g_desktopGeometry.iScreenWidth[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL];
+	g_desktopGeometry.iScreenHeight[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL];
 #else
-	cd_warning ("The dock was not compiled with the support of Xinerama.");
+	cd_warning ("The dock was not compiled with the support of Xinerama/Xrandr.");
 #endif
 }
 
@@ -948,7 +1018,7 @@ gchar *cairo_dock_get_xwindow_name (Window Xid, gboolean bSearchWmName)
 	gchar *cName = NULL;
 	if (iBufferNbElements > 0)
 	{
-		cName = g_strdup (pNameBuffer);
+		cName = g_strdup ((gchar *)pNameBuffer);
 		XFree (pNameBuffer);
 	}
 	return cName;
@@ -988,12 +1058,12 @@ gchar *cairo_dock_get_xwindow_class (Window Xid, gchar **cWMClass)
 		cWmClass = g_strdup (pClassHint->res_class);
 		
 		cd_debug ("  res_name : %s(%x); res_class : %s(%x)", pClassHint->res_name, pClassHint->res_name, pClassHint->res_class, pClassHint->res_class);
-		if (strcmp (pClassHint->res_class, "Wine") == 0 && pClassHint->res_name && g_str_has_suffix (pClassHint->res_name, ".exe"))
+		if (strcmp (pClassHint->res_class, "Wine") == 0 && pClassHint->res_name && (g_str_has_suffix (pClassHint->res_name, ".exe") || g_str_has_suffix (pClassHint->res_name, ".EXE")))
 		{
 			cd_debug ("  wine application detected, changing the class '%s' to '%s'", pClassHint->res_class, pClassHint->res_name);
 			cClass = g_ascii_strdown (pClassHint->res_name, -1);
 		}
-		else if (*pClassHint->res_class == '/' && g_str_has_suffix (pClassHint->res_class, ".exe"))  // cas des applications Mono telles que tomboy ...
+		else if (*pClassHint->res_class == '/' && (g_str_has_suffix (pClassHint->res_class, ".exe") || g_str_has_suffix (pClassHint->res_name, ".EXE")))  // cas des applications Mono telles que tomboy ...
 		{
 			gchar *str = strrchr (pClassHint->res_class, '/');
 			if (str)
@@ -1019,7 +1089,10 @@ gchar *cairo_dock_get_xwindow_class (Window Xid, gchar **cWMClass)
 		XFree (pClassHint->res_class);
 		XFree (pClassHint);
 	}
-	*cWMClass = cWmClass;
+	if (cWMClass)
+		*cWMClass = cWmClass;
+	else
+		g_free (cWmClass);
 	return cClass;
 }
 
