@@ -34,6 +34,7 @@
 #include "cairo-dock-notifications.h"
 #include "cairo-dock-backends-manager.h"
 #include "cairo-dock-container.h"
+#include "cairo-dock-overlay.h"
 #include "cairo-dock-animations.h"
 
 extern gboolean g_bUseOpenGL;
@@ -41,7 +42,7 @@ extern CairoDockGLConfig g_openglConfig;
 extern CairoDockHidingEffect *g_pHidingBackend;
 extern CairoDockHidingEffect *g_pKeepingBelowBackend;
 
-static gboolean _update_fade_out_dock (gpointer pUserData, CairoDock *pDock, gboolean *bContinueAnimation)
+static gboolean _update_fade_out_dock (G_GNUC_UNUSED gpointer pUserData, CairoDock *pDock, gboolean *bContinueAnimation)
 {
 	pDock->iFadeCounter += (pDock->bFadeInOut ? 1 : -1);  // fade out, puis fade in.
 	
@@ -262,7 +263,6 @@ void cairo_dock_request_icon_animation (Icon *pIcon, CairoContainer *pContainer,
 	
 	if (cAnimation == NULL || iNbRounds == 0 || pIcon->iAnimationState != CAIRO_DOCK_STATE_REST)
 		return ;
-	///cairo_dock_notify_on_object (&myIconsMgr, NOTIFICATION_REQUEST_ICON_ANIMATION, pIcon, pDock, cAnimation, iNbRounds);
 	cairo_dock_notify_on_object (pIcon, NOTIFICATION_REQUEST_ICON_ANIMATION, pIcon, pDock, cAnimation, iNbRounds);
 	cairo_dock_start_icon_animation (pIcon, pDock);
 }
@@ -382,7 +382,7 @@ void cairo_dock_update_removing_inserting_icon_size_default (Icon *icon)
 }
 
 
-gboolean cairo_dock_update_inserting_removing_icon_notification (gpointer pUserData, Icon *pIcon, CairoDock *pDock, gboolean *bContinueAnimation)
+gboolean cairo_dock_update_inserting_removing_icon_notification (G_GNUC_UNUSED gpointer pUserData, Icon *pIcon, CairoDock *pDock, gboolean *bContinueAnimation)
 {
 	if (pIcon->iGlideDirection != 0)
 	{
@@ -401,7 +401,9 @@ gboolean cairo_dock_update_inserting_removing_icon_notification (gpointer pUserD
 		cairo_dock_redraw_container (CAIRO_CONTAINER (pDock));
 	}
 	
-	if (pIcon->fInsertRemoveFactor == 0 || ! pIcon->bBeingRemovedByCairo)
+	if (pIcon->fInsertRemoveFactor == 0)
+		pIcon->bBeingRemovedByCairo = FALSE;
+	if (! pIcon->bBeingRemovedByCairo)
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	
 	cairo_dock_update_removing_inserting_icon_size_default (pIcon);
@@ -415,7 +417,7 @@ gboolean cairo_dock_update_inserting_removing_icon_notification (gpointer pUserD
 	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 
-gboolean cairo_dock_on_insert_remove_icon_notification (gpointer pUserData, Icon *pIcon, CairoDock *pDock)
+gboolean cairo_dock_on_insert_remove_icon_notification (G_GNUC_UNUSED gpointer pUserData, Icon *pIcon, G_GNUC_UNUSED CairoDock *pDock)
 {
 	if (pIcon->iAnimationState == CAIRO_DOCK_STATE_REMOVE_INSERT)  // already in insert/remove state
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
@@ -429,7 +431,7 @@ gboolean cairo_dock_on_insert_remove_icon_notification (gpointer pUserData, Icon
 	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 
-gboolean cairo_dock_stop_inserting_removing_icon_notification (gpointer pUserData, Icon *pIcon)
+gboolean cairo_dock_stop_inserting_removing_icon_notification (G_GNUC_UNUSED gpointer pUserData, Icon *pIcon)
 {
 	pIcon->fGlideOffset = 0;
 	pIcon->iGlideDirection = 0;
@@ -443,7 +445,7 @@ gboolean cairo_dock_stop_inserting_removing_icon_notification (gpointer pUserDat
 
 #define cairo_dock_set_transition(pIcon, transition) (pIcon)->pTransition = transition
 
-static gboolean _cairo_dock_transition_step (gpointer pUserData, Icon *pIcon, CairoContainer *pContainer, gboolean *bContinueAnimation)
+static gboolean _cairo_dock_transition_step (G_GNUC_UNUSED gpointer pUserData, Icon *pIcon, CairoContainer *pContainer, gboolean *bContinueAnimation)
 {
 	CairoDockTransition *pTransition = cairo_dock_get_transition (pIcon);
 	if (pTransition == NULL)
@@ -537,3 +539,60 @@ void cairo_dock_remove_transition_on_icon (Icon *pIcon)
 	g_free (pTransition);
 	cairo_dock_set_transition (pIcon, NULL);
 }
+
+
+static gboolean _update_busy_animation (CairoOverlay *pOverlay, Icon *pIcon, CairoContainer *pContainer, gboolean *bContinueAnimation)
+{
+	CairoDockImageBuffer *pImage = cairo_dock_get_overlay_image_buffer (pOverlay);
+	if (! cairo_dock_image_buffer_is_animated (pImage))
+		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	//g_print ("%s ()\n", __func__);
+	
+	cairo_dock_image_buffer_next_frame (pImage);
+	
+	cairo_dock_redraw_icon (pIcon, pContainer);
+	
+	*bContinueAnimation = TRUE;
+	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+}
+static gboolean _remove_busy_animation (Icon *pIcon, CairoOverlay *pOverlay)
+{
+	//g_print ("%s ()\n", __func__);
+	cairo_dock_remove_notification_func_on_object (pIcon,
+		NOTIFICATION_UPDATE_ICON_SLOW,
+		(CairoDockNotificationFunc) _update_busy_animation,
+		pOverlay);
+	
+	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+}
+static const gchar *busy_id = "busy-animation";  // unique ID for all the busy-animation overlays.
+void cairo_dock_start_busy_animation (Icon *pIcon)
+{
+	CairoContainer *pContainer = pIcon->pContainer;
+	g_return_if_fail (pContainer != NULL);
+	
+	CairoOverlay *pOverlay = cairo_dock_add_overlay_from_image (pIcon, NULL, CAIRO_OVERLAY_MIDDLE, (gpointer)busy_id);  // remove any previous busy-animation overlay
+	CairoDockImageBuffer *pImage = cairo_dock_get_overlay_image_buffer (pOverlay);
+	
+	int iWidth, iHeight;
+	cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
+	cairo_dock_load_image_buffer_full (pImage, "/usr/share/cairo-dock/plug-ins/Cairo-Penguin/themes/Classic/faller.png", iWidth * pOverlay->fScale, iHeight * pOverlay->fScale, CAIRO_DOCK_ANIMATED_IMAGE, 1.);
+	
+	
+	cairo_dock_register_notification_on_object (pIcon,
+		NOTIFICATION_UPDATE_ICON_SLOW,
+		(CairoDockNotificationFunc) _update_busy_animation,
+		CAIRO_DOCK_RUN_AFTER, pOverlay);
+	
+	cairo_dock_register_notification_on_object (pOverlay,
+		NOTIFICATION_DESTROY,
+		(CairoDockNotificationFunc) _remove_busy_animation,
+		CAIRO_DOCK_RUN_AFTER, pIcon);  // the overlay is tied to the icon, so pIcon stays alive longer than pOverlay
+	
+	cairo_dock_launch_animation (pContainer);
+}
+
+void cairo_dock_stop_busy_animation (Icon *pIcon)
+{
+	cairo_dock_remove_overlay_at_position (pIcon, CAIRO_OVERLAY_MIDDLE, (gpointer)busy_id);
+}
