@@ -498,7 +498,7 @@ CairoDock * cairo_dock_detach_appli (Icon *pIcon)
 	return pParentDock;
 }
 
-#define x_icon_geometry(icon, pDock) (pDock->container.iWindowPositionX + icon->fXAtRest + (pDock->container.iWidth - pDock->fFlatDockWidth) / 2 + (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2))
+#define x_icon_geometry(icon, pDock) (pDock->container.iWindowPositionX + icon->fXAtRest + (pDock->container.iWidth - pDock->iActiveWidth) * pDock->fAlign + (pDock->iActiveWidth - pDock->fFlatDockWidth) / 2)
 ///#define y_icon_geometry(icon, pDock) (pDock->container.iWindowPositionY + icon->fDrawY - icon->fHeight * myIconsParam.fAmplitude * pDock->fMagnitudeMax)
 #define y_icon_geometry(icon, pDock) (pDock->container.iWindowPositionY + icon->fDrawY)
 void  cairo_dock_set_one_icon_geometry_for_window_manager (Icon *icon, CairoDock *pDock)
@@ -509,15 +509,16 @@ void  cairo_dock_set_one_icon_geometry_for_window_manager (Icon *icon, CairoDock
 	iY = y_icon_geometry (icon, pDock);  // il faudrait un fYAtRest ...
 	//g_print (" -> %d;%d (%.2f)\n", iX - pDock->container.iWindowPositionX, iY - pDock->container.iWindowPositionY, icon->fXAtRest);
 	iWidth = icon->fWidth;
-	iHeight = icon->fHeight * (1. + 2*myIconsParam.fAmplitude * pDock->fMagnitudeMax);  // on elargit en haut et en bas, pour gerer les cas ou l'icone grossirait vers le haut ou vers le bas.
+	int dh = (icon->iImageHeight - icon->fHeight);
+	iHeight = icon->fHeight + 2 * dh;  // on elargit en haut et en bas, pour gerer les cas ou l'icone grossirait vers le haut ou vers le bas.
 	
 	if (pDock->container.bIsHorizontal)
-		cairo_dock_set_xicon_geometry (icon->Xid, iX, iY, iWidth, iHeight);
+		cairo_dock_set_xicon_geometry (icon->Xid, iX, iY - dh, iWidth, iHeight);
 	else
-		cairo_dock_set_xicon_geometry (icon->Xid, iY, iX, iHeight, iWidth);
+		cairo_dock_set_xicon_geometry (icon->Xid, iY - dh, iX, iHeight, iWidth);
 }
 
-void cairo_dock_reserve_one_icon_geometry_for_window_manager (Window *Xid, Icon *icon, CairoDock *pMainDock)
+void cairo_dock_reserve_one_icon_geometry_for_window_manager (G_GNUC_UNUSED Window *Xid, Icon *icon, CairoDock *pMainDock)
 {
 	if (CAIRO_DOCK_IS_APPLI (icon) && icon->cParentDockName == NULL)
 	{
@@ -556,7 +557,7 @@ void cairo_dock_reserve_one_icon_geometry_for_window_manager (Window *Xid, Icon
 			else  // on va se placer a la fin de la barre des taches.
 			{
 				Icon *pIcon, *pLastLauncher = NULL;
-				GList *ic, *last_launcher_ic = NULL;
+				GList *ic;
 				for (ic = pMainDock->icons; ic != NULL; ic = ic->next)
 				{
 					pIcon = ic->data;
@@ -566,7 +567,6 @@ void cairo_dock_reserve_one_icon_geometry_for_window_manager (Window *Xid, Icon
 					|| (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon)))  // separator (user or auto).
 					{
 						pLastLauncher = pIcon;
-						last_launcher_ic = ic;
 					}
 				}
 						
