@@ -101,8 +101,10 @@ static gboolean _mouse_is_really_outside (CairoDock *pDock)
 	int x1, x2, y1, y2;
 	if (pDock->iInputState == CAIRO_DOCK_INPUT_ACTIVE)
 	{
-		x1 = 0;
-		x2 = pDock->container.iWidth;
+		///x1 = 0;
+		///x2 = pDock->container.iWidth;
+		x1 = (pDock->container.iWidth - pDock->iActiveWidth) * pDock->fAlign;
+		x2 = x1 + pDock->iActiveWidth;
 		if (pDock->container.bDirectionUp)
 		{
 			///y1 = (pDock->fMagnitudeMax != 0 ? 0 : pDock->container.iHeight - pDock->iMinDockHeight);
@@ -118,8 +120,8 @@ static gboolean _mouse_is_really_outside (CairoDock *pDock)
 	}
 	else if (pDock->iInputState == CAIRO_DOCK_INPUT_AT_REST)
 	{
-		x1 = (pDock->container.iWidth - pDock->iMinDockWidth) / 2;
-		x2 = (pDock->container.iWidth + pDock->iMinDockWidth) / 2;
+		x1 = (pDock->container.iWidth - pDock->iMinDockWidth) * pDock->fAlign;
+		x2 = x1 + pDock->iMinDockWidth;
 		if (pDock->container.bDirectionUp)
 		{
 			y1 = pDock->container.iHeight - pDock->iMinDockHeight + 1;
@@ -149,7 +151,7 @@ void cairo_dock_freeze_docks (gboolean bFreeze)
 	s_bFrozenDock = bFreeze;
 }
 
-gboolean cairo_dock_render_dock_notification (gpointer pUserData, CairoDock *pDock, cairo_t *pCairoContext)
+gboolean cairo_dock_render_dock_notification (G_GNUC_UNUSED gpointer pUserData, CairoDock *pDock, cairo_t *pCairoContext)
 {
 	if (! pCairoContext)  // on n'a pas mis le rendu cairo ici a cause du rendu optimise.
 	{
@@ -173,7 +175,7 @@ gboolean cairo_dock_render_dock_notification (gpointer pUserData, CairoDock *pDo
 	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 
-gboolean cairo_dock_on_expose (GtkWidget *pWidget,
+gboolean cairo_dock_on_expose (G_GNUC_UNUSED GtkWidget *pWidget,
 #if (GTK_MAJOR_VERSION < 3)
 	GdkEventExpose *pExpose,
 #else
@@ -314,7 +316,7 @@ static gboolean _cairo_dock_show_sub_dock_delayed (CairoDock *pDock)
 
 	return FALSE;
 }
-static void _search_icon (Icon *icon, CairoContainer *pContainer, gpointer *data)
+static void _search_icon (Icon *icon, G_GNUC_UNUSED CairoContainer *pContainer, gpointer *data)
 {
 	if (icon == data[0])
 		data[1] = icon;
@@ -480,7 +482,6 @@ gboolean cairo_dock_on_motion_notify (GtkWidget* pWidget,
 	if (s_bFrozenDock && pMotion != NULL && pMotion->time != 0)
 		return FALSE;
 	Icon *pPointedIcon=NULL, *pLastPointedIcon = cairo_dock_get_pointed_icon (pDock->icons);
-	int iLastMouseX = pDock->container.iMouseX;
 	//g_print ("%s (%.2f;%.2f, %d)\n", __func__, pMotion->x, pMotion->y, pDock->iInputState);
 	
 	if (pMotion != NULL)
@@ -591,7 +592,7 @@ gboolean cairo_dock_on_motion_notify (GtkWidget* pWidget,
 	return FALSE;
 }
 
-gboolean cairo_dock_on_leave_dock_notification2 (gpointer data, CairoDock *pDock, gboolean *bStartAnimation)
+gboolean cairo_dock_on_leave_dock_notification2 (G_GNUC_UNUSED gpointer data, CairoDock *pDock, G_GNUC_UNUSED gboolean *bStartAnimation)
 {
 	//\_______________ On gere le drag d'une icone hors du dock.
 	if (s_pIconClicked != NULL
@@ -639,7 +640,7 @@ gboolean cairo_dock_on_leave_dock_notification2 (gpointer data, CairoDock *pDock
 	}
 	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
-gboolean cairo_dock_on_leave_dock_notification (gpointer data, CairoDock *pDock, gboolean *bStartAnimation)
+gboolean cairo_dock_on_leave_dock_notification (G_GNUC_UNUSED gpointer data, CairoDock *pDock, G_GNUC_UNUSED gboolean *bStartAnimation)
 {
 	//\_______________ Arrive ici, on est sorti du dock.
 	pDock->container.bInside = FALSE;
@@ -732,7 +733,7 @@ gboolean cairo_dock_on_leave_dock_notification (gpointer data, CairoDock *pDock,
 }
 
 
-gboolean cairo_dock_on_leave_notify (GtkWidget* pWidget, GdkEventCrossing* pEvent, CairoDock *pDock)
+gboolean cairo_dock_on_leave_notify (G_GNUC_UNUSED GtkWidget* pWidget, GdkEventCrossing* pEvent, CairoDock *pDock)
 {
 	//g_print ("%s (bInside:%d; iState:%d; iRefCount:%d)\n", __func__, pDock->container.bInside, pDock->iInputState, pDock->iRefCount);
 	//\_______________ On tire le dock => on ignore le signal.
@@ -828,7 +829,7 @@ gboolean cairo_dock_on_leave_notify (GtkWidget* pWidget, GdkEventCrossing* pEven
 	return TRUE;
 }
 
-gboolean cairo_dock_on_enter_notification (gpointer pData, CairoDock *pDock, gboolean *bStartAnimation)
+gboolean cairo_dock_on_enter_notification (G_GNUC_UNUSED gpointer pData, CairoDock *pDock, G_GNUC_UNUSED gboolean *bStartAnimation)
 {
 	// si on rentre avec une icone volante, on la met dedans.
 	if (s_pFlyingContainer != NULL)
@@ -838,10 +839,12 @@ gboolean cairo_dock_on_enter_notification (gpointer pData, CairoDock *pDock, gbo
 		{
 			struct timeval tv;
 			int r = gettimeofday (&tv, NULL);
-			double t = tv.tv_sec + tv.tv_usec * 1e-6;
+			double t = 0.;
+			if (r == 0)
+				t = tv.tv_sec + tv.tv_usec * 1e-6;
 			if (t - s_pFlyingContainer->fCreationTime > 1)  // on empeche le cas ou enlever l'icone fait augmenter le ratio du dock, et donc sa hauteur, et nous fait rentrer dedans des qu'on sort l'icone.
 			{
-				cd_debug ("on remet l'icone volante dans un dock (dock d'origine : %s)\n", pFlyingIcon->cParentDockName);
+				cd_debug ("on remet l'icone volante dans un dock (dock d'origine : %s)", pFlyingIcon->cParentDockName);
 				cairo_dock_free_flying_container (s_pFlyingContainer);
 				cairo_dock_stop_icon_animation (pFlyingIcon);
 				cairo_dock_insert_icon_in_dock (pFlyingIcon, pDock, CAIRO_DOCK_ANIMATE_ICON);
@@ -853,7 +856,7 @@ gboolean cairo_dock_on_enter_notification (gpointer pData, CairoDock *pDock, gbo
 	
 	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
-gboolean cairo_dock_on_enter_notify (GtkWidget* pWidget, GdkEventCrossing* pEvent, CairoDock *pDock)
+gboolean cairo_dock_on_enter_notify (G_GNUC_UNUSED GtkWidget* pWidget, GdkEventCrossing* pEvent, CairoDock *pDock)
 {
 	//g_print ("%s (bIsMainDock : %d; bInside:%d; state:%d; iMagnitudeIndex:%d; input shape:%x; event:%p)\n", __func__, pDock->bIsMainDock, pDock->container.bInside, pDock->iInputState, pDock->iMagnitudeIndex, pDock->pShapeBitmap, pEvent);
 	if (! cairo_dock_entrance_is_allowed (pDock))
@@ -933,7 +936,9 @@ gboolean cairo_dock_on_enter_notify (GtkWidget* pWidget, GdkEventCrossing* pEven
 		{
 			struct timeval tv;
 			int r = gettimeofday (&tv, NULL);
-			double t = tv.tv_sec + tv.tv_usec * 1e-6;
+			double t = 0.;
+			if (r == 0)
+				t = tv.tv_sec + tv.tv_usec * 1e-6;
 			if (t - s_pFlyingContainer->fCreationTime > 1)  // on empeche le cas ou enlever l'icone fait augmenter le ratio du dock, et donc sa hauteur, et nous fait rentrer dedans des qu'on sort l'icone.
 			{
 				//g_print ("on remet l'icone volante dans un dock (dock d'origine : %s)\n", pFlyingIcon->cParentDockName);
@@ -996,7 +1001,7 @@ gboolean cairo_dock_on_enter_notify (GtkWidget* pWidget, GdkEventCrossing* pEven
 }
 
 
-gboolean cairo_dock_on_key_release (GtkWidget *pWidget,
+gboolean cairo_dock_on_key_release (G_GNUC_UNUSED GtkWidget *pWidget,
 	GdkEventKey *pKey,
 	CairoDock *pDock)
 {
@@ -1050,7 +1055,7 @@ static gboolean _check_mouse_outside (CairoDock *pDock)  // ce test est principa
 	cairo_dock_calculate_dock_icons (pDock);  // pour faire retrecir le dock si on n'est pas dedans, merci X de nous faire sortir du dock alors que la souris est toujours dedans :-/
 	return TRUE;
 }
-gboolean cairo_dock_on_button_press (GtkWidget* pWidget, GdkEventButton* pButton, CairoDock *pDock)
+gboolean cairo_dock_on_button_press (G_GNUC_UNUSED GtkWidget* pWidget, GdkEventButton* pButton, CairoDock *pDock)
 {
 	//g_print ("+ %s (%d/%d, %x)\n", __func__, pButton->type, pButton->button, pWidget);
 	if (pDock->container.bIsHorizontal)  // utile ?
@@ -1151,9 +1156,9 @@ gboolean cairo_dock_on_button_press (GtkWidget* pWidget, GdkEventButton* pButton
 						///if (prev_icon != NULL && prev_icon->iGroup != s_pIconClicked->iGroup)  // the previous icon is in a different group -> we'll be at the beginning of our group.
 						///	prev_icon = NULL;  // => move to the beginning of the group/dock
 						cairo_dock_move_icon_after_icon (pDock, s_pIconClicked, prev_icon);
-
-						pDock->pRenderer->calculate_icons (pDock);
-
+						
+						cairo_dock_calculate_dock_icons (pDock);
+						
 						if (! CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (s_pIconClicked))
 						{
 							cairo_dock_request_icon_animation (s_pIconClicked, CAIRO_CONTAINER (pDock), "bounce", 2);
@@ -1255,7 +1260,7 @@ gboolean cairo_dock_on_button_press (GtkWidget* pWidget, GdkEventButton* pButton
 }
 
 
-gboolean cairo_dock_on_scroll (GtkWidget* pWidget, GdkEventScroll* pScroll, CairoDock *pDock)
+gboolean cairo_dock_on_scroll (G_GNUC_UNUSED GtkWidget* pWidget, GdkEventScroll* pScroll, CairoDock *pDock)
 {
 	if (pScroll->direction != GDK_SCROLL_UP && pScroll->direction != GDK_SCROLL_DOWN)  // on degage les scrolls horizontaux.
 	{
@@ -1362,11 +1367,11 @@ gboolean cairo_dock_on_configure (GtkWidget* pWidget, GdkEventConfigure* pEvent,
 				icon = ic->data;
 				if (icon->bDamaged)
 				{
-					//g_print ("#### icon %s is damaged\n", icon->cName);
+					cd_debug ("This icon %s is damaged", icon->cName);
 					icon->bDamaged = FALSE;
 					if (cairo_dock_get_icon_data_renderer (icon) != NULL)
 					{
-						cairo_dock_refresh_data_renderer (icon, CAIRO_CONTAINER (pDock), NULL);  // no cairo context in OpenGL
+						cairo_dock_refresh_data_renderer (icon, CAIRO_CONTAINER (pDock));
 					}
 					else if (icon->iSubdockViewType != 0)
 					{
@@ -1376,7 +1381,7 @@ gboolean cairo_dock_on_configure (GtkWidget* pWidget, GdkEventConfigure* pEvent,
 					{
 						cairo_dock_reload_module_instance (icon->pModuleInstance, FALSE);  // easy but safe way to redraw the icon properly.
 					}
-					else  // if we don't know how thie icon should be drawn, just reload it.
+					else  // if we don't know how the icon should be drawn, just reload it.
 					{
 						cairo_dock_load_icon_image (icon, CAIRO_CONTAINER (pDock));
 					}
@@ -1433,7 +1438,7 @@ gboolean cairo_dock_on_configure (GtkWidget* pWidget, GdkEventConfigure* pEvent,
 static gboolean s_bWaitForData = FALSE;
 static gboolean s_bCouldDrop = FALSE;
 
-void cairo_dock_on_drag_data_received (GtkWidget *pWidget, GdkDragContext *dc, gint x, gint y, GtkSelectionData *selection_data, guint info, guint time, CairoDock *pDock)
+void cairo_dock_on_drag_data_received (G_GNUC_UNUSED GtkWidget *pWidget, GdkDragContext *dc, gint x, gint y, GtkSelectionData *selection_data, G_GNUC_UNUSED guint info, guint time, CairoDock *pDock)
 {
 	cd_debug ("%s (%dx%d, %d, %d)", __func__, x, y, time, pDock->container.bInside);
 	if (cairo_dock_is_hidden (pDock))  // X ne semble pas tenir compte de la zone d'input pour dropper les trucs...
@@ -1451,7 +1456,7 @@ void cairo_dock_on_drag_data_received (GtkWidget *pWidget, GdkDragContext *dc, g
 	{
 		s_bWaitForData = FALSE;
 		gdk_drag_status (dc, GDK_ACTION_COPY, time);
-		cd_debug ("drag info : <%s>\n", cReceivedData);
+		cd_debug ("drag info : <%s>", cReceivedData);
 		pDock->iAvoidingMouseIconType = CAIRO_DOCK_LAUNCHER;
 		if (g_str_has_suffix (cReceivedData, ".desktop")/** || g_str_has_suffix (cReceivedData, ".sh")*/)
 			pDock->fAvoidingMouseMargin = .5;  // on ne sera jamais dessus.
@@ -1482,11 +1487,6 @@ void cairo_dock_on_drag_data_received (GtkWidget *pWidget, GdkDragContext *dc, g
 	if (s_bCouldDrop)  // can drop on the dock
 	{
 		cd_debug ("drop between icons");
-		if (myDocksParam.bLockIcons || myDocksParam.bLockAll)  // locked, can't add anything.
-		{
-			gtk_drag_finish (dc, FALSE, FALSE, time);
-			return ;
-		}
 		
 		pPointedIcon = NULL;
 		fOrder = 0;
@@ -1494,7 +1494,7 @@ void cairo_dock_on_drag_data_received (GtkWidget *pWidget, GdkDragContext *dc, g
 		// try to guess where we dropped.
 		int iDropX = (pDock->container.bIsHorizontal ? x : y);
 		Icon *pNeighboorIcon;
-		Icon *icon;
+		Icon *icon = NULL;
 		GList *ic;
 		for (ic = pDock->icons; ic != NULL; ic = ic->next)
 		{
@@ -1514,6 +1514,12 @@ void cairo_dock_on_drag_data_received (GtkWidget *pWidget, GdkDragContext *dc, g
 				break;
 			}
 		}
+		if (myDocksParam.bLockAll)  // locked, can't add anything.
+		{
+			cairo_dock_show_temporary_dialog_with_default_icon (_("Sorry but the dock is locked"), icon, CAIRO_CONTAINER (pDock), 5000);
+			gtk_drag_finish (dc, FALSE, FALSE, time);
+			return ;
+		}
 	}
 	else  // drop on an icon or nowhere.
 	{
@@ -1585,7 +1591,7 @@ void cairo_dock_on_drag_data_received (GtkWidget *pWidget, GdkDragContext *dc, g
 	gtk_drag_finish (dc, TRUE, FALSE, time);
 }
 
-gboolean cairo_dock_on_drag_drop (GtkWidget *pWidget, GdkDragContext *dc, gint x, gint y, guint time, CairoDock *pDock)
+gboolean cairo_dock_on_drag_drop (GtkWidget *pWidget, GdkDragContext *dc, gint x, gint y, guint time, G_GNUC_UNUSED CairoDock *pDock)
 {
 	cd_message ("%s (%dx%d, %d)", __func__, x, y, time);
 	GdkAtom target = gtk_drag_dest_find_target (pWidget, dc, NULL);
@@ -1607,7 +1613,7 @@ gboolean cairo_dock_on_drag_motion (GtkWidget *pWidget, GdkDragContext *dc, gint
 		/*GdkAtom gdkAtom = gdk_drag_get_selection (dc);
 		Atom xAtom = gdk_x11_atom_to_xatom (gdkAtom);
 		Window Xid = GDK_WINDOW_XID (dc->source_window);
-		cd_debug (" <%s>\n", cairo_dock_get_property_name_on_xwindow (Xid, xAtom));*/
+		cd_debug (" <%s>", cairo_dock_get_property_name_on_xwindow (Xid, xAtom));*/
 		
 		gboolean bStartAnimation = FALSE;
 		cairo_dock_notify_on_object (pDock, NOTIFICATION_START_DRAG_DATA, pDock, &bStartAnimation);
@@ -1646,7 +1652,6 @@ gboolean cairo_dock_on_drag_motion (GtkWidget *pWidget, GdkDragContext *dc, gint
 		X = y - pDock->container.iWidth/2;
 	}
 	int w, h;
-	Icon *icon = cairo_dock_get_pointed_icon (pDock->icons);
 	if (pDock->iInputState == CAIRO_DOCK_INPUT_AT_REST)
 	{
 		w = pDock->iMinDockWidth;
@@ -1675,7 +1680,7 @@ gboolean cairo_dock_on_drag_motion (GtkWidget *pWidget, GdkDragContext *dc, gint
 	return TRUE;  // on accepte le drop.
 }
 
-void cairo_dock_on_drag_leave (GtkWidget *pWidget, GdkDragContext *dc, guint time, CairoDock *pDock)
+void cairo_dock_on_drag_leave (GtkWidget *pWidget, G_GNUC_UNUSED GdkDragContext *dc, G_GNUC_UNUSED guint time, CairoDock *pDock)
 {
 	//g_print ("stop dragging 1\n");
 	Icon *icon = cairo_dock_get_pointed_icon (pDock->icons);
@@ -1735,7 +1740,7 @@ static void _cairo_dock_show_dock_at_mouse (CairoDock *pDock)
 		(pDock->container.bIsHorizontal ? iNewPositionY : iNewPositionX));
 	gtk_widget_show (pDock->container.pWidget);
 }
-void cairo_dock_raise_from_shortcut (const char *cKeyShortcut, gpointer data)
+void cairo_dock_raise_from_shortcut (G_GNUC_UNUSED const char *cKeyShortcut, G_GNUC_UNUSED gpointer data)
 {
 	if (gldi_container_is_visible (CAIRO_CONTAINER (g_pMainDock)))
 	{
@@ -1745,8 +1750,8 @@ void cairo_dock_raise_from_shortcut (const char *cKeyShortcut, gpointer data)
 	{
 		_cairo_dock_show_dock_at_mouse (g_pMainDock);
 	}
-	if (g_pMainDock->iVisibility != CAIRO_DOCK_VISI_SHORTKEY)  // could happen if we set the shortkey outside of the Visibility module.
-		g_pMainDock->iVisibility == CAIRO_DOCK_VISI_SHORTKEY;
+	// if (g_pMainDock->iVisibility != CAIRO_DOCK_VISI_SHORTKEY)  // could happen if we set the shortkey outside of the Visibility module.
+		g_pMainDock->iVisibility = CAIRO_DOCK_VISI_SHORTKEY;
 	s_bHideAfterShortcut = FALSE;
 }
 
