@@ -586,7 +586,7 @@ void cairo_dock_detach_Xid_from_inhibitors (Window Xid, const gchar *cClass)
 	}
 }
 
-static void _cairo_dock_remove_all_applis_from_class (gchar *cClass, CairoDockClassAppli *pClassAppli, gpointer data)
+static void _cairo_dock_remove_all_applis_from_class (G_GNUC_UNUSED gchar *cClass, CairoDockClassAppli *pClassAppli, G_GNUC_UNUSED gpointer data)
 {
 	g_list_free (pClassAppli->pAppliOfClass);
 	pClassAppli->pAppliOfClass = NULL;
@@ -939,7 +939,7 @@ gboolean cairo_dock_check_class_subdock_is_empty (CairoDock *pDock, const gchar
 }
 
 
-static void _cairo_dock_reset_overwrite_exceptions (gchar *cClass, CairoDockClassAppli *pClassAppli, gpointer data)
+static void _cairo_dock_reset_overwrite_exceptions (G_GNUC_UNUSED gchar *cClass, CairoDockClassAppli *pClassAppli, G_GNUC_UNUSED gpointer data)
 {
 	pClassAppli->bUseXIcon = FALSE;
 }
@@ -959,14 +959,14 @@ void cairo_dock_set_overwrite_exceptions (const gchar *cExceptions)
 	int i;
 	for (i = 0; cClassList[i] != NULL; i ++)
 	{
-		CairoDockClassAppli *pClassAppli = cairo_dock_get_class (cClassList[i]);
+		pClassAppli = cairo_dock_get_class (cClassList[i]);
 		pClassAppli->bUseXIcon = TRUE;
 	}
 	
 	g_strfreev (cClassList);
 }
 
-static void _cairo_dock_reset_group_exceptions (gchar *cClass, CairoDockClassAppli *pClassAppli, gpointer data)
+static void _cairo_dock_reset_group_exceptions (G_GNUC_UNUSED gchar *cClass, CairoDockClassAppli *pClassAppli, G_GNUC_UNUSED gpointer data)
 {
 	pClassAppli->bExpand = FALSE;
 }
@@ -986,7 +986,7 @@ void cairo_dock_set_group_exceptions (const gchar *cExceptions)
 	int i;
 	for (i = 0; cClassList[i] != NULL; i ++)
 	{
-		CairoDockClassAppli *pClassAppli = cairo_dock_get_class (cClassList[i]);
+		pClassAppli = cairo_dock_get_class (cClassList[i]);
 		pClassAppli->bExpand = TRUE;
 	}
 	
@@ -1090,7 +1090,7 @@ Icon *cairo_dock_get_inhibitor (Icon *pIcon, gboolean bOnlyInDock)
 	return NULL;
 }
 
-
+/* Not used
 static gboolean _appli_is_older (Icon *pIcon1, Icon *pIcon2, CairoDockClassAppli *pClassAppli)  // TRUE if icon1 older than icon2
 {
 	Icon *pAppliIcon;
@@ -1105,7 +1105,7 @@ static gboolean _appli_is_older (Icon *pIcon1, Icon *pIcon2, CairoDockClassAppli
 	}
 	return FALSE;
 }
-
+*/
 static inline double _get_previous_order (GList *ic)
 {
 	if (ic == NULL)
@@ -1178,7 +1178,7 @@ static inline double _get_first_appli_order (CairoDock *pDock, GList *first_laun
 			if (last_launcher_ic != NULL)
 			{
 				//g_print (" go just after the last launcher (%s)\n", ((Icon*)last_launcher_ic->data)->cName);
-				fOrder = _get_next_order (last_launcher_ic);  // we have already skipped the separators, so we can just take the next order.
+				fOrder = _get_next_order (last_launcher_ic);
 			}
 			else  // no launcher, go to the beginning of the dock.
 			{
@@ -1213,7 +1213,6 @@ void cairo_dock_set_class_order_in_dock (Icon *pIcon, CairoDock *pDock)
 	GList *same_class_ic = NULL;
 
 	// First look for an inhibitor of this class, preferably a launcher.
-	CairoDock *pHostDock = pDock;
 	CairoDock *pParentDock;
 	Icon *pInhibitorIcon;
 	GList *ic;
@@ -1228,7 +1227,6 @@ void cairo_dock_set_class_order_in_dock (Icon *pIcon, CairoDock *pDock)
 		///	pInhibitorIcon = cairo_dock_search_icon_pointing_on_dock (pParentDock, NULL);
 		pSameClassIcon = pInhibitorIcon;
 		same_class_ic = ic;
-		pHostDock = pParentDock;
 		//g_print (" found an inhibitor of this class: %s (%d)\n", pSameClassIcon->cName, pSameClassIcon->iAge);
 		if (CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER (pSameClassIcon))  // it's a launcher, we wont't find better -> quit
 			break ;
@@ -1248,12 +1246,11 @@ void cairo_dock_set_class_order_in_dock (Icon *pIcon, CairoDock *pDock)
 			{
 				pSameClassIcon = pAppliIcon;
 				same_class_ic = ic;
-				pHostDock = pParentDock;
 				//g_print (" found an appli of this class: %s (%d)\n", pSameClassIcon->cName, pSameClassIcon->iAge);
 				break ;
 			}
 		}
-		pIcon->iGroup = CAIRO_DOCK_APPLI;  // no inhibitor, so we'll go in the taskbar group.
+		pIcon->iGroup = (myTaskbarParam.bSeparateApplis ? CAIRO_DOCK_APPLI : CAIRO_DOCK_LAUNCHER);  // no inhibitor, so we'll go in the taskbar group.
 	}
 	else  // an inhibitor is present, we'll go next to it, so we'll be in its group.
 	{
@@ -1296,17 +1293,17 @@ void cairo_dock_set_class_order_in_dock (Icon *pIcon, CairoDock *pDock)
 	// if no icon of our class is present in the dock, place it amongst the other appli icons, after the first appli or after the launchers, and ordered by age.
 	// search the last launcher and the first appli.
 	Icon *icon;
-	Icon *pFirstAppli = NULL, *pLastLauncher = NULL, *pFirstLauncher = NULL;
+	Icon *pFirstLauncher = NULL;
 	GList *first_appli_ic = NULL, *last_launcher_ic = NULL, *first_launcher_ic = NULL;
 	for (ic = pDock->icons; ic != NULL; ic = ic->next)
 	{
 		icon = ic->data;
 		if (CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER (icon)  // launcher, even without class
 		|| CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon)  // container icon (likely to contain some launchers)
-		|| (CAIRO_DOCK_ICON_TYPE_IS_APPLET (icon) && /**icon->cClass != NULL &&*/ icon->pModuleInstance->pModule->pVisitCard->bActAsLauncher)  // applet acting like a launcher
-		|| (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon)))  // separator (user or auto).
+		|| (CAIRO_DOCK_ICON_TYPE_IS_APPLET (icon) && icon->pModuleInstance->pModule->pVisitCard->bActAsLauncher)  // applet acting like a launcher
+		/**|| CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon)*/)  // separator (user or auto).
 		{
-			pLastLauncher = icon;
+			// pLastLauncher = icon;
 			last_launcher_ic = ic;
 			if (pFirstLauncher == NULL)
 			{
@@ -1317,7 +1314,7 @@ void cairo_dock_set_class_order_in_dock (Icon *pIcon, CairoDock *pDock)
 		else if ((CAIRO_DOCK_ICON_TYPE_IS_APPLI (icon) || CAIRO_DOCK_ICON_TYPE_IS_CLASS_CONTAINER (icon))
 		&& ! cairo_dock_class_is_inhibited (icon->cClass))  // an appli not placed next to its inhibitor.
 		{
-			pFirstAppli = icon;
+			// pFirstAppli = icon;
 			first_appli_ic = ic;
 			break ;
 		}
@@ -1388,8 +1385,10 @@ void cairo_dock_set_class_order_amongst_applis (Icon *pIcon, CairoDock *pDock)
 	g_return_if_fail (pClassAppli != NULL);
 	
 	// place the icon amongst the other appli icons of this class, or after the last appli if none.
-	pIcon->iGroup = CAIRO_DOCK_APPLI;
-	Icon *pSameClassIcon = NULL;
+	if (myTaskbarParam.bSeparateApplis)
+		pIcon->iGroup = CAIRO_DOCK_APPLI;
+	else
+		pIcon->iGroup = CAIRO_DOCK_LAUNCHER;
 	Icon *icon;
 	GList *ic, *last_ic = NULL, *first_appli_ic = NULL;
 	GList *last_launcher_ic = NULL, *first_launcher_ic = NULL;
@@ -1616,7 +1615,11 @@ static gchar *_search_desktop_file (const gchar *cDesktopFile)  // file, path or
 				g_string_printf (sDesktopFilePath, "/usr/share/applications/kde4/%s", cFileName);
 				if (! g_file_test (sDesktopFilePath->str, G_FILE_TEST_EXISTS))
 				{
-					bFound = FALSE;
+					g_string_printf (sDesktopFilePath, "%s/.local/share/applications/%s", g_getenv ("HOME"), cFileName);
+					if (! g_file_test (sDesktopFilePath->str, G_FILE_TEST_EXISTS))
+					{
+						bFound = FALSE;
+					}
 				}
 			}
 		}
@@ -1770,6 +1773,48 @@ gchar *cairo_dock_guess_class (const gchar *cCommand, const gchar *cStartupWMCla
 	return cResult;
 }
 
+static void _add_action_menus (GKeyFile *pKeyFile, CairoDockClassAppli *pClassAppli, const gchar *cGettextDomain, const gchar *cMenuListKey, const gchar *cMenuGroup, gboolean bActionFirstInGroupKey)
+{
+	gsize length = 0;
+	gchar **pMenuList = g_key_file_get_string_list (pKeyFile, "Desktop Entry", cMenuListKey, &length, NULL);  
+	if (pMenuList != NULL)
+	{
+		gchar *cGroup;
+		int i;
+		for (i = 0; pMenuList[i] != NULL; i++)
+		{
+			cGroup = g_strdup_printf ("%s %s",
+				bActionFirstInGroupKey ? pMenuList[i] : cMenuGroup,   // [NewWindow Shortcut Group]
+				bActionFirstInGroupKey ? cMenuGroup : pMenuList [i]); // [Desktop Action NewWindow]
+
+			if (g_key_file_has_group (pKeyFile, cGroup))
+			{
+				gchar **pMenuItem = g_new0 (gchar*, 4);
+				// for a few apps, the translations are directly available in the .desktop file (e.g. firefox)
+				gchar *cName = g_key_file_get_locale_string (pKeyFile, cGroup, "Name", NULL, NULL);
+				pMenuItem[0] = g_strdup (dgettext (cGettextDomain, cName)); // but most of the time, it's available in the .mo file
+				g_free (cName);
+				gchar *cCommand = g_key_file_get_string (pKeyFile, cGroup, "Exec", NULL);
+				if (cCommand != NULL)  // remove the launching options %x.
+				{
+					gchar *str = strchr (cCommand, '%');  // search the first one.
+					if (str != NULL)
+					{
+						if (str != cCommand && (*(str-1) == '"' || *(str-1) == '\''))  // take care of "" around the option.
+							str --;
+						*str = '\0';  // il peut rester un espace en fin de chaine, ce n'est pas grave.
+					}
+				}
+				pMenuItem[1] = cCommand;
+				pMenuItem[2] = g_key_file_get_string (pKeyFile, cGroup, "Icon", NULL);
+				
+				pClassAppli->pMenuItems = g_list_append (pClassAppli->pMenuItems, pMenuItem);
+			}
+			g_free (cGroup);
+		}
+		g_strfreev (pMenuList);
+	}
+}
 
 /*
 register from desktop-file name/path (+class-name):
@@ -1868,10 +1913,22 @@ gchar *cairo_dock_register_class_full (const gchar *cDesktopFile, const gchar *c
 	//\__________________ get the attributes.
 	pClassAppli->cDesktopFile = cDesktopFilePath;
 	
+	pClassAppli->cName = g_key_file_get_locale_string (pKeyFile, "Desktop Entry", "Name", NULL, NULL);
+	
 	if (cCommand != NULL)  // remove the launching options %x.
 	{
 		gchar *str = strchr (cCommand, '%');  // search the first one.
-		if (str != NULL)
+		
+		if (str && *(str+1) == 'c')  // this one (caption) is the only one that is expected (ex.: kreversi -caption "%c"; if we let '-caption' with nothing after, the appli will melt down); others are either URL or icon that can be empty as per the freedesktop specs, so we can sefely remove them completely from the command line.
+		{
+			*str = '\0';
+			gchar *cmd2 = g_strdup_printf ("%s%s%s", cCommand, pClassAppli->cName, str+2);  // replace %c with the localized name.
+			g_free (cCommand);
+			cCommand = cmd2;
+			str = strchr (cCommand, '%');  // jump to the next one.
+		}
+		
+		if (str != NULL)  // remove everything from the first option to the end.
 		{
 			if (str != cCommand && (*(str-1) == '"' || *(str-1) == '\''))  // take care of "" around the option.
 				str --;
@@ -1883,8 +1940,6 @@ gchar *cairo_dock_register_class_full (const gchar *cDesktopFile, const gchar *c
 	if (pClassAppli->cStartupWMClass == NULL)
 		pClassAppli->cStartupWMClass = (cStartupWMClass ? cStartupWMClass : g_strdup (cWmClass));
 	
-	pClassAppli->cName = g_key_file_get_locale_string (pKeyFile, "Desktop Entry", "Name", NULL, NULL);
-	
 	pClassAppli->cIcon = g_key_file_get_string (pKeyFile, "Desktop Entry", "Icon", NULL);
 	if (pClassAppli->cIcon != NULL && *pClassAppli->cIcon != '/')  // remove any extension.
 	{
@@ -1897,40 +1952,19 @@ gchar *cairo_dock_register_class_full (const gchar *cDesktopFile, const gchar *c
 	pClassAppli->pMimeTypes = g_key_file_get_string_list (pKeyFile, "Desktop Entry", "MimeType", &length, NULL);
 	
 	pClassAppli->cWorkingDirectory = g_key_file_get_string (pKeyFile, "Desktop Entry", "Path", NULL);
-	
-	// get the Unity menus.
-	gchar **pMenuList = g_key_file_get_string_list (pKeyFile, "Desktop Entry", "X-Ayatana-Desktop-Shortcuts", &length, NULL);  // oh crap, with a name like that you can be sure it will change 25 times before they decide a definite name :-/
-	if (pMenuList != NULL)
-	{
-		gchar *cGroup;
-		int i;
-		for (i = 0; pMenuList[i] != NULL; i++)
-		{
-			cGroup = g_strdup_printf ("%s Shortcut Group", pMenuList[i]);
-			if (g_key_file_has_group (pKeyFile, cGroup))
-			{
-				gchar **pMenuItem = g_new0 (gchar*, 4);
-				pMenuItem[0] = g_key_file_get_locale_string (pKeyFile, cGroup, "Name", NULL, NULL);
-				cCommand = g_key_file_get_string (pKeyFile, cGroup, "Exec", NULL);
-				if (cCommand != NULL)  // remove the launching options %x.
-				{
-					gchar *str = strchr (cCommand, '%');  // search the first one.
-					if (str != NULL)
-					{
-						if (str != cCommand && (*(str-1) == '"' || *(str-1) == '\''))  // take care of "" around the option.
-							str --;
-						*str = '\0';  // il peut rester un espace en fin de chaine, ce n'est pas grave.
-					}
-				}
-				pMenuItem[1] = cCommand;
-				pMenuItem[2] = g_key_file_get_string (pKeyFile, cGroup, "Icon", NULL);
-				
-				pClassAppli->pMenuItems = g_list_append (pClassAppli->pMenuItems, pMenuItem);
-			}
-			g_free (cGroup);
-		}
-		g_strfreev (pMenuList);
-	}
+
+	//\__________________ Gettext domain
+	// The translations of the quicklist menus are generally available in a .mo file
+	gchar *cGettextDomain = g_key_file_get_string (pKeyFile, "Desktop Entry", "X-Ubuntu-Gettext-Domain", NULL);
+	if (cGettextDomain == NULL)
+		cGettextDomain = g_key_file_get_string (pKeyFile, "Desktop Entry", "X-GNOME-Gettext-Domain", NULL); // Yes, they like doing that :P
+		// a few time ago, it seems that it was 'X-Gettext-Domain'
+
+	//______________ Quicklist menus.
+	_add_action_menus (pKeyFile, pClassAppli, cGettextDomain, "X-Ayatana-Desktop-Shortcuts", "Shortcut Group", TRUE); // oh crap, with a name like that you can be sure it will change 25 times before they decide a definite name :-/
+	_add_action_menus (pKeyFile, pClassAppli, cGettextDomain, "Actions", "Desktop Action", FALSE); // yes, it's true ^^ => Ubuntu Quantal
+
+	g_free (cGettextDomain);
 	
 	g_key_file_free (pKeyFile);
 	cd_debug (" -> class '%s'", cClass);
