@@ -37,36 +37,15 @@ static char DES_crypt_key[64] =
 }; 
 #endif
 
-#include "cairo-dock-draw.h"
-#include "cairo-dock-draw-opengl.h"
-#include "cairo-dock-image-buffer.h"
-#include "cairo-dock-icon-manager.h"  // cairo_dock_hide_show_launchers_on_other_desktops
-#include "cairo-dock-icon-factory.h"
-#include "cairo-dock-icon-facility.h"
-#include "cairo-dock-applications-manager.h"
-#include "cairo-dock-module-factory.h"
-#include "cairo-dock-keyfile-utilities.h"
-#include "cairo-dock-dock-factory.h"
-#include "cairo-dock-themes-manager.h"
-#include "cairo-dock-backends-manager.h"
-#include "cairo-dock-callbacks.h"
-#include "cairo-dock-dialog-manager.h"
-#include "cairo-dock-X-utilities.h"
 #include "cairo-dock-log.h"
-#include "cairo-dock-keybinder.h"
-#include "cairo-dock-dock-manager.h"
-#include "cairo-dock-surface-factory.h"
-#include "cairo-dock-class-manager.h"
-#include "cairo-dock-gui-manager.h"
-#include "cairo-dock-desklet-manager.h"
-#include "cairo-dock-container.h"
-#include "cairo-dock-dock-facility.h"
-#include "cairo-dock-file-manager.h"
-#include "cairo-dock-animations.h"
-#include "cairo-dock-launcher-manager.h"
-#include "cairo-dock-indicator-manager.h"
-#include "cairo-dock-X-manager.h"
-#include "cairo-dock-core.h"
+#include "cairo-dock-icon-manager.h"  // cairo_dock_hide_show_launchers_on_other_desktops
+#include "cairo-dock-applications-manager.h"  // cairo_dock_start_applications_manager
+#include "cairo-dock-module-factory.h"  // cairo_dock_activate_modules_from_list
+#include "cairo-dock-keyfile-utilities.h"  // cairo_dock_update_conf_file
+#include "cairo-dock-dock-manager.h"  // cairo_dock_create_dock
+#include "cairo-dock-file-manager.h"  // cairo_dock_get_file_size
+#include "cairo-dock-launcher-manager.h"  // cairo_dock_load_launchers_from_dir
+#include "cairo-dock-core.h"  // gldi_free_all
 #include "cairo-dock-config.h"
 
 gboolean g_bEasterEggs = FALSE;
@@ -75,8 +54,6 @@ extern gchar *g_cCurrentLaunchersPath;
 extern gchar *g_cConfFile;
 extern gboolean g_bUseOpenGL;
 extern CairoDockDesktopEnv g_iDesktopEnv;
-//extern CairoDockHidingEffect *g_pHidingBackend;
-//extern CairoDockHidingEffect *g_pKeepingBelowBackend;
 extern CairoDockDesktopBackground *g_pFakeTransparencyDesktopBg;
 
 static gboolean s_bLoading = FALSE;
@@ -549,16 +526,16 @@ void cairo_dock_decrypt_string( const gchar *cEncryptedString,  gchar **cDecrypt
 		return;
 	}
 #ifdef HAVE_LIBCRYPT
-	guchar *input = g_strdup(cEncryptedString);
+	guchar *input = (guchar *)g_strdup (cEncryptedString);
 	guchar *shifted_input = input;
 	guchar **output = (guchar **)cDecryptedString;
 	
 	guchar *current_output = NULL;
 	
-	*output = g_malloc( (strlen(input)+1)/3+1 );
+	*output = g_malloc( (strlen((char *)input)+1)/3+1 );
 	current_output = *output;
 
-  guchar *last_char_in_input = input + strlen(input);
+  guchar *last_char_in_input = input + strlen((char *)input);
 //  g_print( "Password (before decrypt): %s\n", input );
 
   for( ; shifted_input < last_char_in_input; shifted_input += 16+8, current_output += 8 )
@@ -566,13 +543,12 @@ void cairo_dock_decrypt_string( const gchar *cEncryptedString,  gchar **cDecrypt
     guint block[8];
     guchar txt[64];
     gint i = 0, j = 0;
-    guchar current_letter = 0;
     
     memset( txt, 0, 64 );
 
     shifted_input[16+8-1] = 0; // cut the string
 
-    sscanf( shifted_input, "%X-%X-%X-%X-%X-%X-%X-%X",
+    sscanf( (char *)shifted_input, "%X-%X-%X-%X-%X-%X-%X-%X",
     &block[0], &block[1], &block[2], &block[3], &block[4], &block[5], &block[6], &block[7] );
 
     // process the eight first characters of "input"
@@ -581,7 +557,7 @@ void cairo_dock_decrypt_string( const gchar *cEncryptedString,  gchar **cDecrypt
         txt[i*8+j] = block[i] >> j & 1;
     
     setkey( DES_crypt_key );
-    encrypt( txt, 1 );  // decrypt
+    encrypt( (gchar *)txt, 1 );  // decrypt
 
     for ( i = 0; i < 8; i++ )
     {
@@ -616,15 +592,14 @@ void cairo_dock_encrypt_string( const gchar *cDecryptedString,  gchar **cEncrypt
 #ifdef HAVE_LIBCRYPT
 	const guchar *input = (guchar *)cDecryptedString;
 	guchar **output = (guchar **)cEncryptedString;
-	guint input_length = 0;
 	
 	guchar *current_output = NULL;
 	// for each block of 8 characters, we need 24 bytes.
-	guint nbBlocks = strlen(input)/8+1;
+	guint nbBlocks = strlen((char *)input)/8+1;
 	*output = g_malloc( nbBlocks*24+1 );
 	current_output = *output;
 
-  const guchar *last_char_in_input = input + strlen(input);
+  const guchar *last_char_in_input = input + strlen((char *)input);
 
 //  g_print( "Password (before encrypt): %s\n", input );
 
@@ -637,12 +612,12 @@ void cairo_dock_encrypt_string( const gchar *cDecryptedString,  gchar **cEncrypt
     memset( txt, 0, 64 );
     
     // process the eight first characters of "input"
-    for( i = 0; i < strlen(input) && i < 8 ; i++ )
+    for( i = 0; i < strlen((char *)input) && i < 8 ; i++ )
       for ( j = 0; j < 8; j++ )
         txt[i*8+j] = input[i] >> j & 1;
     
     setkey( DES_crypt_key );
-    encrypt( txt, 0 );  // encrypt
+    encrypt( (char *)txt, 0 );  // encrypt
 
     for ( i = 0; i < 8; i++ )
     {
@@ -651,7 +626,7 @@ void cairo_dock_encrypt_string( const gchar *cDecryptedString,  gchar **cEncrypt
       {
         current_letter |= txt[i*8+j] << j;
       }
-      snprintf( current_output + i*3, 4, "%02X-", current_letter );
+      snprintf( (char *)current_output + i*3, 4, "%02X-", current_letter );
     }
   }
 
