@@ -22,6 +22,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 
+#include <math.h>
 #include <cairo.h>
 
 #include <GL/gl.h> 
@@ -57,6 +58,7 @@ extern CairoDockDesktopGeometry g_desktopGeometry;  // _place_menu_on_icon
 
 // private
 static gboolean s_bSticky = TRUE;
+static gboolean s_bInitialOpacity0 = TRUE;  // set initial window opacity to 0, to avoid grey rectangles.
 
 
 void cairo_dock_set_containers_non_sticky (void)
@@ -69,10 +71,20 @@ void cairo_dock_set_containers_non_sticky (void)
 	s_bSticky = FALSE;
 }
 
-
-static gboolean _prevent_delete (GtkWidget *pWidget, GdkEvent *event, gpointer data)
+void cairo_dock_disable_containers_opacity (void)
 {
-	cd_debug ("pas de alt+f4");
+	if (g_pPrimaryContainer != NULL)
+	{
+		cd_warning ("this function has to be called before any container is created.");
+		return;
+	}
+	s_bInitialOpacity0 = FALSE;
+}
+
+
+static gboolean _prevent_delete (G_GNUC_UNUSED GtkWidget *pWidget, G_GNUC_UNUSED GdkEvent *event, G_GNUC_UNUSED gpointer data)
+{
+	cd_debug ("No alt+f4");
 	return TRUE;  // on empeche les ALT+F4 malheureux.
 }
 
@@ -126,9 +138,9 @@ static gboolean _cairo_default_container_animation_loop (CairoContainer *pContai
 
 static gboolean _set_opacity (GtkWidget *pWidget,
 #if (GTK_MAJOR_VERSION < 3)
-	GdkEventExpose *pExpose,
+	G_GNUC_UNUSED GdkEventExpose *pExpose,
 #else
-	cairo_t *ctx,
+	G_GNUC_UNUSED cairo_t *ctx,
 #endif
 	CairoContainer *pContainer)
 {
@@ -176,15 +188,18 @@ GtkWidget *cairo_dock_init_container_full (CairoContainer *pContainer, gboolean
 	if (s_bSticky)
 		gtk_window_stick (GTK_WINDOW (pWindow));
 	// set the opacity to 0 to avoid seeing grey rectangles until the window is ready to be painted by us.
-	gtk_window_set_opacity (GTK_WINDOW (pWindow), 0.);
-	g_signal_connect (G_OBJECT (pWindow),
-		#if (GTK_MAJOR_VERSION < 3)
-		"expose-event",
-		#else
-		"draw",
-		#endif
-		G_CALLBACK (_set_opacity),
-		pContainer);  // the callback will be removed once it has done its job.
+	if (s_bInitialOpacity0)
+	{
+		gtk_window_set_opacity (GTK_WINDOW (pWindow), 0.);
+		g_signal_connect (G_OBJECT (pWindow),
+			#if (GTK_MAJOR_VERSION < 3)
+			"expose-event",
+			#else
+			"draw",
+			#endif
+			G_CALLBACK (_set_opacity),
+			pContainer);  // the callback will be removed once it has done its job.
+	}
 	
 	// needed since gtk+-3.0 but it's possible that this resize grip has been backported to gtk+-2.0 (e.g. in Ubuntu Natty...)
 	#if (GTK_MAJOR_VERSION >= 3 || ENABLE_GTK_GRIP == 1)
@@ -269,7 +284,6 @@ void cairo_dock_redraw_icon (Icon *icon, CairoContainer *pContainer)
 }
 
 
-
 static gboolean _cairo_dock_search_icon_in_desklet (CairoDesklet *pDesklet, Icon *icon)
 {
 	if (pDesklet->icons != NULL)
@@ -306,9 +320,9 @@ CairoContainer *cairo_dock_search_container_from_icon (Icon *icon)
 
 void cairo_dock_allow_widget_to_receive_data (GtkWidget *pWidget, GCallback pCallBack, gpointer data)
 {
-	/*GtkTargetEntry pTargetEntry[6] = {0};
-	pTargetEntry[0].target = (gchar*)"text/*";
-	pTargetEntry[0].flags = (GtkTargetFlags) 0;
+	// /*GtkTargetEntry pTargetEntry[6] = {0};
+	// pTargetEntry[0].target = (gchar*)"text/*";
+	/* pTargetEntry[0].flags = (GtkTargetFlags) 0;
 	pTargetEntry[0].info = 0;
 	pTargetEntry[1].target = (gchar*)"text/uri-list";
 	pTargetEntry[2].target = (gchar*)"text/plain";
