@@ -68,11 +68,11 @@ static void on_drag_data_received_desklet (GtkWidget *pWidget, GdkDragContext *d
  /// SIGNALS ///
 ///////////////
 
-static gboolean on_expose_desklet(GtkWidget *pWidget,
+static gboolean on_expose_desklet(G_GNUC_UNUSED GtkWidget *pWidget,
 #if (GTK_MAJOR_VERSION < 3)
-	GdkEventExpose *pExpose,
+	G_GNUC_UNUSED GdkEventExpose *pExpose,
 #else
-	cairo_t *ctx,
+	G_GNUC_UNUSED cairo_t *ctx,
 #endif
 	CairoDesklet *pDesklet)
 {
@@ -152,7 +152,7 @@ static gboolean _cairo_dock_write_desklet_size (CairoDesklet *pDesklet)
 		pDesklet->iDesiredWidth = 0;
 		pDesklet->iDesiredHeight = 0;
 		
-		cairo_dock_load_desklet_decorations (pDesklet);
+		cairo_dock_load_desklet_decorations (pDesklet);  // reload the decorations at the new desklet size.
 		
 		if (pDesklet->pIcon != NULL && pDesklet->pIcon->pModuleInstance != NULL)
 		{
@@ -170,7 +170,7 @@ static gboolean _cairo_dock_write_desklet_size (CairoDesklet *pDesklet)
 				{
 					pIcon->iImageWidth = pIcon->fWidth;
 					pIcon->iImageHeight = pIcon->fHeight;
-					if (pIcon->iImageWidth > 0)
+					if (pIcon->iImageWidth > 0)  // the view displays the main icon -> load it.
 						cairo_dock_load_icon_buffers (pIcon, CAIRO_CONTAINER (pDesklet));  // pas de trigger, car on veut pouvoir associer un contexte a l'icone principale tout de suite.
 				}
 				
@@ -264,7 +264,7 @@ static gboolean _cairo_dock_write_desklet_position (CairoDesklet *pDesklet)
 	pDesklet->iSidWritePosition = 0;
 	return FALSE;
 }
-static gboolean on_configure_desklet (GtkWidget* pWidget,
+static gboolean on_configure_desklet (G_GNUC_UNUSED GtkWidget* pWidget,
 	GdkEventConfigure* pEvent,
 	CairoDesklet *pDesklet)
 {
@@ -334,7 +334,7 @@ static gboolean on_configure_desklet (GtkWidget* pWidget,
 	return FALSE;
 }
 
-static gboolean on_scroll_desklet (GtkWidget* pWidget,
+static gboolean on_scroll_desklet (G_GNUC_UNUSED GtkWidget* pWidget,
 	GdkEventScroll* pScroll,
 	CairoDesklet *pDesklet)
 {
@@ -348,11 +348,10 @@ static gboolean on_scroll_desklet (GtkWidget* pWidget,
 }
 
 static gboolean on_unmap_desklet (GtkWidget* pWidget,
-	GdkEvent *pEvent,
+	G_GNUC_UNUSED GdkEvent *pEvent,
 	CairoDesklet *pDesklet)
 {
-	cd_debug ("unmap desklet (bAllowMinimize:%d)\n", pDesklet->bAllowMinimize);
-	Window Xid = gldi_container_get_Xid (CAIRO_CONTAINER (pDesklet));
+	cd_debug ("unmap desklet (bAllowMinimize:%d)", pDesklet->bAllowMinimize);
 	if (pDesklet->iVisibility == CAIRO_DESKLET_ON_WIDGET_LAYER)  // on the widget layer, let pass the unmap event..
 	//if (cairo_dock_window_is_utility (Xid))  // sur la couche des widgets, on ne fait rien.
 		return FALSE;
@@ -361,7 +360,7 @@ static gboolean on_unmap_desklet (GtkWidget* pWidget,
 		if (pDesklet->pUnmapTimer)
 		{
 			double fElapsedTime = g_timer_elapsed (pDesklet->pUnmapTimer, NULL);
-			cd_debug ("fElapsedTime : %fms\n", fElapsedTime);
+			cd_debug ("fElapsedTime : %fms", fElapsedTime);
 			g_timer_destroy (pDesklet->pUnmapTimer);
 			pDesklet->pUnmapTimer = NULL;
 			if (fElapsedTime < .2)
@@ -378,7 +377,7 @@ static gboolean on_unmap_desklet (GtkWidget* pWidget,
 	return TRUE;  // stops other handlers from being invoked for the event.
 }
 
-static gboolean on_button_press_desklet(GtkWidget *pWidget,
+static gboolean on_button_press_desklet(G_GNUC_UNUSED GtkWidget *pWidget,
 	GdkEventButton *pButton,
 	CairoDesklet *pDesklet)
 {
@@ -450,7 +449,7 @@ static gboolean on_button_press_desklet(GtkWidget *pWidget,
 					Icon *icon = pDesklet->pIcon;
 					g_return_val_if_fail (CAIRO_DOCK_IS_APPLET (icon), FALSE);
 					pDesklet->bNoInput = ! pDesklet->bNoInput;
-					cd_debug ("no input : %d (%s)\n", pDesklet->bNoInput, icon->pModuleInstance->cConfFilePath);
+					cd_debug ("no input : %d (%s)", pDesklet->bNoInput, icon->pModuleInstance->cConfFilePath);
 					cairo_dock_update_conf_file (icon->pModuleInstance->cConfFilePath,
 						G_TYPE_BOOLEAN, "Desklet", "no input", pDesklet->bNoInput,
 						G_TYPE_INVALID);
@@ -542,7 +541,7 @@ static gboolean on_button_press_desklet(GtkWidget *pWidget,
 	return FALSE;
 }
 
-static void on_drag_data_received_desklet (GtkWidget *pWidget, GdkDragContext *dc, gint x, gint y, GtkSelectionData *selection_data, guint info, guint t, CairoDesklet *pDesklet)
+static void on_drag_data_received_desklet (G_GNUC_UNUSED GtkWidget *pWidget, G_GNUC_UNUSED GdkDragContext *dc, gint x, gint y, GtkSelectionData *selection_data, G_GNUC_UNUSED guint info, G_GNUC_UNUSED guint t, CairoDesklet *pDesklet)
 {
 	//g_print ("%s (%dx%d)\n", __func__, x, y);
 	
@@ -647,8 +646,8 @@ static gboolean on_motion_notify_desklet (GtkWidget *pWidget,
 }
 
 
-static gboolean on_focus_in_out_desklet(GtkWidget *widget,
-	GdkEventFocus *event,
+static gboolean on_focus_in_out_desklet(G_GNUC_UNUSED GtkWidget *widget,
+	G_GNUC_UNUSED GdkEventFocus *event,
 	CairoDesklet *pDesklet)
 {
 	gtk_widget_queue_draw(pDesklet->container.pWidget);
@@ -656,7 +655,7 @@ static gboolean on_focus_in_out_desklet(GtkWidget *widget,
 }
 
 static gboolean on_enter_desklet (GtkWidget* pWidget,
-	GdkEventCrossing* pEvent,
+	G_GNUC_UNUSED GdkEventCrossing* pEvent,
 	CairoDesklet *pDesklet)
 {
 	//g_print ("%s (%d)\n", __func__, pDesklet->container.bInside);
@@ -838,7 +837,7 @@ void cairo_dock_free_desklet (CairoDesklet *pDesklet)
 {
 	if (pDesklet == NULL)
 		return;
-
+	
 	if (pDesklet->iSidWriteSize != 0)
 		g_source_remove (pDesklet->iSidWriteSize);
 	if (pDesklet->iSidWritePosition != 0)
@@ -921,12 +920,12 @@ void cairo_dock_configure_desklet (CairoDesklet *pDesklet, CairoDeskletAttribute
 			
 			int iCurrentDesktop, iCurrentViewportX, iCurrentViewportY;
 			cairo_dock_get_current_desktop_and_viewport (&iCurrentDesktop, &iCurrentViewportX, &iCurrentViewportY);
-			cd_debug (">>> on fixe le desklet sur le bureau (%d,%d,%d) (cur : %d,%d,%d)\n", iNumDesktop, iNumViewportX, iNumViewportY, iCurrentDesktop, iCurrentViewportX, iCurrentViewportY);
+			cd_debug (">>> on fixe le desklet sur le bureau (%d,%d,%d) (cur : %d,%d,%d)", iNumDesktop, iNumViewportX, iNumViewportY, iCurrentDesktop, iCurrentViewportX, iCurrentViewportY);
 			
 			iNumViewportX -= iCurrentViewportX;
 			iNumViewportY -= iCurrentViewportY;
 			
-			cd_debug ("on le place en %d + %d\n", iNumViewportX * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL], iAbsolutePositionX);
+			cd_debug ("on le place en %d + %d", iNumViewportX * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL], iAbsolutePositionX);
 			cairo_dock_move_xwindow_to_absolute_position (Xid, iNumDesktop, iNumViewportX * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] + iAbsolutePositionX, iNumViewportY * g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] + iAbsolutePositionY);
 		}
 	}
@@ -1113,7 +1112,7 @@ void cairo_dock_zoom_out_desklet (CairoDesklet *pDesklet)
 
 static void _cairo_dock_reserve_space_for_desklet (CairoDesklet *pDesklet, gboolean bReserve)
 {
-	cd_debug ("%s (%d)\n", __func__, bReserve);
+	cd_debug ("%s (%d)", __func__, bReserve);
 	Window Xid = gldi_container_get_Xid (CAIRO_CONTAINER (pDesklet));
 	int left=0, right=0, top=0, bottom=0;
 	int left_start_y=0, left_end_y=0, right_start_y=0, right_end_y=0, top_start_x=0, top_end_x=0, bottom_start_x=0, bottom_end_x=0;
@@ -1299,4 +1298,5 @@ gboolean cairo_dock_detach_icon_from_desklet (Icon *icon, CairoDesklet *pDesklet
 	
 	// calculate icons
 	cairo_dock_update_desklet_icons (pDesklet);
+	return TRUE;
 }
