@@ -54,7 +54,7 @@ extern CairoDockDesktopGeometry g_desktopGeometry;
 extern gboolean g_bUseOpenGL;
 extern CairoDockHidingEffect *g_pHidingBackend;  // cairo_dock_is_hidden
 
-#define _drawn_text_width(pDialog) (pDialog->iMaxTextWidth != 0 && pDialog->iTextWidth > pDialog->iMaxTextWidth ? pDialog->iMaxTextWidth : pDialog->iTextWidth)
+#define _drawn_text_width(pDialog) (pDialog)->iTextWidth
 
 static void _cairo_dock_compute_dialog_sizes (CairoDialog *pDialog)
 {
@@ -81,7 +81,7 @@ static void _cairo_dock_compute_dialog_sizes (CairoDialog *pDialog)
 	pDialog->container.iHeight = pDialog->iComputedHeight;
 }
 
-static gboolean on_expose_dialog (GtkWidget *pWidget,
+static gboolean on_expose_dialog (G_GNUC_UNUSED GtkWidget *pWidget,
 #if (GTK_MAJOR_VERSION < 3)
 	GdkEventExpose *pExpose,
 #else
@@ -90,9 +90,9 @@ static gboolean on_expose_dialog (GtkWidget *pWidget,
 	CairoDialog *pDialog)
 {
 	//g_print ("%s (%dx%d ; %d;%d)\n", __func__, pDialog->container.iWidth, pDialog->container.iHeight, pExpose->area.x, pExpose->area.y);
-	int x, y;
+	/* int x, y;
 	// OpenGL renderers are not ready for dialogs.
-	/*if (g_bUseOpenGL && (pDialog->pDecorator == NULL || pDialog->pDecorator->render_opengl != NULL) && (pDialog->pRenderer == NULL || pDialog->pRenderer->render_opengl != NULL))
+	if (g_bUseOpenGL && (pDialog->pDecorator == NULL || pDialog->pDecorator->render_opengl != NULL) && (pDialog->pRenderer == NULL || pDialog->pRenderer->render_opengl != NULL))
 	{
 		if (! gldi_glx_begin_draw_container (CAIRO_CONTAINER (pDialog)))
 			return FALSE;
@@ -175,7 +175,7 @@ static void _cairo_dock_set_dialog_input_shape (CairoDialog *pDialog)
 	gldi_container_set_input_shape (CAIRO_CONTAINER (pDialog), pDialog->pShapeBitmap);
 }
 
-static gboolean on_configure_dialog (GtkWidget* pWidget,
+static gboolean on_configure_dialog (G_GNUC_UNUSED GtkWidget* pWidget,
 	GdkEventConfigure* pEvent,
 	CairoDialog *pDialog)
 {
@@ -245,7 +245,7 @@ static gboolean on_configure_dialog (GtkWidget* pWidget,
 }
 
 static gboolean on_unmap_dialog (GtkWidget* pWidget,
-	GdkEvent *pEvent,
+	G_GNUC_UNUSED GdkEvent *pEvent,
 	CairoDialog *pDialog)
 {
 	//g_print ("unmap dialog (bAllowMinimize:%d, visible:%d)\n", pDialog->bAllowMinimize, GTK_WIDGET_VISIBLE (pWidget));
@@ -359,15 +359,18 @@ static CairoDialog *_cairo_dock_create_empty_dialog (gboolean bInteractive)
 	return pDialog;
 }
 
-static cairo_surface_t *_cairo_dock_create_dialog_text_surface (const gchar *cText, CairoDockLabelDescription *pTextDescription, int *iTextWidth, int *iTextHeight)
+static cairo_surface_t *_cairo_dock_create_dialog_text_surface (const gchar *cText, gboolean bUseMarkup, int *iTextWidth, int *iTextHeight)
 {
 	if (cText == NULL)
 		return NULL;
 	
-	return cairo_dock_create_surface_from_text (cText,
-		(pTextDescription ? pTextDescription : &myDialogsParam.dialogTextDescription),
+	myDialogsParam.dialogTextDescription.bUseMarkup = bUseMarkup;  // slight optimization, rather than duplicating the TextDescription each time.
+	cairo_surface_t *pSurface = cairo_dock_create_surface_from_text (cText,
+		&myDialogsParam.dialogTextDescription,
 		iTextWidth,
 		iTextHeight);
+	myDialogsParam.dialogTextDescription.bUseMarkup = FALSE;  // by default
+	return pSurface;
 }
 
 static cairo_surface_t *_cairo_dock_create_dialog_icon_surface (const gchar *cImageFilePath, int iNbFrames, Icon *pIcon, CairoContainer *pContainer, int iDesiredSize, int *iIconSize)
@@ -416,17 +419,7 @@ static gboolean _cairo_dock_animate_dialog_icon (CairoDialog *pDialog)
 	cairo_dock_damage_icon_dialog (pDialog);
 	return TRUE;
 }
-static gboolean _cairo_dock_animate_dialog_text (CairoDialog *pDialog)
-{
-	if (pDialog->iTextWidth <= pDialog->iMaxTextWidth)
-		return FALSE;
-	pDialog->iCurrentTextOffset += 3;
-	if (pDialog->iCurrentTextOffset >= pDialog->iTextWidth)
-		pDialog->iCurrentTextOffset -= pDialog->iTextWidth;
-	cairo_dock_damage_text_dialog (pDialog);
-	return TRUE;
-}
-static gboolean on_button_press_widget (GtkWidget *widget,
+static gboolean on_button_press_widget (G_GNUC_UNUSED GtkWidget *widget,
 	GdkEventButton *pButton,
 	CairoDialog *pDialog)
 {
@@ -435,6 +428,12 @@ static gboolean on_button_press_widget (GtkWidget *widget,
 	pDialog->iButtonPressTime = pButton->time;
 	return FALSE;
 }
+static void _force_above (G_GNUC_UNUSED GtkWidget *pWidget, CairoDialog *pDialog)
+{
+	gtk_window_set_keep_above (GTK_WINDOW (pDialog->container.pWidget), TRUE);
+	Window Xid = gldi_container_get_Xid (CAIRO_CONTAINER (pDialog));
+	cairo_dock_set_xwindow_type_hint (Xid, "_NET_WM_WINDOW_TYPE_DOCK");  // pour passer devant les fenetres plein ecran; depend du WM.
+}
 CairoDialog *cairo_dock_new_dialog (CairoDialogAttribute *pAttribute, Icon *pIcon, CairoContainer *pContainer)
 {
 	//\________________ On cree un nouveau dialogue.
@@ -443,24 +442,21 @@ CairoDialog *cairo_dock_new_dialog (CairoDialogAttribute *pAttribute, Icon *pIco
 	pDialog->container.bIsHorizontal = TRUE;
 	if (pAttribute->bForceAbove)
 	{
-		gtk_window_set_keep_above (GTK_WINDOW (pDialog->container.pWidget), TRUE);
-		Window Xid = gldi_container_get_Xid (CAIRO_CONTAINER (pDialog));
-		cairo_dock_set_xwindow_type_hint (Xid, "_NET_WM_WINDOW_TYPE_DOCK");  // pour passer devant les fenetres plein ecran; depend du WM.
+		g_signal_connect (G_OBJECT (pDialog->container.pWidget),
+			"realize",
+			G_CALLBACK (_force_above),
+			pDialog);  // gtk_widget_get_window() returns NULL until the window is realized.
 	}
 	
 	//\________________ On cree la surface du message.
 	if (pAttribute->cText != NULL)
 	{
-		pDialog->iMaxTextWidth = pAttribute->iMaxTextWidth;
 		pDialog->pTextBuffer = _cairo_dock_create_dialog_text_surface (pAttribute->cText,
-			pAttribute->pTextDescription,
+			pAttribute->bUseMarkup,
 			&pDialog->iTextWidth, &pDialog->iTextHeight);
 		///pDialog->iTextTexture = cairo_dock_create_texture_from_surface (pDialog->pTextBuffer);
-		if (pDialog->iMaxTextWidth > 0 && pDialog->pTextBuffer != NULL && pDialog->iTextWidth > pDialog->iMaxTextWidth)
-		{
-			pDialog->iSidAnimateText = g_timeout_add (200, (GSourceFunc) _cairo_dock_animate_dialog_text, (gpointer) pDialog);  // multiple du timeout de l'icone animee.
-		}
 	}
+	pDialog->bUseMarkup = pAttribute->bUseMarkup;  // remember this attribute, in case another text is set (with cairo_dock_set_dialog_message).
 
 	//\________________ On cree la surface de l'icone a afficher sur le cote.
 	if (pAttribute->cImageFilePath != NULL)
@@ -661,10 +657,6 @@ void cairo_dock_free_dialog (CairoDialog *pDialog)
 	{
 		g_source_remove (pDialog->iSidAnimateIcon);
 	}
-	if (pDialog->iSidAnimateText > 0)
-	{
-		g_source_remove (pDialog->iSidAnimateText);
-	}
 	
 	cd_debug ("");
 
@@ -760,7 +752,10 @@ static void _cairo_dock_dialog_calculate_aimed_point (Icon *pIcon, CairoContaine
 			if (cairo_dock_is_hidden (pDock))
 			{
 				*iX = pContainer->iWindowPositionX +
-					(pIcon ? (pIcon->fXAtRest + pIcon->fWidth/2) / pDock->fFlatDockWidth * pDock->iMaxDockWidth : 0);
+					pDock->iMaxDockWidth/2
+					- pDock->fFlatDockWidth/2
+					+ pIcon->fXAtRest + pIcon->fWidth/2;
+					///(pIcon ? (pIcon->fXAtRest + pIcon->fWidth/2) / pDock->fFlatDockWidth * pDock->iMaxDockWidth : 0);
 			}
 			else
 			{
@@ -771,7 +766,6 @@ static void _cairo_dock_dialog_calculate_aimed_point (Icon *pIcon, CairoContaine
 	}
 	else if (CAIRO_DOCK_IS_DESKLET (pContainer))
 	{
-		CairoDesklet *pDesklet = CAIRO_DESKLET (pContainer);
 		*bDirectionUp = (pContainer->iWindowPositionY > g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] / 2);
 		///*bIsHorizontal = (pContainer->iWindowPositionX > 50 && pContainer->iWindowPositionX + pContainer->iHeight < g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] - 50);
 		*bIsHorizontal = TRUE;
@@ -854,7 +848,7 @@ void cairo_dock_set_dialog_widget_text_color (GtkWidget *pWidget)
 	color.red = myDialogsParam.dialogTextDescription.fColorStart[0];
 	color.green = myDialogsParam.dialogTextDescription.fColorStart[1];
 	color.blue = myDialogsParam.dialogTextDescription.fColorStart[2];
-	color.alpha = myDialogsParam.dialogTextDescription.fColorStart[3];
+	color.alpha = 1.;
 	gtk_widget_override_color (pWidget, GTK_STATE_NORMAL, &color);
 	#endif
 }
@@ -907,11 +901,6 @@ void cairo_dock_set_new_dialog_text_surface (CairoDialog *pDialog, cairo_surface
 	{
 		cairo_dock_damage_text_dialog (pDialog);
 	}
-
-	if (pDialog->iMaxTextWidth > 0 && pDialog->iSidAnimateText == 0 && pDialog->pTextBuffer != NULL && pDialog->iTextWidth > pDialog->iMaxTextWidth)
-	{
-		pDialog->iSidAnimateText = g_timeout_add (200, (GSourceFunc) _cairo_dock_animate_dialog_text, (gpointer) pDialog);  // multiple du timeout de l'icone animee.
-	}
 }
 
 void cairo_dock_set_new_dialog_icon_surface (CairoDialog *pDialog, cairo_surface_t *pNewIconSurface, int iNewIconSize)
@@ -945,7 +934,7 @@ void cairo_dock_set_new_dialog_icon_surface (CairoDialog *pDialog, cairo_surface
 void cairo_dock_set_dialog_message (CairoDialog *pDialog, const gchar *cMessage)
 {
 	int iNewTextWidth=0, iNewTextHeight=0;
-	cairo_surface_t *pNewTextSurface = _cairo_dock_create_dialog_text_surface (cMessage, NULL, &iNewTextWidth, &iNewTextHeight);
+	cairo_surface_t *pNewTextSurface = _cairo_dock_create_dialog_text_surface (cMessage, FALSE, &iNewTextWidth, &iNewTextHeight);
 	
 	cairo_dock_set_new_dialog_text_surface (pDialog, pNewTextSurface, iNewTextWidth, iNewTextHeight);
 }
