@@ -140,8 +140,8 @@ static void cairo_dock_unload_dialog_buttons (void)
 }
 
 
-static gboolean on_enter_dialog (GtkWidget* pWidget,
-	GdkEventCrossing* pEvent,
+static gboolean on_enter_dialog (G_GNUC_UNUSED GtkWidget* pWidget,
+	G_GNUC_UNUSED GdkEventCrossing* pEvent,
 	CairoDialog *pDialog)
 {
 	//cd_debug ("inside");
@@ -149,7 +149,7 @@ static gboolean on_enter_dialog (GtkWidget* pWidget,
 	return FALSE;
 }
 
-static gboolean on_leave_dialog (GtkWidget* pWidget,
+static gboolean on_leave_dialog (G_GNUC_UNUSED GtkWidget* pWidget,
 	GdkEventCrossing* pEvent,
 	CairoDialog *pDialog)
 {
@@ -170,14 +170,15 @@ static gboolean on_leave_dialog (GtkWidget* pWidget,
 	{
 		if (pIcon != NULL)
 		{
-			CairoContainer *pContainer = cairo_dock_search_container_from_icon (pIcon);
+			return FALSE;
+			/*CairoContainer *pContainer = cairo_dock_search_container_from_icon (pIcon);
 			///if (!pContainer || !pContainer->bInside)  // peut arriver dans le cas d'un dock cache possedant un dialogue. Initialement les 2 se chevauchent, il faut considerer qu'on est hors du dialogue afin de pouvoir le replacer.
 			{
 				//g_print ("en fait on est dedans\n");
 				return FALSE;
 			}
 			//else
-			//	//g_print ("leave dialog\n");
+			//	//g_print ("leave dialog\n");*/
 		}
 	}
 	
@@ -216,7 +217,7 @@ static int _cairo_dock_find_clicked_button_in_dialog (GdkEventButton* pButton, C
 	return -1;
 }
 
-static gboolean on_button_press_dialog (GtkWidget* pWidget,
+static gboolean on_button_press_dialog (G_GNUC_UNUSED GtkWidget* pWidget,
 	GdkEventButton* pButton,
 	CairoDialog *pDialog)
 {
@@ -281,7 +282,7 @@ static gboolean on_button_press_dialog (GtkWidget* pWidget,
 
 #define KEY(x) GDK_KEY_##x
 
-static gboolean on_key_press_dialog (GtkWidget *pWidget,
+static gboolean on_key_press_dialog (G_GNUC_UNUSED GtkWidget *pWidget,
 	GdkEventKey *pKey,
 	CairoDialog *pDialog)
 {
@@ -332,28 +333,8 @@ static void _cairo_dock_draw_inside_dialog_opengl (CairoDialog *pDialog, double
 			y += (pDialog->iMessageHeight - pDialog->iTextHeight) / 2;
 		
 		glBindTexture (GL_TEXTURE_2D, pDialog->iTextTexture);
-		if (pDialog->iMaxTextWidth != 0 && pDialog->iTextWidth > pDialog->iMaxTextWidth)
-		{
-			double w = MIN (pDialog->iMaxTextWidth, pDialog->iTextWidth - pDialog->iCurrentTextOffset);  // taille de la portion de texte a gauche.
-			_cairo_dock_apply_current_texture_portion_at_size_with_offset (1.*pDialog->iCurrentTextOffset/pDialog->iTextWidth, 0.,
-				1.*(pDialog->iTextWidth - pDialog->iCurrentTextOffset) / pDialog->iTextWidth, 1.,
-				w, pDialog->iTextHeight,
-				x + w/2, pDialog->container.iHeight - y - pDialog->iTextHeight/2);
-			
-			if (pDialog->iTextWidth - pDialog->iCurrentTextOffset < pDialog->iMaxTextWidth)
-			{
-				w = pDialog->iMaxTextWidth - (pDialog->iTextWidth - pDialog->iCurrentTextOffset);  // taille de la portion de texte a droite.
-				_cairo_dock_apply_current_texture_portion_at_size_with_offset (0., 0.,
-					w / pDialog->iTextWidth, 1.,
-					w, pDialog->iTextHeight,
-					x + pDialog->iMaxTextWidth - w/2, pDialog->container.iHeight - y - pDialog->iTextHeight/2);
-			}
-		}
-		else
-		{
-			_cairo_dock_apply_current_texture_at_size_with_offset (pDialog->iTextWidth, pDialog->iTextHeight,
-				x + pDialog->iTextWidth/2, pDialog->container.iHeight - y - pDialog->iTextHeight/2);
-		}
+		_cairo_dock_apply_current_texture_at_size_with_offset (pDialog->iTextWidth, pDialog->iTextHeight,
+			x + pDialog->iTextWidth/2, pDialog->container.iHeight - y - pDialog->iTextHeight/2);
 	}
 	
 	if (pDialog->pButtons != NULL)
@@ -416,31 +397,11 @@ static void _cairo_dock_draw_inside_dialog (cairo_t *pCairoContext, CairoDialog
 		y = (pDialog->container.bDirectionUp ? pDialog->iTopMargin : pDialog->container.iHeight - (pDialog->iTopMargin + pDialog->iBubbleHeight));
 		if (pDialog->iTextHeight < pDialog->iMessageHeight)  // on centre le texte.
 			y += (pDialog->iMessageHeight - pDialog->iTextHeight) / 2;
-		if (pDialog->iMaxTextWidth != 0 && pDialog->iTextWidth > pDialog->iMaxTextWidth)
-		{
-			cairo_save (pCairoContext);
-			cairo_rectangle (pCairoContext,
-				x,
-				y,
-				pDialog->iMaxTextWidth,
-				pDialog->iTextHeight);
-			cairo_clip (pCairoContext);
-		}
 		cairo_set_source_surface (pCairoContext,
 			pDialog->pTextBuffer,
-			x - pDialog->iCurrentTextOffset,
+			x,
 			y);
 		_paint_inside_dialog(pCairoContext, fAlpha);
-		
-		if (pDialog->iMaxTextWidth != 0 && pDialog->iTextWidth > pDialog->iMaxTextWidth)
-		{
-			cairo_set_source_surface (pCairoContext,
-				pDialog->pTextBuffer,
-				x - pDialog->iCurrentTextOffset + pDialog->iTextWidth + 10,
-				y);
-			_paint_inside_dialog (pCairoContext, fAlpha);
-			cairo_restore (pCairoContext);
-		}
 	}
 	
 	if (pDialog->pButtons != NULL)
@@ -471,7 +432,7 @@ static void _cairo_dock_draw_inside_dialog (cairo_t *pCairoContext, CairoDialog
 		pDialog->pRenderer->render (pCairoContext, pDialog, fAlpha);
 }
 
-static gboolean _cairo_dock_render_dialog_notification (gpointer data, CairoDialog *pDialog, cairo_t *pCairoContext)
+static gboolean _cairo_dock_render_dialog_notification (G_GNUC_UNUSED gpointer data, CairoDialog *pDialog, cairo_t *pCairoContext)
 {
 	if (pCairoContext == NULL)
 	{
@@ -617,7 +578,7 @@ CairoDialog *cairo_dock_build_dialog (CairoDialogAttribute *pAttribute, Icon *pI
 			return NULL;
 		}
 	}
-	cd_debug ("%s (%s, %s, %x, %x, %x (%x;%x))", __func__, pAttribute->cText, pAttribute->cImageFilePath, pAttribute->pInteractiveWidget, pAttribute->pActionFunc, pAttribute->pTextDescription, pIcon, pContainer);
+	cd_debug ("%s (%s, %s, %x, %x, (%x;%x))", __func__, pAttribute->cText, pAttribute->cImageFilePath, pAttribute->pInteractiveWidget, pAttribute->pActionFunc, pIcon, pContainer);
 	
 	//\________________ On cree un nouveau dialogue.
 	CairoDialog *pDialog = cairo_dock_new_dialog (pAttribute, pIcon, pContainer);
@@ -700,7 +661,7 @@ static void _cairo_dock_dialog_find_optimal_placement (CairoDialog *pDialog)
 				iXleft = pDialogOnOurWay->container.iWindowPositionX;
 				iXright = pDialogOnOurWay->container.iWindowPositionX + pDialogOnOurWay->container.iWidth;
 				if ( ((iTopY < iY && iBottomY > iY) || (iTopY >= iY && iTopY < iY + iHeight))
-					&& ((iXleft < iZoneXLeft && iXright > iZoneXLeft) || iXleft >= iZoneXLeft && iXleft < iZoneXRight) )  // intersection of the 2 rectangles.
+					&& ((iXleft < iZoneXLeft && iXright > iZoneXLeft) || (iXleft >= iZoneXLeft && iXleft < iZoneXRight)) )  // intersection of the 2 rectangles.
 				{
 					cd_debug ("  dialogue genant:  %d - %d, %d - %d", iTopY, iBottomY, iXleft, iXright);
 					if (pDialogOnOurWay->iAimedX < pDialog->iAimedX)  // this dialog is on our left.
@@ -743,7 +704,7 @@ static void cairo_dock_place_dialog (CairoDialog *pDialog, CairoContainer *pCont
 	if (pDialog->container.bInside && ! (pDialog->pInteractiveWidget || pDialog->action_on_answer))  // in the case of a modal dialog, the dialog takes the dock's events, including the "enter-event" one. So we are inside the dialog as soon as we enter the dock, and consequently, the dialog is not replaced when the dock unhides itself.
 		return;
 	
-	GdkGravity iGravity;
+	// GdkGravity iGravity;
 	if (pContainer != NULL/* && pDialog->pIcon != NULL*/)
 	{
 		cairo_dock_set_dialog_orientation (pDialog, pContainer);
@@ -763,7 +724,7 @@ static void cairo_dock_place_dialog (CairoDialog *pDialog, CairoContainer *pCont
 			pDialog->iComputedPositionY = (pDialog->container.bDirectionUp ? MAX (0, pDialog->iAimedY - pDialog->iComputedHeight) : pDialog->iAimedY + pDialog->iMinBottomGap);  // on place la bulle (et non pas la fenetre) sans faire d'optimisation.
 		}
 		
-		if (pDialog->bRight)
+		/*if (pDialog->bRight)
 		{
 			if (pDialog->container.bDirectionUp)
 				iGravity = GDK_GRAVITY_SOUTH_WEST;
@@ -776,7 +737,7 @@ static void cairo_dock_place_dialog (CairoDialog *pDialog, CairoContainer *pCont
 				iGravity = GDK_GRAVITY_SOUTH_EAST;
 			else
 				iGravity = GDK_GRAVITY_NORTH_EAST;
-		}
+		}*/
 	}
 	else  // dialogue lie a aucun container => au milieu de l'ecran courant.
 	{
@@ -784,7 +745,7 @@ static void cairo_dock_place_dialog (CairoDialog *pDialog, CairoContainer *pCont
 		pDialog->iComputedPositionX = (g_pMainDock ? g_pMainDock->iScreenOffsetX : 0) + (g_desktopGeometry.iScreenWidth [CAIRO_DOCK_HORIZONTAL] - pDialog->container.iWidth) / 2;
 		pDialog->iComputedPositionY = (g_pMainDock ? g_pMainDock->iScreenOffsetY : 0) + (g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL] - pDialog->container.iHeight) / 2;
 		
-		iGravity = GDK_GRAVITY_CENTER;
+		// iGravity = GDK_GRAVITY_CENTER;
 	}
 	
 	pDialog->bPositionForced = FALSE;
@@ -830,7 +791,7 @@ void cairo_dock_refresh_all_dialogs (gboolean bReplace)
 	}
 }
 
-static gboolean _replace_all_dialogs (gpointer data)
+static gboolean _replace_all_dialogs (G_GNUC_UNUSED gpointer data)
 {
 	cairo_dock_replace_all_dialogs ();
 	s_iSidReplaceDialogs = 0;
@@ -850,7 +811,7 @@ CairoDialog *cairo_dock_show_dialog_full (const gchar *cText, Icon *pIcon, Cairo
 {
 	if (pIcon != NULL && cairo_dock_icon_is_being_removed (pIcon))  // icone en cours de suppression.
 	{
-		cd_debug ("dialog skipped for %s (%.2f)\n", pIcon->cName, pIcon->fInsertRemoveFactor);
+		cd_debug ("dialog skipped for %s (%.2f)", pIcon->cName, pIcon->fInsertRemoveFactor);
 		return NULL;
 	}
 	
@@ -967,7 +928,7 @@ CairoDialog *cairo_dock_show_dialog_with_value (const gchar *cText, Icon *pIcon,
 
 
 
-static void _cairo_dock_get_answer_from_dialog (int iClickedButton, GtkWidget *pInteractiveWidget, gpointer *data, CairoDialog *pDialog)
+static void _cairo_dock_get_answer_from_dialog (int iClickedButton, G_GNUC_UNUSED GtkWidget *pInteractiveWidget, gpointer *data, CairoDialog *pDialog)
 {
 	cd_message ("%s (%d)", __func__, iClickedButton);
 	int *iAnswerBuffer = data[0];
@@ -980,7 +941,7 @@ static void _cairo_dock_get_answer_from_dialog (int iClickedButton, GtkWidget *p
 	if (g_main_loop_is_running (pBlockingLoop))
 		g_main_loop_quit (pBlockingLoop);
 }
-static gboolean _cairo_dock_dialog_destroyed (GtkWidget *pWidget, GdkEvent *event, GMainLoop *pBlockingLoop)
+static gboolean _cairo_dock_dialog_destroyed (GtkWidget *pWidget, G_GNUC_UNUSED GdkEvent *event, GMainLoop *pBlockingLoop)
 {
 	cd_debug ("dialogue detruit, on sort de la boucle\n");
 	gtk_window_set_modal (GTK_WINDOW (pWidget), FALSE);  /// utile ?...
@@ -988,7 +949,7 @@ static gboolean _cairo_dock_dialog_destroyed (GtkWidget *pWidget, GdkEvent *even
 		g_main_loop_quit (pBlockingLoop);
 	return FALSE;
 }
-int cairo_dock_show_dialog_and_wait (const gchar *cText, Icon *pIcon, CairoContainer *pContainer, double fTimeLength, const gchar *cIconPath, GtkWidget *pInteractiveWidget)
+int cairo_dock_show_dialog_and_wait (const gchar *cText, Icon *pIcon, CairoContainer *pContainer, G_GNUC_UNUSED double fTimeLength, const gchar *cIconPath, GtkWidget *pInteractiveWidget)
 {
 	int iClickedButton = -3;
 	GMainLoop *pBlockingLoop = g_main_loop_new (NULL, FALSE);
@@ -1022,10 +983,11 @@ int cairo_dock_show_dialog_and_wait (const gchar *cText, Icon *pIcon, CairoConta
 			cairo_dock_pop_up (CAIRO_DOCK (pContainer));
 		}*/
 		cd_debug ("debut de boucle bloquante ...\n");
+		// gdk_threads_enter has been deprecated since version 3.6 and should not be used in newly-written code. All GDK and GTK+ calls should be made from the main thread
 		GDK_THREADS_LEAVE ();
 		g_main_loop_run (pBlockingLoop);
 		GDK_THREADS_ENTER ();
-		cd_debug ("fin de boucle bloquante -> %d\n", iClickedButton);
+		cd_debug ("fin de boucle bloquante -> %d", iClickedButton);
 		/*if (myDocksParam.bPopUp && CAIRO_DOCK_IS_DOCK (pContainer))
 			cairo_dock_pop_down (CAIRO_DOCK (pContainer));*/
 		if (CAIRO_DOCK_IS_DOCK (pContainer))
