@@ -28,9 +28,6 @@
 
 #include <cairo.h>
 #include <pango/pango.h>
-#include <librsvg/rsvg.h>
-#include <librsvg/rsvg-cairo.h>
-
 
 #include <X11/extensions/Xrender.h>
 #include <X11/extensions/shape.h>
@@ -58,9 +55,9 @@
 #include "cairo-dock-indicator-manager.h"  // myIndicators.bUseClassIndic
 #include "cairo-dock-class-manager.h"
 #include "cairo-dock-animations.h"
-///#include "cairo-dock-emblem.h"
 #include "cairo-dock-X-manager.h"
 #include "cairo-dock-global-variables.h"
+#include "cairo-dock-data-renderer.h"
 #include "cairo-dock-opengl.h"
 
 #include "cairo-dock-dock-facility.h"
@@ -68,22 +65,6 @@
 extern CairoDockDesktopGeometry g_desktopGeometry;
 extern gboolean g_bUseOpenGL;  // for cairo_dock_make_preview()
 
-/**void cairo_dock_reload_reflects_in_dock (CairoDock *pDock)
-{
-	cairo_t *pCairoContext = cairo_dock_create_drawing_context_generic (CAIRO_CONTAINER (pDock));
-	Icon *icon;
-	GList *ic;
-	for (ic = pDock->icons; ic != NULL; ic = ic->next)
-	{
-		icon = ic->data;
-		if (icon->pReflectionBuffer != NULL)
-		{
-			cairo_dock_add_reflection_to_icon (icon, CAIRO_CONTAINER (pDock));
-		}
-	}
-	cairo_destroy (pCairoContext);
-}*/
-
 
 void cairo_dock_update_dock_size (CairoDock *pDock)  // iMaxIconHeight et fFlatDockWidth doivent avoir ete mis a jour au prealable.
 {
@@ -194,6 +175,8 @@ void cairo_dock_update_dock_size (CairoDock *pDock)  // iMaxIconHeight et fFlatD
 	if (iPrevMaxDockHeight == pDock->iMaxDockHeight && iPrevMaxDockWidth == pDock->iMaxDockWidth)  // if the size has changed, shapes will be updated by the "configure" callback, so we don't need to do it here; if not, we do it in case the icons define a new shape (ex.: separators in Panel view) or in case the screen edge has changed.
 	{
 		cairo_dock_update_input_shape (pDock);  // done after the icons' position is known.
+		if (pDock->container.bInside)  // if the mouse is inside, set the new input shape immediately.
+			cairo_dock_set_input_shape_active (pDock);
 	}
 	
 	if (iPrevMaxDockHeight == pDock->iMaxDockHeight && iPrevMaxDockWidth == pDock->iMaxDockWidth)  // same remark as for the input shape.
@@ -316,8 +299,6 @@ void cairo_dock_reserve_space_for_dock (CairoDock *pDock, gboolean bReserve)
 
 	if (bReserve)
 	{
-		int iWindowPositionX = pDock->container.iWindowPositionX, iWindowPositionY = pDock->container.iWindowPositionY;
-		
 		int w = pDock->iMinDockWidth;
 		int h = pDock->iMinDockHeight;
 		int x, y;  // position qu'aurait la fenetre du dock s'il avait la taille minimale.
@@ -466,18 +447,21 @@ void cairo_dock_move_resize_dock (CairoDock *pDock)
 ///////////////////
 static GldiShape *_cairo_dock_create_input_shape (CairoDock *pDock, int w, int h)
 {
-	int W = pDock->iMaxDockWidth;
+ 	int W = pDock->iMaxDockWidth;
 	int H = pDock->iMaxDockHeight;
 	if (W == 0 || H == 0)  // very unlikely to happen, but anyway avoid this case.
 	{
 		return NULL;
 	}
 	
+	double offset = (W - pDock->iActiveWidth) * pDock->fAlign + (pDock->iActiveWidth - w) / 2;
+	
 	GldiShape *pShapeBitmap;
 	if (pDock->container.bIsHorizontal)
 	{
 		pShapeBitmap = gldi_container_create_input_shape (CAIRO_CONTAINER (pDock),
-			(W - w) / 2,  // centre en x.
+			///(W - w) * pDock->fAlign,
+			offset,
 			pDock->container.bDirectionUp ? H - h : 0,
 			w,
 			h);
@@ -486,7 +470,8 @@ static GldiShape *_cairo_dock_create_input_shape (CairoDock *pDock, int w, int h
 	{
 		pShapeBitmap = gldi_container_create_input_shape (CAIRO_CONTAINER (pDock),
 			pDock->container.bDirectionUp ? H - h : 0,
-			(W - w) / 2,  // centre en x.
+			///(W - w) * pDock->fAlign,
+			offset,
 			h,
 			w);
 	}
@@ -779,7 +764,7 @@ Icon * cairo_dock_calculate_wave_with_position_linear (GList *pIconList, int x_a
 		{
 			icon = ic->data;
 			//if (ic == pIconList)
-			//	cd_debug ("fX : %.2f - %.2f\n", icon->fX, offset);
+			//	cd_debug ("fX : %.2f - %.2f", icon->fX, offset);
 			icon->fX -= offset;
 		}
 	}
@@ -791,9 +776,11 @@ Icon * cairo_dock_calculate_wave_with_position_linear (GList *pIconList, int x_a
 Icon *cairo_dock_apply_wave_effect_linear (CairoDock *pDock)
 {
 	//\_______________ On calcule la position du curseur dans le referentiel du dock a plat.
-	int dx = pDock->container.iMouseX - (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2) - pDock->container.iWidth / 2;  // ecart par rapport au milieu du dock a plat.
-	int x_abs = dx + pDock->fFlatDockWidth / 2;  // ecart par rapport a la gauche du dock minimal  plat.
+	//int dx = pDock->container.iMouseX - (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2) - pDock->container.iWidth / 2;  // ecart par rapport au milieu du dock a plat.
+	//int x_abs = dx + pDock->fFlatDockWidth / 2;  // ecart par rapport a la gauche du dock minimal  plat.
 	//g_print ("%s (flat:%d, w:%d, x:%d)\n", __func__, (int)pDock->fFlatDockWidth, pDock->container.iWidth, pDock->container.iMouseX);
+	double offset = (pDock->container.iWidth - pDock->iActiveWidth) * pDock->fAlign + (pDock->iActiveWidth - pDock->fFlatDockWidth) / 2;
+	int x_abs = pDock->container.iMouseX - offset;
 	//\_______________ On calcule l'ensemble des parametres des icones.
 	double fMagnitude = cairo_dock_calculate_magnitude (pDock->iMagnitudeIndex);  // * pDock->fMagnitudeMax
 	Icon *pPointedIcon = cairo_dock_calculate_wave_with_position_linear (pDock->icons, x_abs, fMagnitude, pDock->fFlatDockWidth, pDock->container.iWidth, pDock->container.iHeight, pDock->fAlign, pDock->fFoldingFactor, pDock->container.bDirectionUp);  // iMaxDockWidth
@@ -813,7 +800,6 @@ double cairo_dock_get_current_dock_width_linear (CairoDock *pDock)
 	return fWidth;
 }
 
-
 void cairo_dock_check_if_mouse_inside_linear (CairoDock *pDock)
 {
 	CairoDockMousePositionType iMousePositionType;
@@ -821,13 +807,15 @@ void cairo_dock_check_if_mouse_inside_linear (CairoDock *pDock)
 	///int iHeight = (pDock->fMagnitudeMax != 0 ? pDock->container.iHeight : pDock->iMinDockHeight);
 	int iHeight = pDock->iActiveHeight;
 	///int iExtraHeight = (pDock->bAtBottom ? 0 : myIconsParam.iLabelSize);
-	int iExtraHeight = 0;  /// il faudrait voir si on a un sous-dock ou un dialogue au dessus :-/
+	// int iExtraHeight = 0;  /// il faudrait voir si on a un sous-dock ou un dialogue au dessus :-/
 	int iMouseX = pDock->container.iMouseX;
 	int iMouseY = (pDock->container.bDirectionUp ? pDock->container.iHeight - pDock->container.iMouseY : pDock->container.iMouseY);
 	//g_print ("%s (%dx%d, %dx%d, %f)\n", __func__, iMouseX, iMouseY, iWidth, iHeight, pDock->fFoldingFactor);
 
 	//\_______________ On regarde si le curseur est dans le dock ou pas, et on joue sur la taille des icones en consequence.
-	int x_abs = pDock->container.iMouseX + (pDock->fFlatDockWidth - iWidth) / 2;  // abscisse par rapport a la gauche du dock minimal plat.
+	double offset = (iWidth - pDock->iActiveWidth) * pDock->fAlign + (pDock->iActiveWidth - pDock->fFlatDockWidth) / 2;
+	int x_abs = pDock->container.iMouseX - offset;
+	///int x_abs = pDock->container.iMouseX + (pDock->fFlatDockWidth - iWidth) * pDock->fAlign;  // abscisse par rapport a la gauche du dock minimal plat.
 	gboolean bMouseInsideDock = (x_abs >= 0 && x_abs <= pDock->fFlatDockWidth && iMouseX > 0 && iMouseX < iWidth);
 	//g_print ("bMouseInsideDock : %d (%d;%d/%.2f)\n", bMouseInsideDock, pDock->container.bInside, x_abs, pDock->fFlatDockWidth);
 
@@ -955,7 +943,8 @@ void cairo_dock_set_subdock_position_linear (Icon *pPointedIcon, CairoDock *pDoc
 {
 	CairoDock *pSubDock = pPointedIcon->pSubDock;
 	///int iX = pPointedIcon->fXAtRest - (pDock->fFlatDockWidth - pDock->iMaxDockWidth) / 2 + pPointedIcon->fWidth / 2 + (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2);
-	int iX = pPointedIcon->fDrawX + pPointedIcon->fWidth * pPointedIcon->fScale / 2 + (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2);
+	//int iX = pPointedIcon->fDrawX + pPointedIcon->fWidth * pPointedIcon->fScale / 2 + (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2);
+	int iX = pPointedIcon->fDrawX + pPointedIcon->fWidth * pPointedIcon->fScale / 2;
 	if (pSubDock->container.bIsHorizontal == pDock->container.bIsHorizontal)
 	{
 		pSubDock->fAlign = 0.5;
@@ -1130,6 +1119,9 @@ void cairo_dock_resize_icon_in_dock (Icon *pIcon, CairoDock *pDock)  // the requ
 	
 	cairo_dock_load_icon_image (pIcon, CAIRO_CONTAINER (pDock));  // handles the applet's context
 	
+	if (cairo_dock_get_icon_data_renderer (pIcon) != NULL)
+		cairo_dock_reload_data_renderer_on_icon (pIcon, CAIRO_CONTAINER (pDock));
+	
 	cairo_dock_trigger_update_dock_size (pDock);
 	gtk_widget_queue_draw (pDock->container.pWidget);
 }
@@ -1142,7 +1134,6 @@ void cairo_dock_resize_icon_in_dock (Icon *pIcon, CairoDock *pDock)  // the requ
 static cairo_surface_t *_cairo_dock_make_stripes_background (int iWidth, int iHeight, double *fStripesColorBright, double *fStripesColorDark, int iNbStripes, double fStripesWidth, double fStripesAngle)
 {
 	cairo_pattern_t *pStripesPattern;
-	double fWidth = iWidth;
 	if (fabs (fStripesAngle) != 90)
 		pStripesPattern = cairo_pattern_create_linear (0.0f,
 			0.0f,
@@ -1214,7 +1205,8 @@ static cairo_surface_t *_cairo_dock_make_stripes_background (int iWidth, int iHe
 }
 static void _cairo_dock_load_default_background (CairoDockImageBuffer *pImage, int iWidth, int iHeight)
 {
-	//g_print ("%s (%s, %d)\n", __func__, myDocksParam.cBackgroundImageFile, myDocksParam.bBackgroundImageRepeat);
+	cd_debug ("%s (%s, %d, %dx%d)", __func__, myDocksParam.cBackgroundImageFile, myDocksParam.bBackgroundImageRepeat, iWidth,
+				iHeight);
 	if (myDocksParam.cBackgroundImageFile != NULL)
 	{
 		if (myDocksParam.bBackgroundImageRepeat)
@@ -1361,4 +1353,4 @@ void cairo_dock_make_preview (CairoDock *pDock, const gchar *cPreviewPath)
 		cairo_surface_destroy (pSurface);
 		g_free (glbuffer);
 	}
-}
\ No newline at end of file
+}
