@@ -61,6 +61,7 @@
 #include "cairo-dock-desktop-file-factory.h"
 #include "cairo-dock-draw-opengl.h"
 #include "cairo-dock-opengl.h"
+#include "cairo-dock-data-renderer.h"
 #include "cairo-dock-dock-factory.h"
 
 extern gchar *g_cCurrentLaunchersPath;
@@ -116,7 +117,6 @@ static gboolean _cairo_dock_shrink_down (CairoDock *pDock)
 {
 	//g_print ("%s (%d, %f, %f)\n", __func__, pDock->iMagnitudeIndex, pDock->fFoldingFactor, pDock->fDecorationsOffsetX);
 	//\_________________ On fait decroitre la magnitude du dock.
-	int iPrevMagnitudeIndex = pDock->iMagnitudeIndex;
 	pDock->iMagnitudeIndex -= myBackendsParam.iShrinkDownInterval;
 	if (pDock->iMagnitudeIndex < 0)
 		pDock->iMagnitudeIndex = 0;
@@ -439,7 +439,7 @@ static gboolean _cairo_dock_dock_animation_loop (CairoContainer *pContainer)
 }
 
 static gboolean _on_dock_destroyed (GtkWidget *menu, CairoContainer *pContainer);
-static void _on_menu_deactivated (GtkMenuShell *menu, CairoDock *pDock)
+static void _on_menu_deactivated (G_GNUC_UNUSED GtkMenuShell *menu, CairoDock *pDock)
 {
 	//g_print ("\n+++ %s ()\n\n", __func__);
 	g_return_if_fail (CAIRO_DOCK_IS_DOCK (pDock));
@@ -476,8 +476,9 @@ static gboolean _on_dock_destroyed (GtkWidget *menu, CairoContainer *pContainer)
 		NULL,
 		_on_menu_destroyed,
 		pContainer);
+	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
-static void _setup_menu (CairoContainer *pContainer, Icon *pIcon, GtkWidget *pMenu)
+static void _setup_menu (CairoContainer *pContainer, G_GNUC_UNUSED Icon *pIcon, GtkWidget *pMenu)
 {
 	// keep the dock visible
 	CAIRO_DOCK (pContainer)->bHasModalWindow = TRUE;
@@ -737,7 +738,7 @@ void cairo_dock_insert_icon_in_dock_full (Icon *icon, CairoDock *pDock, gboolean
 		cd_warning ("This icon (%s) is already inside a container !", icon->cName);
 	}
 
-	//\______________ On regarde si on doit inserer un separateur.
+	//\______________ check if a separator is needed (ie, if the group of the new icon (not its order) is new).
 	gboolean bSeparatorNeeded = FALSE;
 	if (bInsertSeparator && ! CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon))
 	{
@@ -749,7 +750,7 @@ void cairo_dock_insert_icon_in_dock_full (Icon *icon, CairoDock *pDock, gboolean
 		}
 	}
 
-	//\______________ On insere l'icone a sa place dans la liste.
+	//\______________ insert the icon in the list.
 	if (icon->fOrder == CAIRO_DOCK_LAST_ORDER)
 	{
 		Icon *pLastIcon = cairo_dock_get_last_icon_of_order (pDock->icons, icon->iGroup);
@@ -1076,7 +1077,6 @@ void cairo_dock_remove_icons_from_dock (CairoDock *pDock, CairoDock *pReceivingD
 	pDock->icons = NULL;
 	Icon *icon;
 	GList *ic;
-	gchar *cDesktopFilePath;
 	for (ic = pIconsList; ic != NULL; ic = ic->next)
 	{
 		icon = ic->data;
@@ -1113,6 +1113,8 @@ void cairo_dock_remove_icons_from_dock (CairoDock *pDock, CairoDock *pReceivingD
 				icon->pModuleInstance->pDock = pReceivingDock;
 				cairo_dock_reload_module_instance (icon->pModuleInstance, FALSE);
 			}
+			else if (cairo_dock_get_icon_data_renderer (icon) != NULL)
+				cairo_dock_reload_data_renderer_on_icon (icon, CAIRO_CONTAINER (pReceivingDock));
 		}
 	}
 
@@ -1146,6 +1148,9 @@ void cairo_dock_reload_buffers_in_dock (CairoDock *pDock, gboolean bRecursive, g
 				cairo_dock_set_icon_size_in_dock (pDock, icon);
 			}
 			cairo_dock_trigger_load_icon_buffers (icon);
+			
+			if (bUpdateIconSize && cairo_dock_get_icon_data_renderer (icon) != NULL)
+				cairo_dock_reload_data_renderer_on_icon (icon, CAIRO_CONTAINER (pDock));
 		}
 		
 		if (bRecursive && icon->pSubDock != NULL)  // we handle the sub-dock for applets too, so that they don't need to care.
@@ -1179,7 +1184,7 @@ void cairo_dock_set_icon_size_in_dock (CairoDock *pDock, Icon *icon)
 	else
 	{
 		int wi, hi;
-		if (pDock->iIconSize != 0)
+		if (! pDock->bGlobalIconSize && pDock->iIconSize != 0)
 		{
 			wi = hi = pDock->iIconSize;
 		}
