@@ -165,7 +165,6 @@ struct _CairoDock {
 	gdouble fFoldingFactor;
 	gint iAvoidingMouseIconType;// type d'icone devant eviter la souris, -1 si aucun.
 	gdouble fAvoidingMouseMargin;// marge d'evitement de la souris, en fraction de la largeur d'an icon (entre 0 et 0.5)
-	GList *pFirstDrawnElement_deprecated;// pointeur sur le 1er element de la liste des icones a etre dessine, en partant de la gauche.
 	gdouble fDecorationsOffsetX;// decalage des decorations pour les faire suivre la souris.
 	// counter for the fade out effect.
 	gint iFadeCounter;
@@ -283,7 +282,8 @@ struct _CairoDock {
 	guint iSidUpdateDockSize;
 	/// whether the dock should use the global icons size parameters.
 	gboolean bGlobalIconSize;
-	gint reserved[1];
+	
+	gpointer reserved[4];
 };
 
 
@@ -375,7 +375,6 @@ Icon *cairo_dock_add_new_launcher_by_uri_or_type (const gchar *cExternDesktopFil
 *@param iType type of the launcher.
 *@param pReceivingDock the dock that will hold the new launcher.
 *@param fOrder the order of the icon inside the dock.
-*@param iGroup the group it will belong to
 *@return the newly created Icon corresponding to the type, or NULL if an error occured.
 */
 #define cairo_dock_add_new_launcher_by_type(iType, pReceivingDock, fOrder) cairo_dock_add_new_launcher_by_uri_or_type (NULL, iType, pReceivingDock, fOrder)
