@@ -29,8 +29,6 @@
 
 #include <cairo.h>
 #include <pango/pango.h>
-#include <librsvg/rsvg.h>
-#include <librsvg/rsvg-cairo.h>
 
 
 #include <X11/extensions/Xrender.h>
@@ -284,10 +282,12 @@ static inline void _compute_icon_coordinate (Icon *icon, CairoContainer *pContai
 		}
 		fGlideScale = (1 + fDockMagnitude * myIconsParam.fAmplitude * sin (fPhase)) / icon->fScale;  // c'est un peu hacky ... il faudrait passer l'icone precedente en parametre ...
 		if (! pContainer->bDirectionUp)
+		{
 			if (pContainer->bIsHorizontal)
 				fY = (1-fGlideScale)*icon->fHeight*icon->fScale;
 			else
 				fX = (1-fGlideScale)*icon->fHeight*icon->fScale;
+		}
 	}
 	else
 		fGlideScale = 1;
@@ -406,33 +406,20 @@ void cairo_dock_render_one_icon_opengl (Icon *icon, CairoDock *pDock, double fDo
 		glMatrixMode (GL_MODELVIEW);
 	}
 	
-	//\_____________________ On dessine les infos additionnelles.
-	if (icon->iQuickInfoTexture != 0)
-	{
-		double fMaxScale = cairo_dock_get_icon_max_scale (icon);
-		
-		glPushMatrix ();
-		glRotatef (-icon->fOrientation/G_PI*180., 0., 0., 1.);
-		glTranslatef (0., (- icon->fHeight + icon->iQuickInfoHeight / fMaxScale * fRatio) * icon->fScale/2, 0.);
-		
-		cairo_dock_draw_texture_with_alpha (icon->iQuickInfoTexture,
-			icon->iQuickInfoWidth / fMaxScale * fRatio * icon->fScale,
-			icon->iQuickInfoHeight / fMaxScale * fRatio * icon->fScale,
-			icon->fAlpha);
-		
-		glPopMatrix ();
-	}
-	
+	//\_____________________ Draw the overlays on top of that.
 	cairo_dock_draw_icon_overlays_opengl (icon, fRatio);
 	
 	//\_____________________ On dessine les etiquettes, avec un alpha proportionnel au facteur d'echelle de leur icone.
 	glPopMatrix ();  // retour au debut de la fonction.
-	if (bUseText && icon->pTextBuffer != NULL && icon->iHideLabel == 0
+	if (bUseText && icon->label.iTexture != 0 && icon->iHideLabel == 0
 	&& (icon->bPointed || (icon->fScale > 1.01 && ! myIconsParam.bLabelForPointedIconOnly)))  // 1.01 car sin(pi) = 1+epsilon :-/  //  && icon->iAnimationState < CAIRO_DOCK_STATE_CLICKED
 	{
 		glPushMatrix ();
 		glLoadIdentity ();
 		
+		_cairo_dock_enable_texture ();
+		_cairo_dock_set_blend_alpha ();
+		
 		double fMagnitude;
 		if (myIconsParam.bLabelForPointedIconOnly ||pDock->fMagnitudeMax == 0.)
 		{
@@ -445,27 +432,27 @@ void cairo_dock_render_one_icon_opengl (Icon *icon, CairoDock *pDock, double fDo
 			///fMagnitude *= (fMagnitude * myIconsParam.fLabelAlphaThreshold + 1) / (myIconsParam.fLabelAlphaThreshold + 1);
 		}
 		
-		double dx = .5 * (icon->iTextWidth & 1);  // on decale la texture pour la coller sur la grille des coordonnees entieres.
-		double dy = .5 * (icon->iTextHeight & 1);
+		double dx = .5 * (icon->label.iWidth & 1);  // on decale la texture pour la coller sur la grille des coordonnees entieres.
+		double dy = .5 * (icon->label.iHeight & 1);
 		
 		if (pDock->container.bIsHorizontal || !myIconsParam.bTextAlwaysHorizontal)
 		{
-			if (fX + icon->iTextWidth/2 > pDock->container.iWidth)  // l'etiquette deborde a droite.
-				fX = pDock->container.iWidth - icon->iTextWidth/2;
-			if (fX - icon->iTextWidth/2 < 0)  // l'etiquette deborde a gauche.
-				fX = icon->iTextWidth/2;
+			if (fX + icon->label.iWidth/2 > pDock->container.iWidth)  // l'etiquette deborde a droite.
+				fX = pDock->container.iWidth - icon->label.iWidth/2;
+			if (fX - icon->label.iWidth/2 < 0)  // l'etiquette deborde a gauche.
+				fX = icon->label.iWidth/2;
 			
 			if (pDock->container.bIsHorizontal)
 				glTranslatef (floor (fX) + dx,
 					pDock->container.bDirectionUp ? 
-						floor (fY + myIconsParam.iLabelSize - icon->iTextHeight / 2) - dy:
-						floor (fY - icon->fHeight * icon->fScale - myIconsParam.iLabelSize + icon->iTextHeight / 2) + dy,
+						floor (fY + myIconsParam.iLabelSize - icon->label.iHeight / 2) - dy:
+						floor (fY - icon->fHeight * icon->fScale - myIconsParam.iLabelSize + icon->label.iHeight / 2) + dy,
 					0.);
 			else
 			{
 				glTranslatef (pDock->container.bDirectionUp ? 
-						floor (fY - myIconsParam.iLabelSize + icon->iTextHeight / 2) - dy:
-						floor (fY + icon->fHeight * icon->fScale + myIconsParam.iLabelSize - icon->iTextHeight / 2) + dy,
+						floor (fY - myIconsParam.iLabelSize + icon->label.iHeight / 2) - dy:
+						floor (fY + icon->fHeight * icon->fScale + myIconsParam.iLabelSize - icon->label.iHeight / 2) + dy,
 					floor (fX) + dx,
 					0.);
 				glRotatef (pDock->container.bDirectionUp ? 90 : -90, 0., 0., 1.);
@@ -476,27 +463,74 @@ void cairo_dock_render_one_icon_opengl (Icon *icon, CairoDock *pDock, double fDo
 				glRotatef (-icon->fOrientation/G_PI*180., 0., 0., 1.);
 				glTranslatef (icon->fWidth * icon->fScale/2, -icon->fHeight * icon->fScale/2, 0.);
 			}
+			
+			_cairo_dock_set_alpha (fMagnitude);
+			cairo_dock_apply_image_buffer_texture (&icon->label);
 		}
 		else  // horizontal label on a vertical dock -> draw them next to the icon, vertically centered (like the Parabolic view)
 		{
-			const int pad = 3;
-			glTranslatef (pDock->container.bDirectionUp ? 
-					floor (fY - (myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin) * (1 - pDock->fMagnitudeMax) - pad - icon->iTextWidth/2) + dx :
-					floor (fY + icon->fHeight * icon->fScale + (myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin) * (1 - pDock->fMagnitudeMax) + pad + icon->iTextWidth/2) + dx,
-				floor (fX) + dy,
-				0.);
 			if (icon->pSubDock && gldi_container_is_visible (CAIRO_CONTAINER (icon->pSubDock)))
 			{
 				fMagnitude /= 3;
 			}
+			
+			const int pad = 3;
+			int iXStick = (pDock->container.bDirectionUp ? 
+				floor (fY - (myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin) * (1 - pDock->fMagnitudeMax) - pad) :  // right border
+				floor (fY + icon->fHeight * icon->fScale + (myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin) * (1 - pDock->fMagnitudeMax) + pad));  // left border
+			int  iMaxWidth = (pDock->container.bDirectionUp ?
+				iXStick :
+				pDock->container.iHeight - iXStick);
+			
+			int w;
+			if (icon->label.iWidth > iMaxWidth)
+			{
+				w = iMaxWidth;
+				dx = .5 * (w & 1);
+			}
+			else
+			{
+				w = icon->label.iWidth;
+			}
+			glTranslatef ((pDock->container.bDirectionUp ? 
+					floor (iXStick - w/2) + dx :
+					floor (iXStick + w/2) + dx),
+				floor (fX) + dy,
+				0.);
+			
+			if (icon->label.iWidth > iMaxWidth)  // draw with an alpha gradation on the last part.
+			{
+				cairo_dock_apply_image_buffer_texture_with_limit (&icon->label, fMagnitude, iMaxWidth);
+				/*glBindTexture (GL_TEXTURE_2D, icon->label.iTexture);
+				
+				double h = icon->label.iHeight;
+				double u0 = 0., u1 = (double) iMaxWidth / icon->label.iWidth;
+				glBegin(GL_QUAD_STRIP);
+				
+				double a = .75; // 3/4 plain, 1/4 gradation
+				a = (double) (floor ((-.5+a)*w)) / w + .5;
+				glColor4f (1., 1., 1., fMagnitude);
+				glTexCoord2f(u0, 0); glVertex3f (-.5*w,  .5*h, 0.);  // top left
+				glTexCoord2f(u0, 1); glVertex3f (-.5*w, -.5*h, 0.);  // bottom left
+				
+				glTexCoord2f(u1*a, 0); glVertex3f ((-.5+a)*w,  .5*h, 0.);  // top middle
+				glTexCoord2f(u1*a, 1); glVertex3f ((-.5+a)*w, -.5*h, 0.);  // bottom middle
+				
+				glColor4f (1., 1., 1., 0.);
+				
+				glTexCoord2f(u1, 0); glVertex3f (.5*w,  .5*h, 0.);  // top right
+				glTexCoord2f(u1, 1); glVertex3f (.5*w, -.5*h, 0.);  // bottom right
+				
+				glEnd();*/
+			}
+			else
+			{
+				_cairo_dock_set_alpha (fMagnitude);
+				cairo_dock_apply_image_buffer_texture_with_offset (&icon->label, 0, 0);
+			}
 		}
-		
-		_cairo_dock_enable_texture ();
-		_cairo_dock_set_blend_alpha ();
-		_cairo_dock_apply_texture_at_size_with_alpha (icon->iLabelTexture,
-			icon->iTextWidth,
-			icon->iTextHeight,
-			fMagnitude);
+		/*_cairo_dock_set_alpha (fMagnitude);
+		cairo_dock_apply_image_buffer_texture (&icon->label);*/
 		_cairo_dock_disable_texture ();
 		
 		glPopMatrix ();
@@ -578,6 +612,7 @@ void cairo_dock_render_hidden_dock_opengl (CairoDock *pDock)
 				pHiddenBgColor[3] *= pDock->fPostHideOffset;
 				if (pHiddenBgColor[3] != 0)
 				{
+					_cairo_dock_set_blend_alpha ();
 					glPushMatrix ();
 					w = icon->fWidth * icon->fScale;
 					h = icon->fHeight * icon->fScale;
@@ -685,7 +720,7 @@ GLuint cairo_dock_create_texture_from_surface (cairo_surface_t *pImageSurface)
 
 GLuint cairo_dock_create_texture_from_raw_data (const guchar *pTextureRaw, int iWidth, int iHeight)
 {
-	/*cd_debug ("%dx%d\n", iWidth, iHeight);
+	/*cd_debug ("%dx%d", iWidth, iHeight);
 	int i;
 	guint pixel, alpha, red, green, blue;
 	float fAlphaFactor;
@@ -818,82 +853,6 @@ void cairo_dock_update_icon_texture (Icon *pIcon)
 	}
 }
 
-void cairo_dock_update_label_texture (Icon *pIcon)
-{
-	if (pIcon->iLabelTexture != 0)
-	{
-		_cairo_dock_delete_texture (pIcon->iLabelTexture);
-		pIcon->iLabelTexture = 0;
-	}
-	if (pIcon != NULL && pIcon->pTextBuffer != NULL)
-	{
-		_cairo_dock_enable_texture ();
-		_cairo_dock_set_blend_source ();
-		glColor4f (1., 1., 1., 1.);
-		
-		glGenTextures (1, &pIcon->iLabelTexture);
-		int w = cairo_image_surface_get_width (pIcon->pTextBuffer);
-		int h = cairo_image_surface_get_height (pIcon->pTextBuffer);
-		glBindTexture (GL_TEXTURE_2D, pIcon->iLabelTexture);
-		
-		glTexParameteri (GL_TEXTURE_2D,
-			GL_TEXTURE_MIN_FILTER,
-			g_bEasterEggs ? GL_LINEAR_MIPMAP_LINEAR : GL_LINEAR);
-		if (g_bEasterEggs)
-			glTexParameteri(GL_TEXTURE_2D, GL_GENERATE_MIPMAP, GL_TRUE);
-		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-		
-		glTexImage2D (GL_TEXTURE_2D,
-			0,
-			4,  // GL_ALPHA / GL_BGRA
-			w,
-			h,
-			0,
-			GL_BGRA,  // GL_ALPHA / GL_BGRA
-			GL_UNSIGNED_BYTE,
-			cairo_image_surface_get_data (pIcon->pTextBuffer));
-		glDisable (GL_TEXTURE_2D);
-	}
-}
-
-void cairo_dock_update_quick_info_texture (Icon *pIcon)
-{
-	if (pIcon->iQuickInfoTexture != 0)
-	{
-		_cairo_dock_delete_texture (pIcon->iQuickInfoTexture);
-		pIcon->iQuickInfoTexture = 0;
-	}
-	if (pIcon != NULL && pIcon->pQuickInfoBuffer != NULL)
-	{
-		_cairo_dock_enable_texture ();
-		_cairo_dock_set_blend_source ();
-		glColor4f (1., 1., 1., 1.);
-		
-		glGenTextures (1, &pIcon->iQuickInfoTexture);
-		int w = cairo_image_surface_get_width (pIcon->pQuickInfoBuffer);
-		int h = cairo_image_surface_get_height (pIcon->pQuickInfoBuffer);
-		glBindTexture (GL_TEXTURE_2D, pIcon->iQuickInfoTexture);
-		
-		glTexParameteri (GL_TEXTURE_2D,
-			GL_TEXTURE_MIN_FILTER,
-			g_bEasterEggs ? GL_LINEAR_MIPMAP_LINEAR : GL_LINEAR);
-		if (g_bEasterEggs)
-			glTexParameteri(GL_TEXTURE_2D, GL_GENERATE_MIPMAP, GL_TRUE);
-		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-		
-		glTexImage2D (GL_TEXTURE_2D,
-			0,
-			4,  // GL_ALPHA / GL_BGRA
-			w,
-			h,
-			0,
-			GL_BGRA,  // GL_ALPHA / GL_BGRA
-			GL_UNSIGNED_BYTE,
-			cairo_image_surface_get_data (pIcon->pQuickInfoBuffer));
-		glDisable (GL_TEXTURE_2D);
-	}
-}
-
 
 
 void cairo_dock_draw_texture_with_alpha (GLuint iTexture, int iWidth, int iHeight, double fAlpha)
@@ -1022,70 +981,6 @@ void cairo_dock_draw_hidden_appli_icon (Icon *pIcon, CairoContainer *pContainer,
 }
 
 
-// A utiliser un jour.
-
-typedef struct _CairoAnimatedImage {
-	cairo_surface_t *pSurface;
-	GLuint iTexture;
-	gint iFrameWidth, iFrameHeight;
-	gint iNbFrames;
-	gint iCurrentFrame;
-	} CairoAnimatedImage;
-
-void cairo_dock_load_animated_image (const gchar *cImageFile, int iNbFrames, int iFrameWidth, int iFrameHeight, cairo_t *pSourceContext, CairoAnimatedImage *pAnimatedImage)
-{
-	pAnimatedImage->iNbFrames = iNbFrames;
-	pAnimatedImage->iCurrentFrame = 0;
-	
-	pAnimatedImage->iFrameWidth = iFrameWidth * iNbFrames;
-	pAnimatedImage->iFrameHeight = iFrameHeight;
-	pAnimatedImage->pSurface = cairo_dock_create_surface_from_image_simple (cImageFile,
-			pAnimatedImage->iFrameWidth,
-			pAnimatedImage->iFrameHeight);
-	
-	if (g_bUseOpenGL && pAnimatedImage->pSurface != NULL)
-	{
-		pAnimatedImage->iTexture = cairo_dock_create_texture_from_surface (pAnimatedImage->pSurface);
-	}
-}
-
-CairoAnimatedImage *cairo_dock_create_animated_image (const gchar *cImageFile, int iNbFrames, int iFrameWidth, int iFrameHeight, cairo_t *pSourceContext)
-{
-	CairoAnimatedImage *pAnimatedImage = g_new0 (CairoAnimatedImage, 1);
-	
-	cairo_dock_load_animated_image (cImageFile, iNbFrames, iFrameWidth, iFrameHeight, pSourceContext, pAnimatedImage);
-	
-	return pAnimatedImage;
-}
-
-#define cairo_dock_update_animated_image_state(pAnimatedImage) do {\
-	(pAnimatedImage)->iCurrentFrame ++;\
-	if ((pAnimatedImage)->iCurrentFrame == (pAnimatedImage)->iNbFrames)\
-		(pAnimatedImage)->iCurrentFrame = 0; } while (0)
-
-void cairo_dock_update_animated_image_cairo (CairoAnimatedImage *pAnimatedImage, cairo_t *pCairoContext)
-{
-	cairo_dock_update_animated_image_state (pAnimatedImage);
-	cairo_save (pCairoContext);
-	cairo_rectangle (pCairoContext, 0., 0., pAnimatedImage->iFrameWidth, pAnimatedImage->iFrameHeight);
-	cairo_clip (pCairoContext);
-	cairo_set_source_surface (pCairoContext,
-		pAnimatedImage->pSurface,
-		- pAnimatedImage->iFrameWidth * pAnimatedImage->iCurrentFrame,
-		0.);
-	cairo_restore (pCairoContext);
-}
-
-void cairo_dock_update_animated_image_opengl (CairoAnimatedImage *pAnimatedImage)
-{
-	cairo_dock_update_animated_image_state (pAnimatedImage);
-	_cairo_dock_apply_current_texture_portion_at_size_with_offset (1.*pAnimatedImage->iCurrentFrame/pAnimatedImage->iNbFrames, 0.,
-		1. / pAnimatedImage->iNbFrames, 1.,
-		pAnimatedImage->iFrameWidth, pAnimatedImage->iFrameHeight,
-		0., 0.);
-}
-
-
 
 //typedef void (*GLXBindTexImageProc) (Display *display, GLXDrawable drawable, int buffer, int *attribList);
 //typedef void (*GLXReleaseTexImageProc) (Display *display, GLXDrawable drawable, int buffer);
