@@ -289,7 +289,7 @@ void cairo_dock_render_decorations_in_frame (cairo_t *pCairoContext, CairoDock *
 }
 
 
-void cairo_dock_set_icon_scale_on_context (cairo_t *pCairoContext, Icon *icon, gboolean bIsHorizontal, double fRatio, gboolean bDirectionUp)
+void cairo_dock_set_icon_scale_on_context (cairo_t *pCairoContext, Icon *icon, gboolean bIsHorizontal, G_GNUC_UNUSED double fRatio, gboolean bDirectionUp)
 {
 	if (bIsHorizontal)
 	{
@@ -329,7 +329,6 @@ void cairo_dock_set_icon_scale_on_context (cairo_t *pCairoContext, Icon *icon, g
 
 void cairo_dock_draw_icon_reflect_cairo (Icon *icon, CairoContainer *pContainer, cairo_t *pCairoContext)
 {
-	double fRatio = pContainer->fRatio;
 	if (pContainer->bUseReflect && icon->pIconBuffer != NULL)
 	{
 		cairo_save (pCairoContext);
@@ -468,7 +467,7 @@ void cairo_dock_draw_icon_cairo (Icon *icon, CairoDock *pDock, cairo_t *pCairoCo
 	cairo_dock_draw_icon_reflect_cairo (icon, CAIRO_CONTAINER (pDock), pCairoContext);
 }
 
-gboolean cairo_dock_render_icon_notification (gpointer pUserData, Icon *icon, CairoDock *pDock, gboolean *bHasBeenRendered, cairo_t *pCairoContext)
+gboolean cairo_dock_render_icon_notification (G_GNUC_UNUSED gpointer pUserData, Icon *icon, CairoDock *pDock, gboolean *bHasBeenRendered, cairo_t *pCairoContext)
 {
 	if (*bHasBeenRendered)
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
@@ -555,7 +554,7 @@ void cairo_dock_render_one_icon (Icon *icon, CairoDock *pDock, cairo_t *pCairoCo
 	cairo_restore (pCairoContext);  // retour juste apres la translation (fDrawX, fDrawY).
 	
 	//\_____________________ On dessine les etiquettes, avec un alpha proportionnel au facteur d'echelle de leur icone.
-	if (bUseText && icon->pTextBuffer != NULL && icon->iHideLabel == 0
+	if (bUseText && icon->label.pSurface != NULL && icon->iHideLabel == 0
 	&& (icon->bPointed || (icon->fScale > 1.01 && ! myIconsParam.bLabelForPointedIconOnly)))  // 1.01 car sin(pi) = 1+epsilon :-/  //  && icon->iAnimationState < CAIRO_DOCK_STATE_CLICKED
 	{
 		cairo_save (pCairoContext);
@@ -572,81 +571,99 @@ void cairo_dock_render_one_icon (Icon *icon, CairoDock *pDock, cairo_t *pCairoCo
 			///fMagnitude *= (fMagnitude * myIconsParam.fLabelAlphaThreshold + 1) / (myIconsParam.fLabelAlphaThreshold + 1);
 		}
 		
-		//int iLabelSize = icon->iTextHeight;
+		//int iLabelSize = icon->label.iHeight;
 		int iLabelSize = myIconsParam.iLabelSize;
-		//g_print ("%d / %d\n", icon->iTextHeight, myIconsParam.iLabelSize),
+		//g_print ("%d / %d\n", icon->label.iHeight, myIconsParam.iLabelSize),
 		cairo_identity_matrix (pCairoContext);  // on positionne les etiquettes sur un pixels entier, sinon ca floute.
 		if (bIsHorizontal)
 			cairo_translate (pCairoContext, floor (icon->fDrawX + icon->fGlideOffset * icon->fWidth * icon->fScale * (icon->fGlideOffset < 0 ? fGlideScale : 1)), floor (icon->fDrawY));
 		else
 			cairo_translate (pCairoContext, floor (icon->fDrawY), floor (icon->fDrawX + icon->fGlideOffset * icon->fWidth * icon->fScale * (icon->fGlideOffset < 0 ? fGlideScale : 1)));
 		
-		double fOffsetX = (icon->fWidth * icon->fScale - icon->iTextWidth) / 2;
+		double fOffsetX = (icon->fWidth * icon->fScale - icon->label.iWidth) / 2;
 		if (fOffsetX < - icon->fDrawX)  // l'etiquette deborde a gauche.
 			fOffsetX = - icon->fDrawX;
-		else if (icon->fDrawX + fOffsetX + icon->iTextWidth > iWidth)  // l'etiquette deborde a droite.
-			fOffsetX = iWidth - icon->iTextWidth - icon->fDrawX;
+		else if (icon->fDrawX + fOffsetX + icon->label.iWidth > iWidth)  // l'etiquette deborde a droite.
+			fOffsetX = iWidth - icon->label.iWidth - icon->fDrawX;
 		
 		if (icon->fOrientation != 0 && ! myIconsParam.bTextAlwaysHorizontal)
 			cairo_rotate (pCairoContext, icon->fOrientation);
 		
 		if (bIsHorizontal)
 		{
-			cairo_set_source_surface (pCairoContext,
-				icon->pTextBuffer,
-				floor (fOffsetX),
-				floor (bDirectionUp ? -iLabelSize : icon->fHeight * icon->fScale));
+			cairo_dock_apply_image_buffer_surface_with_offset (&icon->label, pCairoContext,
+				floor (fOffsetX), floor (bDirectionUp ? -iLabelSize : icon->fHeight * icon->fScale), fMagnitude);
 		}
 		else if (myIconsParam.bTextAlwaysHorizontal)  // horizontal label on a vertical dock -> draw them next to the icon, vertically centered (like the Parabolic view)
 		{
-			const int pad = 3;
-			cairo_set_source_surface (pCairoContext,
-				icon->pTextBuffer,
-				bDirectionUp ? 
-					floor (0 - (myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin) * (1 - pDock->fMagnitudeMax) - pad - icon->iTextWidth):
-					floor (0 + icon->fHeight * icon->fScale + (myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin) * (1 - pDock->fMagnitudeMax) + pad),
-				floor (0 + icon->fWidth * icon->fScale/2 - icon->iTextHeight/2));
-			if (icon->pSubDock && gldi_container_is_visible (CAIRO_CONTAINER (icon->pSubDock)))
+			if (icon->pSubDock && gldi_container_is_visible (CAIRO_CONTAINER (icon->pSubDock)))  // in vertical mode 
 			{
 				fMagnitude /= 3;
 			}
+			const int pad = 3;
+			double fY = icon->fDrawY;
+			int  iMaxWidth = (pDock->container.bDirectionUp ?
+				fY - (myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin) * (1 - pDock->fMagnitudeMax) - pad :
+				pDock->container.iHeight - (fY + icon->fHeight * icon->fScale + (myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin) * (1 - pDock->fMagnitudeMax) + pad));
+			int iOffsetX = floor (bDirectionUp ? 
+				MAX (- iMaxWidth, - (myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin) * (1 - pDock->fMagnitudeMax) - pad - icon->label.iWidth):
+				icon->fHeight * icon->fScale + (myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin) * (1 - pDock->fMagnitudeMax) + pad);
+			int iOffsetY = floor (icon->fWidth * icon->fScale/2 - icon->label.iHeight/2);
+			if (icon->label.iWidth < iMaxWidth)
+			{
+				cairo_dock_apply_image_buffer_surface_with_offset (&icon->label, pCairoContext,
+					iOffsetX,
+					iOffsetY,
+					fMagnitude);
+			}
+			else
+			{
+				cairo_dock_apply_image_buffer_surface_with_offset_and_limit (&icon->label, pCairoContext, iOffsetX, iOffsetY, fMagnitude, iMaxWidth);
+				/*cairo_set_source_surface (pCairoContext,
+					icon->label.pSurface,
+					iOffsetX,
+					iOffsetY);
+				
+				cairo_pattern_t *pGradationPattern = cairo_pattern_create_linear (iOffsetX,
+					0.,
+					iOffsetX + iMaxWidth,
+					0.);
+				cairo_pattern_set_extend (pGradationPattern, CAIRO_EXTEND_NONE);
+				cairo_pattern_add_color_stop_rgba (pGradationPattern,
+					0.,
+					0.,
+					0.,
+					0.,
+					fMagnitude);
+				cairo_pattern_add_color_stop_rgba (pGradationPattern,
+					0.75,
+					0.,
+					0.,
+					0.,
+					fMagnitude);
+				cairo_pattern_add_color_stop_rgba (pGradationPattern,
+					1.,
+					0.,
+					0.,
+					0.,
+					0.);
+				cairo_mask (pCairoContext, pGradationPattern);
+				cairo_pattern_destroy (pGradationPattern);*/
+			}
 		}
 		else
 		{
 			cairo_rotate (pCairoContext, bDirectionUp ? - G_PI/2 : G_PI/2);
-			cairo_set_source_surface (pCairoContext,
-				icon->pTextBuffer,
+			cairo_dock_apply_image_buffer_surface_with_offset (&icon->label, pCairoContext,
 				floor (bDirectionUp ? fOffsetX - icon->fWidth * icon->fScale : fOffsetX),
-				-floor (bDirectionUp ? iLabelSize : icon->fHeight * icon->fScale + iLabelSize));
+				-floor (bDirectionUp ? iLabelSize : icon->fHeight * icon->fScale + iLabelSize),
+				fMagnitude);
 		}
 		
-		if (fMagnitude > .1)
-			cairo_paint_with_alpha (pCairoContext, fMagnitude);
 		cairo_restore (pCairoContext);  // retour juste apres la translation (fDrawX, fDrawY).
 	}
 	
-	//\_____________________ On dessine les infos additionnelles.
-	if (icon->pQuickInfoBuffer != NULL)
-	{
-		double fMaxScale = cairo_dock_get_icon_max_scale (icon);
-		cairo_translate (pCairoContext,
-			(- icon->iQuickInfoWidth / fMaxScale * fRatio + icon->fWidthFactor * icon->fWidth) / 2 * icon->fScale,
-			(icon->fHeight - icon->iQuickInfoHeight / fMaxScale * fRatio) * icon->fScale);
-		
-		cairo_scale (pCairoContext,
-			fRatio * icon->fScale / fMaxScale,
-			fRatio * icon->fScale / fMaxScale);
-		
-		cairo_set_source_surface (pCairoContext,
-			icon->pQuickInfoBuffer,
-			0,
-			0);
-		if (icon->fAlpha == 1)
-			cairo_paint (pCairoContext);
-		else
-			cairo_paint_with_alpha (pCairoContext, icon->fAlpha);
-	}
-	
+	//\_____________________ Draw the overlays on top of that.
 	cairo_dock_draw_icon_overlays_cairo (icon, fRatio, pCairoContext);
 }
 
@@ -678,24 +695,26 @@ void cairo_dock_render_one_icon_in_desklet (Icon *icon, CairoContainer *pContain
 		}
 	}
 	
-	//\_____________________ On dessine les etiquettes, avec un alpha proportionnel au facteur d'echelle de leur icone.
-	if (bUseText && icon->pTextBuffer != NULL)
+	//\_____________________ On dessine les etiquettes.
+	if (bUseText && icon->label.pSurface != NULL)
 	{
 		cairo_save (pCairoContext);
-		double fOffsetX = (icon->fWidthFactor * icon->fWidth * icon->fScale - icon->iTextWidth) / 2;
+		double fOffsetX = (icon->fWidthFactor * icon->fWidth * icon->fScale - icon->label.iWidth) / 2;
 		if (fOffsetX < - icon->fDrawX)
 			fOffsetX = - icon->fDrawX;
-		else if (icon->fDrawX + fOffsetX + icon->iTextWidth > pContainer->iWidth)
-			fOffsetX = pContainer->iWidth - icon->iTextWidth - icon->fDrawX;
+		else if (icon->fDrawX + fOffsetX + icon->label.iWidth > pContainer->iWidth)
+			fOffsetX = pContainer->iWidth - icon->label.iWidth - icon->fDrawX;
 		if (icon->fOrientation != 0)
 		{
 			cairo_rotate (pCairoContext, icon->fOrientation);
 		}
-		cairo_set_source_surface (pCairoContext,
+		/**cairo_set_source_surface (pCairoContext,
 			icon->pTextBuffer,
 			fOffsetX,
 			-myIconsParam.iLabelSize);
-		cairo_paint (pCairoContext);
+		cairo_paint (pCairoContext);*/
+		cairo_dock_apply_image_buffer_surface_with_offset (&icon->label, pCairoContext,
+			fOffsetX, -myIconsParam.iLabelSize, 1.);
 		cairo_restore (pCairoContext);  // retour juste apres la translation (fDrawX, fDrawY).
 	}
 	
@@ -703,7 +722,7 @@ void cairo_dock_render_one_icon_in_desklet (Icon *icon, CairoContainer *pContain
 	///	_cairo_dock_draw_appli_indicator (icon, pCairoContext, TRUE, 1., TRUE);
 	
 	//\_____________________ On dessine les infos additionnelles.
-	if (icon->pQuickInfoBuffer != NULL)
+	/**if (icon->pQuickInfoBuffer != NULL)
 	{
 		cairo_translate (pCairoContext,
 			(- icon->iQuickInfoWidth + icon->fWidth) / 2 * icon->fScale,
@@ -718,7 +737,8 @@ void cairo_dock_render_one_icon_in_desklet (Icon *icon, CairoContainer *pContain
 			0,
 			0);
 		cairo_paint (pCairoContext);
-	}
+	}*/
+	cairo_dock_draw_icon_overlays_cairo (icon, pContainer->fRatio, pCairoContext);
 }
 
 
