@@ -34,6 +34,7 @@
 #include "cairo-dock-container.h"
 #include "cairo-dock-launcher-manager.h"  // cairo_dock_launch_command_syncl
 #include "cairo-dock-X-utilities.h"  // cairo_dock_property_is_present_on_root
+#include "cairo-dock-icon-manager.h"  // cairo_dock_free_icon
 #define _MANAGER_DEF_
 #include "cairo-dock-file-manager.h"
 
@@ -115,6 +116,7 @@ static gpointer _cairo_dock_fm_launch_uri_threaded (gchar *cURI)
 	cd_debug ("%s (%s)", __func__, cURI);
 	s_pEnvBackend->launch_uri (cURI);
 	g_free (cURI);
+	return NULL;
 }
 gboolean cairo_dock_fm_launch_uri (const gchar *cURI)
 {
@@ -124,7 +126,16 @@ gboolean cairo_dock_fm_launch_uri (const gchar *cURI)
 		//s_pEnvBackend->launch_uri (cURI);
 		GError *erreur = NULL;
 		gchar *cThreadURI = g_strdup (cURI);
+		#if (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION < 32)
 		GThread* pThread = g_thread_create ((GThreadFunc) _cairo_dock_fm_launch_uri_threaded, (gpointer) cThreadURI, FALSE, &erreur);
+		#else
+		// The name can be useful for discriminating threads in a debugger.
+		// Some systems restrict the length of name to 16 bytes. 
+		gchar *cThreadName = g_strndup (cURI, 15);
+		GThread* pThread = g_thread_try_new (cThreadName, (GThreadFunc) _cairo_dock_fm_launch_uri_threaded, (gpointer) cThreadURI, &erreur);
+		g_thread_unref (pThread);
+		g_free (cThreadName);
+		#endif
 		if (erreur != NULL)
 		{
 			cd_warning (erreur->message);
