@@ -308,7 +308,7 @@ Icon *cairo_dock_get_icon_with_base_uri (GList *pIconList, const gchar *cBaseURI
 	for (ic = pIconList; ic != NULL; ic = ic->next)
 	{
 		icon = ic->data;
-		//cd_message ("  icon->cBaseURI : %s\n", icon->cBaseURI);
+		//cd_message ("  icon->cBaseURI : %s", icon->cBaseURI);
 		if (icon->cBaseURI != NULL && strcmp (icon->cBaseURI, cBaseURI) == 0)
 			return icon;
 	}
@@ -323,7 +323,7 @@ Icon *cairo_dock_get_icon_with_name (GList *pIconList, const gchar *cName)
 	for (ic = pIconList; ic != NULL; ic = ic->next)
 	{
 		icon = ic->data;
-		//cd_message ("  icon->cName : %s\n", icon->cName);
+		//cd_message ("  icon->cName : %s", icon->cName);
 		if (icon->cName != NULL && strcmp (icon->cName, cName) == 0)
 			return icon;
 	}
@@ -538,7 +538,7 @@ void cairo_dock_update_icon_s_container_name (Icon *icon, const gchar *cNewParen
 }
 
 
-void cairo_dock_set_icon_name (const gchar *cIconName, Icon *pIcon, CairoContainer *pContainer_useless)  // fonction proposee par Necropotame.
+void cairo_dock_set_icon_name (const gchar *cIconName, Icon *pIcon, G_GNUC_UNUSED CairoContainer *pContainer_useless)  // fonction proposee par Necropotame.
 {
 	g_return_if_fail (pIcon != NULL);  // le contexte sera verifie plus loin.
 	gchar *cUniqueName = NULL;
@@ -557,10 +557,13 @@ void cairo_dock_set_icon_name (const gchar *cIconName, Icon *pIcon, CairoContain
 	
 	g_free (cUniqueName);
 	
-	cairo_dock_load_icon_text (pIcon, &myIconsParam.iconTextDescription);
+	cairo_dock_load_icon_text (pIcon);
+	
+	if (pIcon->pContainer && pIcon->pContainer->bInside)  // for a dock, in this case the label will be visible.
+		cairo_dock_redraw_container (pIcon->pContainer);  // this is not really optimized, ideally the view should provide a way to redraw the label area only...
 }
 
-void cairo_dock_set_icon_name_printf (Icon *pIcon, CairoContainer *pContainer_useless, const gchar *cIconNameFormat, ...)
+void cairo_dock_set_icon_name_printf (Icon *pIcon, G_GNUC_UNUSED CairoContainer *pContainer_useless, const gchar *cIconNameFormat, ...)
 {
 	va_list args;
 	va_start (args, cIconNameFormat);
@@ -570,18 +573,17 @@ void cairo_dock_set_icon_name_printf (Icon *pIcon, CairoContainer *pContainer_us
 	va_end (args);
 }
 
-void cairo_dock_set_quick_info (Icon *pIcon, CairoContainer *pContainer_useless, const gchar *cQuickInfo)
+void cairo_dock_set_quick_info (Icon *pIcon, G_GNUC_UNUSED CairoContainer *pContainer_useless, const gchar *cQuickInfo)
 {
 	g_return_if_fail (pIcon != NULL);
 	
-	if (pIcon->cQuickInfo != cQuickInfo)
+	if (pIcon->cQuickInfo != cQuickInfo)  // be paranoid, in case one passes pIcon->cQuickInfo to the function
 	{
 		g_free (pIcon->cQuickInfo);
 		pIcon->cQuickInfo = g_strdup (cQuickInfo);
 	}
 	
-	cairo_dock_load_icon_quickinfo (pIcon,
-		&myIconsParam.quickInfoTextDescription);
+	cairo_dock_load_icon_quickinfo (pIcon);
 }
 
 void cairo_dock_set_quick_info_printf (Icon *pIcon, CairoContainer *pContainer_useless, const gchar *cQuickInfoFormat, ...)
