@@ -23,6 +23,7 @@
 #include <glib.h>
 
 #include "cairo-dock-struct.h"
+#include "cairo-dock-image-buffer.h"
 #include "cairo-dock-object.h"
 
 G_BEGIN_DECLS
@@ -95,6 +96,7 @@ struct _Icon {
 	CairoDockIconGroup iGroup;
 	/// interface
 	IconInterface iface;
+	CairoContainer *pContainer;  // container where the icon is currently.
 	
 	//\____________ properties.
 	// generic.
@@ -120,14 +122,9 @@ struct _Icon {
 	/// a flag that allows the icon to be always visible, even with the dock is hidden.
 	gboolean bAlwaysVisible;
 	gboolean bIsDemandingAttention;
-	
-	CairoDataRenderer *pDataRenderer;
-	CairoDockTransition *pTransition;
-	
-	CairoDockAnimationState iAnimationState;
-	/// Whether the icon is currently pointed or not.
-	gboolean bPointed;
-	gdouble fInsertRemoveFactor;
+	gboolean bHasHiddenBg;
+	gdouble *pHiddenBgColor;  // NULL to use the default color
+	gboolean bIgnoreQuicklist;  // TRUE to not display the Ubuntu's quicklist of the class
 	
 	// Launcher.
 	gchar *cDesktopFileName;  // nom (et non pas chemin) du fichier .desktop
@@ -135,6 +132,8 @@ struct _Icon {
 	gchar *cWorkingDirectory;
 	gchar *cBaseURI;
 	gint iVolumeID;
+	gchar **pMimeTypes;
+	gchar *cWmClass;
 	
 	// Appli.
 	Window Xid;
@@ -162,17 +161,12 @@ struct _Icon {
 	gint iImageWidth, iImageHeight;  // taille de la surface/texture telle qu'elle a ete creee.
 	cairo_surface_t* pIconBuffer;
 	GLuint iIconTexture;
-	cairo_surface_t* pReflectionBuffer_deprecated;
+	CairoDockImageBuffer label; // the label above the icon
+	GList *pOverlays;  // a list of CairoOverlay
+	CairoDataRenderer *pDataRenderer;
+	CairoDockTransition *pTransition;
 	
-	gint iTextWidth, iTextHeight;
-	cairo_surface_t* pTextBuffer;
-	GLuint iLabelTexture;
-	
-	gint iQuickInfoWidth, iQuickInfoHeight;
-	cairo_surface_t* pQuickInfoBuffer;
-	GLuint iQuickInfoTexture;
-	
-	//\____________ Parametres de dessin, definis par la vue/les animations.
+	//\____________ Drawing parameters.
 	gdouble fXMin, fXMax;  // Abscisse extremale gauche/droite que the icon atteindra (variable avec la vague).
 	gdouble fXAtRest;  // Abscisse de the icon au repos.
 	gdouble fPhase;  // Phase de the icon (entre -pi et piconi).
@@ -192,27 +186,23 @@ struct _Icon {
 	gint iGlideDirection;  // direction dans laquelle glisse the icon.
 	gdouble fGlideScale;  // echelle d'adaptation au glissement.
 	
-	gboolean bBeingRemovedByCairo;  // devrait etre dans pDataSlot...
+	CairoDockAnimationState iAnimationState;
+	/// Whether the icon is currently pointed or not.
+	gboolean bPointed;
+	gdouble fInsertRemoveFactor;
+	gboolean bDamaged;  // TRUE when the icon couldn't draw its surface, because the Gl context was not yet ready.
 	
+	//\____________ Other dynamic parameters.
+	gboolean bBeingRemovedByCairo;  // devrait etre dans pDataSlot...
 	guint iSidRedrawSubdockContent;
 	guint iSidLoadImage;
 	guint iSidDoubleClickDelay;
-	/// container where the icon is currently.
-	CairoContainer *pContainer;
 	gint iNbDoubleClickListeners;
-	
-	gchar **pMimeTypes;
-	
 	gint iHideLabel;
-	gchar *cWmClass;
-	GList *pOverlays;
-	gdouble *pHiddenBgColor;  // NULL to use the default color
-	
 	gint iThumbnailX, iThumbnailY;  // X icon geometry for apps
 	gint iThumbnailWidth, iThumbnailHeight;
-	gboolean bDamaged;  // TRUE when the icon couldn't draw its surface, because the Gl context was not yet ready.
-	gboolean bHasHiddenBg;
-	//gpointer reserved[1];
+	
+	gpointer reserved[4];
 };
 
 typedef void (*CairoIconContainerLoadFunc) (void);
@@ -300,15 +290,13 @@ void cairo_dock_load_icon_image (Icon *icon, CairoContainer *pContainer);
 
 /**Fill the label buffer (surface & texture) of a given icon, according to a text description.
 *@param icon the icon.
-*@param pTextDescription desctiption of the text rendering.
 */
-void cairo_dock_load_icon_text (Icon *icon, CairoDockLabelDescription *pTextDescription);
+void cairo_dock_load_icon_text (Icon *icon);
 
 /**Fill the quick-info buffer (surface & texture) of a given icon, according to a text description.
 *@param icon the icon.
-*@param pTextDescription desctiption of the text rendering.
 */
-void cairo_dock_load_icon_quickinfo (Icon *icon, CairoDockLabelDescription *pTextDescription);
+void cairo_dock_load_icon_quickinfo (Icon *icon);
 
 /** Fill all the buffers (surfaces & textures) of a given icon, according to its type. Set its size accordingly, and fills the reflection buffer for cairo. Label and quick-info are loaded with the current global text description.
 *@param pIcon the icon.
