@@ -23,8 +23,6 @@
 
 #include <gtk/gtk.h>
 
-
-
 #include "gldi-config.h"  // GLDI_SHARE_DATA_DIR
 #include "cairo-dock-draw.h"
 #include "cairo-dock-surface-factory.h"
@@ -33,11 +31,11 @@
 #include "cairo-dock-dock-manager.h"  // cairo_dock_redraw_root_docks
 #include "cairo-dock-draw-opengl.h"
 #include "cairo-dock-container.h"
-///#include "cairo-dock-emblem.h"
 #include "cairo-dock-applications-manager.h"  // cairo_dock_foreach_applis
 #include "cairo-dock-image-buffer.h"
 #include "cairo-dock-icon-manager.h"
 #include "cairo-dock-notifications.h"
+#include "cairo-dock-data-renderer.h"
 #include "cairo-dock-applications-manager.h"  // myTaskbarParam.bShowAppli
 #define _MANAGER_DEF_
 #include "cairo-dock-indicator-manager.h"
@@ -76,7 +74,6 @@ static void _cairo_dock_draw_appli_indicator_opengl (Icon *icon, CairoDock *pDoc
 {
 	gboolean bIsHorizontal = pDock->container.bIsHorizontal;
 	gboolean bDirectionUp = pDock->container.bDirectionUp;
-	double fRatio = pDock->container.fRatio;
 	if (! myIndicatorsParam.bRotateWithDock)
 		bDirectionUp = bIsHorizontal = TRUE;
 	
@@ -110,7 +107,7 @@ static void _cairo_dock_draw_appli_indicator_opengl (Icon *icon, CairoDock *pDoc
 	cairo_dock_draw_texture_with_alpha (s_indicatorBuffer.iTexture, 1., 1., 1.);
 	glPopMatrix ();
 }
-static void _cairo_dock_draw_active_window_indicator_opengl (Icon *icon, CairoDock *pDock, double fRatio)
+static void _cairo_dock_draw_active_window_indicator_opengl (Icon *icon, CairoDock *pDock, G_GNUC_UNUSED double fRatio)
 {
 	if (s_activeIndicatorBuffer.iTexture == 0)
 		return ;
@@ -154,7 +151,6 @@ static void _cairo_dock_draw_appli_indicator (Icon *icon, CairoDock *pDock, cair
 {
 	gboolean bIsHorizontal = pDock->container.bIsHorizontal;
 	gboolean bDirectionUp = pDock->container.bDirectionUp;
-	double fRatio = pDock->container.fRatio;
 	if (! myIndicatorsParam.bRotateWithDock)
 		bDirectionUp = bIsHorizontal = TRUE;
 	
@@ -264,7 +260,7 @@ static inline gboolean _active_indicator_is_visible (Icon *icon)
 	return bIsActive;
 }
 
-static gboolean cairo_dock_pre_render_indicator_notification (gpointer pUserData, Icon *icon, CairoDock *pDock, cairo_t *pCairoContext)
+static gboolean cairo_dock_pre_render_indicator_notification (G_GNUC_UNUSED gpointer pUserData, Icon *icon, CairoDock *pDock, cairo_t *pCairoContext)
 {
 	gboolean bIsActive = (myIndicatorsParam.bActiveIndicatorAbove ? FALSE : _active_indicator_is_visible (icon));
 	
@@ -295,7 +291,7 @@ static gboolean cairo_dock_pre_render_indicator_notification (gpointer pUserData
 	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 
-static gboolean cairo_dock_render_indicator_notification (gpointer pUserData, Icon *icon, CairoDock *pDock, gboolean *bHasBeenRendered, cairo_t *pCairoContext)
+static gboolean cairo_dock_render_indicator_notification (G_GNUC_UNUSED gpointer pUserData, Icon *icon, CairoDock *pDock, G_GNUC_UNUSED gboolean *bHasBeenRendered, cairo_t *pCairoContext)
 {
 	gboolean bIsActive = (myIndicatorsParam.bActiveIndicatorAbove ? _active_indicator_is_visible (icon) : FALSE);
 	
@@ -352,6 +348,7 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoIndicatorsParam *pIndicator
 	{
 		pIndicators->cIndicatorImagePath = cairo_dock_search_image_s_path (cIndicatorImageName);
 		g_free (cIndicatorImageName);
+		cIndicatorImageName = NULL;
 	}
 	else
 		pIndicators->cIndicatorImagePath = g_strdup (GLDI_SHARE_DATA_DIR"/icons/default-indicator.png");
@@ -404,30 +401,21 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoIndicatorsParam *pIndicator
 	//\__________________ On recupere l'indicateur de fenetre active.
 	int iIndicType = cairo_dock_get_integer_key_value (pKeyFile, "Indicators", "active indic type", &bFlushConfFileNeeded, -1, NULL, NULL);  // -1 pour pouvoir intercepter le cas ou la cle n'existe pas.
 	
-	cIndicatorImageName = cairo_dock_get_string_key_value (pKeyFile, "Indicators", "active indicator", &bFlushConfFileNeeded, NULL, NULL, NULL);
-	if (iIndicType == -1)  // nouvelle cle.
+	if (iIndicType == 0 || iIndicType == -1)  // image or new key => get the image
 	{
-		iIndicType = (cIndicatorImageName != NULL ? 0 : 1);
-		g_key_file_set_integer (pKeyFile, "Indicators", "active indic type", iIndicType);
-	}
-	else
-	{
-		if (iIndicType != 0)  // pas d'image.
+		cIndicatorImageName = cairo_dock_get_string_key_value (pKeyFile, "Indicators", "active indicator", &bFlushConfFileNeeded, NULL, NULL, NULL);
+		if (cIndicatorImageName != NULL)  // ensure the image exists
+			pIndicators->cActiveIndicatorImagePath = cairo_dock_search_image_s_path (cIndicatorImageName);
+		if (iIndicType == -1)  // new key
 		{
-			g_free (cIndicatorImageName);
-			cIndicatorImageName = NULL;
+			iIndicType = (pIndicators->cActiveIndicatorImagePath != NULL ? 0 : 1);  // if a valid image was defined before, use this option.
+			g_key_file_set_integer (pKeyFile, "Indicators", "active indic type", iIndicType);
 		}
-	}
-	
-	if (cIndicatorImageName != NULL)
-	{
-		pIndicators->cActiveIndicatorImagePath = cairo_dock_search_image_s_path (cIndicatorImageName);
 		g_free (cIndicatorImageName);
+		cIndicatorImageName = NULL;
 	}
-	else
-		pIndicators->cActiveIndicatorImagePath = NULL;
 	
-	if (iIndicType == 1)  // cadre
+	if (pIndicators->cActiveIndicatorImagePath == NULL)  // 'frame' option, or no image defined, or nonexistent image => load the frame
 	{
 		double couleur_active[4] = {0., 0.4, 0.8, 0.5};
 		cairo_dock_get_double_list_key_value (pKeyFile, "Indicators", "active color", &bFlushConfFileNeeded, pIndicators->fActiveColor, 4, couleur_active, "Icons", NULL);
@@ -446,6 +434,7 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoIndicatorsParam *pIndicator
 		{
 			pIndicators->cClassIndicatorImagePath = cairo_dock_search_image_s_path (cIndicatorImageName);
 			g_free (cIndicatorImageName);
+			cIndicatorImageName = NULL;
 		}
 		else
 		{
@@ -453,6 +442,17 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoIndicatorsParam *pIndicator
 		}
 		pIndicators->bZoomClassIndicator = cairo_dock_get_boolean_key_value (pKeyFile, "Indicators", "zoom class", &bFlushConfFileNeeded, FALSE, NULL, NULL);
 	}
+	
+	//\__________________ Progress bar.
+	double start_color[4] = {.53, .53, .53, .85};  // grey
+	cairo_dock_get_double_list_key_value (pKeyFile, "Indicators", "bar_color_start", &bFlushConfFileNeeded, pIndicators->fBarColorStart, 4, start_color, NULL, NULL);
+	double stop_color[4] = {.87, .87, .87, .85};  // grey (lighter)
+	cairo_dock_get_double_list_key_value (pKeyFile, "Indicators", "bar_color_stop", &bFlushConfFileNeeded, pIndicators->fBarColorStop, 4, stop_color, NULL, NULL);
+	pIndicators->bBarHasOutline = cairo_dock_get_boolean_key_value (pKeyFile, "Indicators", "bar_outline", &bFlushConfFileNeeded, TRUE, NULL, NULL);
+	double outline_color[4] = {1, 1, 1, .85};  // white
+	cairo_dock_get_double_list_key_value (pKeyFile, "Indicators", "bar_color_outline", &bFlushConfFileNeeded, pIndicators->fBarColorOutline, 4, outline_color, NULL, NULL);
+	pIndicators->iBarThickness = cairo_dock_get_integer_key_value (pKeyFile, "Indicators", "bar_thickness", &bFlushConfFileNeeded, 4, NULL, NULL);
+	
 	return bFlushConfFileNeeded;
 }
 
@@ -534,7 +534,7 @@ static inline void _load_active_window_indicator (const gchar *cImagePath, doubl
 			iHeight);
 	}
 }
-static inline void _load_class_indicator (const gchar *cIndicatorImagePath, double fMaxScale)
+static inline void _load_class_indicator (const gchar *cIndicatorImagePath)
 {
 	cairo_dock_unload_image_buffer (&s_classIndicatorBuffer);
 	
@@ -555,7 +555,7 @@ static void load (void)
 	
 	_load_active_window_indicator (myIndicatorsParam.cActiveIndicatorImagePath, fMaxScale, myIndicatorsParam.iActiveCornerRadius, myIndicatorsParam.iActiveLineWidth, myIndicatorsParam.fActiveColor);
 	
-	_load_class_indicator (myTaskbarParam.bShowAppli && myTaskbarParam.bGroupAppliByClass ? myIndicatorsParam.cClassIndicatorImagePath : NULL, fMaxScale);
+	_load_class_indicator (myTaskbarParam.bShowAppli && myTaskbarParam.bGroupAppliByClass ? myIndicatorsParam.cClassIndicatorImagePath : NULL);
 }
 
 
@@ -563,10 +563,17 @@ static void load (void)
  /// RELOAD ///
 //////////////
 
-static void _set_indicator (Icon *pIcon, CairoContainer *pContainer, gpointer data)
+static void _set_indicator (Icon *pIcon, G_GNUC_UNUSED CairoContainer *pContainer, gpointer data)
 {
 	pIcon->bHasIndicator = GPOINTER_TO_INT (data);
 }
+static void _reload_progress_bar (Icon *pIcon, CairoContainer *pContainer, G_GNUC_UNUSED gpointer data)
+{
+	if (cairo_dock_get_icon_data_renderer (pIcon) != NULL)
+	{
+		cairo_dock_reload_data_renderer_on_icon (pIcon, pContainer);
+	}
+}
 static void reload (CairoIndicatorsParam *pPrevIndicators, CairoIndicatorsParam *pIndicators)
 {
 	double fMaxScale = cairo_dock_get_max_scale (g_pMainDock);
@@ -593,7 +600,7 @@ static void reload (CairoIndicatorsParam *pPrevIndicators, CairoIndicatorsParam
 	if (cairo_dock_strings_differ (pPrevIndicators->cClassIndicatorImagePath, pIndicators->cClassIndicatorImagePath) ||
 		pPrevIndicators->bUseClassIndic != pIndicators->bUseClassIndic)
 	{
-		_load_class_indicator (myTaskbarParam.bShowAppli && myTaskbarParam.bGroupAppliByClass ? pIndicators->cClassIndicatorImagePath : NULL, fMaxScale);
+		_load_class_indicator (myTaskbarParam.bShowAppli && myTaskbarParam.bGroupAppliByClass ? pIndicators->cClassIndicatorImagePath : NULL);
 		
 		if (pPrevIndicators->bUseClassIndic != pIndicators->bUseClassIndic && g_pMainDock)  // on recharge les icones pointant sur une classe (qui sont dans le main dock).
 		{
@@ -618,6 +625,24 @@ static void reload (CairoIndicatorsParam *pPrevIndicators, CairoIndicatorsParam
 		cairo_dock_foreach_applis ((CairoDockForeachIconFunc) _set_indicator, FALSE, GINT_TO_POINTER (pIndicators->bDrawIndicatorOnAppli));
 	}
 	
+	if (pPrevIndicators->fBarColorStart[0] != pIndicators->fBarColorStart[0]
+	|| pPrevIndicators->fBarColorStart[1] != pIndicators->fBarColorStart[1]
+	|| pPrevIndicators->fBarColorStart[2] != pIndicators->fBarColorStart[2]
+	|| pPrevIndicators->fBarColorStart[3] != pIndicators->fBarColorStart[3]
+	|| pPrevIndicators->fBarColorStop[0] != pIndicators->fBarColorStop[0]
+	|| pPrevIndicators->fBarColorStop[1] != pIndicators->fBarColorStop[1]
+	|| pPrevIndicators->fBarColorStop[2] != pIndicators->fBarColorStop[2]
+	|| pPrevIndicators->fBarColorStop[3] != pIndicators->fBarColorStop[3]
+	|| pPrevIndicators->iBarThickness != pIndicators->iBarThickness
+	|| pPrevIndicators->bBarHasOutline != pIndicators->bBarHasOutline
+	|| pPrevIndicators->fBarColorOutline[0] != pIndicators->fBarColorOutline[0]
+	|| pPrevIndicators->fBarColorOutline[1] != pIndicators->fBarColorOutline[1]
+	|| pPrevIndicators->fBarColorOutline[2] != pIndicators->fBarColorOutline[2]
+	|| pPrevIndicators->fBarColorOutline[3] != pIndicators->fBarColorOutline[3])
+	{
+		cairo_dock_foreach_icons ((CairoDockForeachIconFunc) _reload_progress_bar, NULL);
+	}
+	
 	cairo_dock_redraw_root_docks (FALSE);  // tous les docks (main dock et les autres qui peuvent contenir des applets avec un indicateur).
 }
 
