@@ -47,8 +47,14 @@ extern CairoDock *g_pMainDock;
 extern gchar *g_cConfFile;
 extern gchar *g_cCurrentLaunchersPath;
 
-static CairoDock *_cairo_dock_handle_container (Icon *icon, const gchar *cRendererName)
+static void _cairo_dock_handle_container (Icon *icon, const gchar *cRendererName)
 {
+	if (CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon) && g_strcmp0 (icon->cName, icon->cParentDockName) == 0)  // it shouldn't happen, but if ever it does, be sure to forbid an icon pointing on itself.
+	{
+		cd_warning ("It seems we have a sub-dock in itself! => its parent dock is now the main dock");
+		cairo_dock_update_icon_s_container_name (icon, CAIRO_DOCK_MAIN_DOCK_NAME); // => to the main dock...
+	}
+
 	//\____________ On cree son container si necessaire.
 	CairoDock *pParentDock = cairo_dock_search_dock_from_name (icon->cParentDockName);
 	if (pParentDock == NULL)
@@ -88,8 +94,6 @@ static CairoDock *_cairo_dock_handle_container (Icon *icon, const gchar *cRender
 		if (icon->iSubdockViewType != 0)
 			cairo_dock_trigger_redraw_subdock_content_on_icon (icon);
 	}
-	
-	return pParentDock;
 }
 
 static void _load_launcher (Icon *icon)
@@ -191,8 +195,8 @@ Icon * cairo_dock_create_icon_from_desktop_file (const gchar *cDesktopFileName)
 	}
 	icon->iface.on_delete = _delete_launcher;
 	
-	//\____________ On gere son dock et sous-dock.
-	CairoDock *pParentDock = _cairo_dock_handle_container (icon, cRendererName);
+	//\____________ We manage its dock and sub-dock.
+	_cairo_dock_handle_container (icon, cRendererName);
 	g_free (cRendererName);
 	
 	//\____________ On remplit ses buffers.
@@ -212,7 +216,6 @@ Icon * cairo_dock_create_icon_from_desktop_file (const gchar *cDesktopFileName)
 Icon * cairo_dock_create_dummy_launcher (gchar *cName, gchar *cFileName, gchar *cCommand, gchar *cQuickInfo, double fOrder)
 {
 	//\____________ On cree l'icone.
-	gchar *cRendererName = NULL;
 	Icon *pIcon = cairo_dock_new_icon ();
 	pIcon->iTrueType = CAIRO_DOCK_ICON_TYPE_OTHER;
 	pIcon->iGroup = CAIRO_DOCK_LAUNCHER;
@@ -388,7 +391,7 @@ void cairo_dock_reload_launcher (Icon *icon)
 		icon->cName = g_strdup (" ");
 	
 	if (cairo_dock_strings_differ (cName, icon->cName))
-		cairo_dock_load_icon_text (icon, &myIconsParam.iconTextDescription);
+		cairo_dock_load_icon_text (icon);
 	
 	// set sub-dock renderer
 	if (icon->pSubDock != NULL)  // son rendu a pu changer.
@@ -426,7 +429,7 @@ void cairo_dock_reload_launcher (Icon *icon)
 
 
 
-gchar *cairo_dock_launch_command_sync (const gchar *cCommand)
+gchar *cairo_dock_launch_command_sync_with_stderr (const gchar *cCommand, gboolean bPrintStdErr)
 {
 	gchar *standard_output=NULL, *standard_error=NULL;
 	gint exit_status=0;
@@ -436,14 +439,14 @@ gchar *cairo_dock_launch_command_sync (const gchar *cCommand)
 		&standard_error,
 		&exit_status,
 		&erreur);
-	if (erreur != NULL)
+	if (erreur != NULL || !r)
 	{
 		cd_warning (erreur->message);
 		g_error_free (erreur);
 		g_free (standard_error);
 		return NULL;
 	}
-	if (standard_error != NULL && *standard_error != '\0')
+	if (bPrintStdErr && standard_error != NULL && *standard_error != '\0')
 	{
 		cd_warning (standard_error);
 	}
@@ -504,9 +507,18 @@ gboolean cairo_dock_launch_command_full (const gchar *cCommand, gchar *cWorkingD
 	
 	if (cCommandFull == NULL)
 		cCommandFull = g_strdup (cCommand);
-	
+
 	GError *erreur = NULL;
+	#if (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION < 32)
 	GThread* pThread = g_thread_create ((GThreadFunc) _cairo_dock_launch_threaded, cCommandFull, FALSE, &erreur);
+	#else
+	// The name can be useful for discriminating threads in a debugger.
+	// Some systems restrict the length of name to 16 bytes. 
+	gchar *cThreadName = g_strndup (cCommand, 15);
+	GThread* pThread = g_thread_try_new (cThreadName, (GThreadFunc) _cairo_dock_launch_threaded, cCommandFull, &erreur);
+	g_thread_unref (pThread);
+	g_free (cThreadName);
+	#endif
 	if (erreur != NULL)
 	{
 		cd_warning ("couldn't launch this command (%s : %s)", cCommandFull, erreur->message);
