@@ -29,6 +29,7 @@
 
 #include "gldi-config.h"
 #include "cairo-dock-notifications.h"
+#include "cairo-dock-icon-facility.h"
 #include "cairo-dock-dock-facility.h"  // cairo_dock_update_dock_size
 #include "cairo-dock-dock-manager.h"
 #include "cairo-dock-keyfile-utilities.h"  // cairo_dock_conf_file_needs_update
@@ -40,49 +41,20 @@
 #include "cairo-dock-animations.h"
 #include "cairo-dock-dialog-manager.h"  // cairo_dock_show_temporary_dialog_with_icon
 #include "cairo-dock-config.h"
-///#include "cairo-dock-gui-manager.h"  // cairo_dock_trigger_refresh_launcher_gui
 #include "cairo-dock-module-manager.h"
+#include "cairo-dock-data-renderer.h"
 #include "cairo-dock-module-factory.h"
 
 // dependancies
 extern gchar *g_cCurrentThemePath;
 extern int g_iMajorVersion, g_iMinorVersion, g_iMicroVersion;
 extern gboolean g_bEasterEggs;
-
-static int s_iMaxOrder = 0;
-
+extern CairoDock *g_pMainDock;
 
   /////////////////////
  /// MODULE LOADER ///
 /////////////////////
 
-static gchar *_cairo_dock_extract_default_module_name_from_path (gchar *cSoFilePath)
-{
-	gchar *ptr = g_strrstr (cSoFilePath, "/");
-	if (ptr == NULL)
-		ptr = cSoFilePath;
-	else
-		ptr ++;
-	if (strncmp (ptr, "lib", 3) == 0)
-		ptr += 3;
-
-	if (strncmp (ptr, "cd-", 3) == 0)
-		ptr += 3;
-	else if (strncmp (ptr, "cd_", 3) == 0)
-		ptr += 3;
-
-	gchar *cModuleName = g_strdup (ptr);
-
-	ptr = g_strrstr (cModuleName, ".so");
-	if (ptr != NULL)
-		*ptr = '\0';
-
-	//ptr = cModuleName;
-	//while ((ptr = g_strrstr (ptr, "-")) != NULL)
-	//	*ptr = '_';
-
-	return cModuleName;
-}
 
 static void _cairo_dock_close_module (CairoDockModule *module)
 {
@@ -101,7 +73,7 @@ static void _cairo_dock_close_module (CairoDockModule *module)
 	module->cConfFilePath = NULL;
 }
 
-static void _cairo_dock_open_module (CairoDockModule *pCairoDockModule, GError **erreur)
+static gboolean _cairo_dock_open_module (CairoDockModule *pCairoDockModule, GError **erreur)
 {
 	//\__________________ On ouvre le .so.
 	/**GModule *module = g_module_open (pCairoDockModule->cSoFilePath, G_MODULE_BIND_LAZY | G_MODULE_BIND_LOCAL);
@@ -115,10 +87,9 @@ static void _cairo_dock_open_module (CairoDockModule *pCairoDockModule, GError *
 	if (! pCairoDockModule->handle)
 	{
 		g_set_error (erreur, 1, 1, "while opening module '%s' : (%s)", pCairoDockModule->cSoFilePath, dlerror ());
-		return ;
+		return FALSE;
 	}
 	//\__________________ On identifie le module.
-	gboolean bSymbolFound;
 	CairoDockModulePreInit function_pre_init = NULL;
 	function_pre_init = dlsym (pCairoDockModule->handle, "pre_init");
 	/**bSymbolFound = g_module_symbol (module, "pre_init", (gpointer) &function_pre_init);
@@ -130,16 +101,15 @@ static void _cairo_dock_open_module (CairoDockModule *pCairoDockModule, GError *
 		gboolean bModuleLoaded = function_pre_init (pCairoDockModule->pVisitCard, pCairoDockModule->pInterface);
 		if (! bModuleLoaded)
 		{
-			_cairo_dock_close_module (pCairoDockModule);
 			cd_debug ("module '%s' has not been loaded", pCairoDockModule->cSoFilePath);  // peut arriver a xxx-integration ou icon-effect par exemple.
-			return ;
+			_cairo_dock_close_module (pCairoDockModule);
+			return FALSE;
 		}
 	}
 	else
 	{
-		pCairoDockModule->pVisitCard = NULL;
 		g_set_error (erreur, 1, 1, "this module ('%s') does not have the common entry point 'pre_init', it may be broken or icompatible with cairo-dock", pCairoDockModule->cSoFilePath);
-		return ;
+		return FALSE;
 	}
 	
 	//\__________________ On verifie sa compatibilite.
@@ -148,21 +118,16 @@ static void _cairo_dock_open_module (CairoDockModule *pCairoDockModule, GError *
 		(pVisitCard->iMajorVersionNeeded > g_iMajorVersion || (pVisitCard->iMajorVersionNeeded == g_iMajorVersion && pVisitCard->iMinorVersionNeeded > g_iMinorVersion) || (pVisitCard->iMajorVersionNeeded == g_iMajorVersion && pVisitCard->iMinorVersionNeeded == g_iMinorVersion && pVisitCard->iMicroVersionNeeded > g_iMicroVersion)))
 	{
 		g_set_error (erreur, 1, 1, "this module ('%s') needs at least Cairo-Dock v%d.%d.%d, but Cairo-Dock is in v%d.%d.%d (%s)\n  It will be ignored", pCairoDockModule->cSoFilePath, pVisitCard->iMajorVersionNeeded, pVisitCard->iMinorVersionNeeded, pVisitCard->iMicroVersionNeeded, g_iMajorVersion, g_iMinorVersion, g_iMicroVersion, GLDI_VERSION);
-		cairo_dock_free_visit_card (pCairoDockModule->pVisitCard);
-		pCairoDockModule->pVisitCard = NULL;
-		return ;
+		return FALSE;
 	}
 	if (! g_bEasterEggs &&
 		pVisitCard->cDockVersionOnCompilation != NULL && strcmp (pVisitCard->cDockVersionOnCompilation, GLDI_VERSION) != 0)  // separation des versions en easter egg.
 	{
 		g_set_error (erreur, 1, 1, "this module ('%s') was compiled with Cairo-Dock v%s, but Cairo-Dock is in v%s\n  It will be ignored", pCairoDockModule->cSoFilePath, pVisitCard->cDockVersionOnCompilation, GLDI_VERSION);
-		cairo_dock_free_visit_card (pCairoDockModule->pVisitCard);
-		pCairoDockModule->pVisitCard = NULL;
-		return ;
+		return FALSE;
 	}
-
-	if (pVisitCard->cModuleName == NULL)
-		pVisitCard->cModuleName = _cairo_dock_extract_default_module_name_from_path (pCairoDockModule->cSoFilePath);
+	
+	return TRUE;  // if we passed all the stages, the module is ready to be registered.
 }
 
 CairoDockModule *cairo_dock_new_module (const gchar *cSoFilePath, GError **erreur)
@@ -173,17 +138,14 @@ CairoDockModule *cairo_dock_new_module (const gchar *cSoFilePath, GError **erreu
 	{
 		pCairoDockModule->cSoFilePath = g_strdup (cSoFilePath);
 		GError *tmp_erreur = NULL;
-		_cairo_dock_open_module (pCairoDockModule, &tmp_erreur);
-		if (tmp_erreur != NULL)
+		gboolean bOpened = _cairo_dock_open_module (pCairoDockModule, &tmp_erreur);
+		if (! bOpened)
 		{
-			g_propagate_error (erreur, tmp_erreur);
-			g_free (pCairoDockModule->cSoFilePath);
-			g_free (pCairoDockModule);
-			return NULL;
-		}
-		if (pCairoDockModule->pVisitCard == NULL)
-		{
-			g_free (pCairoDockModule);
+			if (tmp_erreur != NULL)
+			{
+				g_propagate_error (erreur, tmp_erreur);
+			}
+			cairo_dock_free_module (pCairoDockModule);
 			return NULL;
 		}
 	}
@@ -194,10 +156,11 @@ void cairo_dock_free_module (CairoDockModule *module)
 {
 	if (module == NULL)
 		return ;
-	cd_debug ("%s (%s)", __func__, module->pVisitCard->cModuleName);
-
-	cairo_dock_deactivate_module (module);
-
+	if (module->pVisitCard)
+	{
+		cd_debug ("%s (%s)", __func__, module->pVisitCard->cModuleName);
+		cairo_dock_deactivate_module (module);
+	}
 	_cairo_dock_close_module (module);
 
 	g_free (module->cSoFilePath);
@@ -229,9 +192,6 @@ gchar *cairo_dock_check_module_conf_dir (CairoDockModule *pModule)
 		}
 	}
 	
-	if (pModule->cConfFilePath == NULL)
-		pModule->cConfFilePath = g_strdup_printf ("%s/%s", pVisitCard->cShareDataDir, pVisitCard->cConfFileName);
-	
 	return cUserDataDirPath;
 }
 
@@ -278,7 +238,6 @@ GKeyFile *cairo_dock_pre_read_module_instance_config (CairoDockModuleInstance *p
 	if (pInstance->cConfFilePath == NULL)  // aucun fichier de conf (xxx-integration par exemple).
 		return NULL;
 	gchar *cInstanceConfFilePath = pInstance->cConfFilePath;
-	CairoDockModule *pModule = pInstance->pModule;
 	
 	GKeyFile *pKeyFile = cairo_dock_open_key_file (cInstanceConfFilePath);
 	if (pKeyFile == NULL)  // fichier illisible.
@@ -315,19 +274,37 @@ GKeyFile *cairo_dock_pre_read_module_instance_config (CairoDockModuleInstance *p
 		}
 		
 		pMinimalConfig->cIconFileName = cairo_dock_get_string_key_value (pKeyFile, "Icon", "icon", NULL, NULL, NULL, NULL);
+		pMinimalConfig->cDockName = cairo_dock_get_string_key_value (pKeyFile, "Icon", "dock name", NULL, NULL, NULL, NULL);
 		pMinimalConfig->fOrder = cairo_dock_get_double_key_value (pKeyFile, "Icon", "order", NULL, CAIRO_DOCK_LAST_ORDER, NULL, NULL);
-		if (pMinimalConfig->fOrder == CAIRO_DOCK_LAST_ORDER)
+		if (pMinimalConfig->fOrder == CAIRO_DOCK_LAST_ORDER)  // no order is defined (1st activation) => place it after the last launcher/applet
 		{
-			pMinimalConfig->fOrder = ++ s_iMaxOrder;
+			GList *ic, *next_ic;
+			Icon *icon, *icon1 = NULL, *icon2 = NULL;
+			if (g_pMainDock != NULL)  // the dock is not defined too => it goes into the main dock.
+			{
+				for (ic = g_pMainDock->icons; ic != NULL; ic = ic->next)
+				{
+					icon = ic->data;
+					if (CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER (icon) || CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon) || CAIRO_DOCK_ICON_TYPE_IS_APPLET (icon))
+					{
+						icon1 = icon;
+						next_ic = ic->next;
+						icon2 = (next_ic?next_ic->data:NULL);
+					}
+				}
+			}
+			if (icon1 != NULL)
+			{
+				pMinimalConfig->fOrder = (icon2 && icon2->iGroup == CAIRO_DOCK_LAUNCHER ? (icon1->fOrder + icon2->fOrder) / 2 : icon1->fOrder + 1);
+			}
+			else
+			{
+				pMinimalConfig->fOrder = 0;
+			}
 			g_key_file_set_double (pKeyFile, "Icon", "order", pMinimalConfig->fOrder);
-			cd_debug ("set order to %.1f\n", pMinimalConfig->fOrder);
+			cd_debug ("set order to %.1f", pMinimalConfig->fOrder);
 			cairo_dock_write_keys_to_file (pKeyFile, cInstanceConfFilePath);
 		}
-		else
-		{
-			s_iMaxOrder = MAX (s_iMaxOrder, pMinimalConfig->fOrder);
-		}
-		pMinimalConfig->cDockName = cairo_dock_get_string_key_value (pKeyFile, "Icon", "dock name", NULL, NULL, NULL, NULL);
 		int iBgColorType;
 		if (g_key_file_has_key (pKeyFile, "Icon", "always_visi", NULL))
 		{
@@ -570,14 +547,12 @@ void cairo_dock_reload_module_instance (CairoDockModuleInstance *pInstance, gboo
 	CairoDockModule *module = pInstance->pModule;
 	cd_message ("%s (%s, %d)", __func__, module->pVisitCard->cModuleName, bReloadAppletConf);
 	
-	GError *erreur = NULL;
 	CairoContainer *pCurrentContainer = pInstance->pContainer;
 	pInstance->pContainer = NULL;
 	CairoDock *pCurrentDock = pInstance->pDock;
 	pInstance->pDock = NULL;
 	CairoDesklet *pCurrentDesklet = pInstance->pDesklet;
 	pInstance->pDesklet = NULL;
-	gchar *cOldDockName = NULL;
 	gchar *cCurrentSubDockName = NULL;
 	
 	CairoContainer *pNewContainer = NULL;
@@ -598,6 +573,8 @@ void cairo_dock_reload_module_instance (CairoDockModuleInstance *pInstance, gboo
 			//\______________ On met a jour les champs 'nom' et 'image' de l'icone.
 			if (pIcon != NULL)
 			{
+				if (pCurrentDock && ! pIcon->pContainer)  // icon already detached (by drag and drop)
+					pCurrentDock = NULL;
 				cCurrentSubDockName = g_strdup (pIcon->cName);
 				
 				// on gere le changement de nom de son sous-dock.
@@ -636,13 +613,19 @@ void cairo_dock_reload_module_instance (CairoDockModuleInstance *pInstance, gboo
 				pNewContainer = CAIRO_CONTAINER (pNewDock);
 			}
 			
-			// on la detache de son dock si son container a change.
-			if (pCurrentDock != NULL && (pMinimalConfig->bIsDetached || pNewDock != pCurrentDock))
+			// detach the icon from its container if it has changed
+			if (pCurrentDock != NULL && (pMinimalConfig->bIsDetached || pNewDock != pCurrentDock))  // was in a dock, now is in another dock or in a desklet
 			{
 				cd_message ("le container a change (%s -> %s)", pIcon->cParentDockName, pMinimalConfig->bIsDetached ? "desklet" : pMinimalConfig->cDockName);
-				cOldDockName = g_strdup (pIcon->cParentDockName);
 				cairo_dock_detach_icon_from_dock (pIcon, pCurrentDock);
 			}
+			else if (pCurrentDesklet != NULL && ! pMinimalConfig->bIsDetached)  // was in a desklet, now is in a dock
+			{
+				///cairo_dock_destroy_desklet (pCurrentDesklet);
+				///pCurrentDesklet = NULL;
+				pCurrentDesklet->pIcon = NULL;
+				cairo_dock_set_icon_container (pIcon, NULL);
+			}
 			
 			// on recupere son desklet (cree au besoin).
 			if (pMinimalConfig->bIsDetached)
@@ -697,7 +680,7 @@ void cairo_dock_reload_module_instance (CairoDockModuleInstance *pInstance, gboo
 		{
 			cairo_dock_resize_icon_in_dock (pIcon, pNewDock);
 			if (bReloadAppletConf)
-				cairo_dock_load_icon_text (pIcon, &myIconsParam.iconTextDescription);
+				cairo_dock_load_icon_text (pIcon);
 		}
 	}
 	
@@ -709,7 +692,7 @@ void cairo_dock_reload_module_instance (CairoDockModuleInstance *pInstance, gboo
 	}
 	
 	//\_______________________ On recharge l'instance.
-	if (bCanReload && module->pInterface->reloadModule != NULL)
+	if (bCanReload && module && module->pInterface && module->pInterface->reloadModule != NULL)
 		module->pInterface->reloadModule (pInstance, pCurrentContainer, pKeyFile);
 	
 	if (pNewDock != NULL && pNewDock->iRefCount != 0)  // on redessine l'icone pointant sur le sous-dock contenant l'applet, au cas ou son image aurait change.
@@ -728,7 +711,6 @@ void cairo_dock_reload_module_instance (CairoDockModuleInstance *pInstance, gboo
 	{
 		if (pCurrentDock->iRefCount == 0 && pCurrentDock->icons == NULL && !pCurrentDock->bIsMainDock)  // dock principal vide.
 		{
-			///cairo_dock_destroy_dock (pCurrentDock, cOldDockName);
 			pCurrentDock = NULL;  // se fera detruire automatiquement.
 		}
 		else
@@ -742,8 +724,10 @@ void cairo_dock_reload_module_instance (CairoDockModuleInstance *pInstance, gboo
 		cairo_dock_destroy_dock (pIcon->pSubDock, cCurrentSubDockName);
 		pIcon->pSubDock = NULL;
 	}
-	g_free (cOldDockName);
 	g_free (cCurrentSubDockName);
+	
+	if (! bReloadAppletConf && cairo_dock_get_icon_data_renderer (pIcon) != NULL)  // reload the data-renderer at the new size
+		cairo_dock_reload_data_renderer_on_icon (pIcon, pNewContainer);
 }
 
 
@@ -769,7 +753,7 @@ void cairo_dock_activate_module (CairoDockModule *module, GError **erreur)
 		gchar *cUserDataDirPath = cairo_dock_check_module_conf_dir (module);
 		if (cUserDataDirPath == NULL)
 		{
-			g_set_error (erreur, 1, 1, "No instance of module %s could be created", __func__, module->pVisitCard->cModuleName);
+			g_set_error (erreur, 1, 1, "No instance of module %s could be created", module->pVisitCard->cModuleName);
 			return;
 		}
 		
@@ -871,15 +855,20 @@ void cairo_dock_reload_module (CairoDockModule *pModule, gboolean bReloadAppletC
 
 void cairo_dock_popup_module_instance_description (CairoDockModuleInstance *pModuleInstance)
 {
-	gchar *cDescription = g_strdup_printf ("%s (v%s) by %s\n%s",
-		pModuleInstance->pModule->pVisitCard->cModuleName,
+	gchar *cDescription = g_strdup_printf ("%s (v%s) %s %s\n%s",
+		pModuleInstance->pModule->pVisitCard->cModuleName, // let the original name
 		pModuleInstance->pModule->pVisitCard->cModuleVersion,
+		_("by"),
 		pModuleInstance->pModule->pVisitCard->cAuthor,
 		dgettext (pModuleInstance->pModule->pVisitCard->cGettextDomain,
 		pModuleInstance->pModule->pVisitCard->cDescription));
 	
-	myDialogsParam.dialogTextDescription.bUseMarkup = TRUE;
-	cairo_dock_show_temporary_dialog_with_icon (cDescription, pModuleInstance->pIcon, pModuleInstance->pContainer, 0, pModuleInstance->pModule->pVisitCard->cIconFilePath);
+	CairoDialogAttribute attr;
+	memset (&attr, 0, sizeof (CairoDialogAttribute));
+	attr.cText = cDescription;
+	attr.cImageFilePath = pModuleInstance->pModule->pVisitCard->cIconFilePath;
+	attr.bUseMarkup = TRUE;
+	cairo_dock_build_dialog (&attr, pModuleInstance->pIcon, pModuleInstance->pContainer);
+	
 	g_free (cDescription);
-	myDialogsParam.dialogTextDescription.bUseMarkup = FALSE;
 }
