@@ -79,20 +79,20 @@ static inline gboolean _check_extension (const char *extName, const gchar *cExte
 }
 static gboolean _check_gl_extension (const char *extName)
 {
-	const gchar *glExtensions = glGetString (GL_EXTENSIONS);
+	const gchar *glExtensions = (gchar *) glGetString (GL_EXTENSIONS);
 	return _check_extension (extName, glExtensions);
 }
 static gboolean _check_client_glx_extension (const char *extName)
 {
 	Display *display = gdk_x11_get_default_xdisplay ();
-	int screen = 0;
+	//int screen = 0;
 	//const gchar *glxExtensions = glXQueryExtensionsString (display, screen);
 	const gchar *glxExtensions = glXGetClientString (display, GLX_EXTENSIONS);
 	return _check_extension (extName, glxExtensions);
 }
 
 
-static void _post_initialize_opengl_backend (GtkWidget *pWidget, CairoContainer *pContainer)  // initialisation necessitant un contexte opengl.
+static void _post_initialize_opengl_backend (G_GNUC_UNUSED GtkWidget *pWidget, CairoContainer *pContainer)  // initialisation necessitant un contexte opengl.
 {
 	g_return_if_fail (!s_bInitialized);
 	
@@ -115,7 +115,7 @@ static void _post_initialize_opengl_backend (GtkWidget *pWidget, CairoContainer
 		glTexParameterf (GL_TEXTURE_2D, GL_TEXTURE_MAX_ANISOTROPY_EXT, fMaximumAnistropy);
 	}
 	
-	cd_debug ("OpenGL config summary :\n - bNonPowerOfTwoAvailable : %d\n - bFboAvailable : %d\n - direct rendering : %d\n - bTextureFromPixmapAvailable : %d\n - bAccumBufferAvailable : %d\n - Anisotroy filtering level max : %.1f\n - OpenGL version: %s\n - OpenGL vendor: %s\n - OpenGL renderer: %s\n\n",
+	cd_message ("OpenGL config summary :\n - bNonPowerOfTwoAvailable : %d\n - bFboAvailable : %d\n - direct rendering : %d\n - bTextureFromPixmapAvailable : %d\n - bAccumBufferAvailable : %d\n - Anisotroy filtering level max : %.1f\n - OpenGL version: %s\n - OpenGL vendor: %s\n - OpenGL renderer: %s\n\n",
 		g_openglConfig.bNonPowerOfTwoAvailable,
 		g_openglConfig.bFboAvailable,
 		!g_openglConfig.bIndirectRendering,
@@ -171,7 +171,6 @@ gboolean cairo_dock_initialize_opengl_backend (gboolean bForceOpenGL)  // taken
 	
 	//\_________________ On cherche un visual qui reponde a tous les criteres.
 	GLXFBConfig *pFBConfigs;
-	XRenderPictFormat *pPictFormat = NULL;
 	int doubleBufferAttributes[] = {
 		GLX_DRAWABLE_TYPE, 		GLX_WINDOW_BIT,
 		GLX_RENDER_TYPE, 		GLX_RGBA_BIT,
@@ -302,8 +301,8 @@ gboolean cairo_dock_initialize_opengl_backend (gboolean bForceOpenGL)  // taken
 	g_openglConfig.bTextureFromPixmapAvailable = _check_client_glx_extension ("GLX_EXT_texture_from_pixmap");
 	if (g_openglConfig.bTextureFromPixmapAvailable)
 	{
-		g_openglConfig.bindTexImage = (gpointer)glXGetProcAddress ("glXBindTexImageEXT");
-		g_openglConfig.releaseTexImage = (gpointer)glXGetProcAddress ("glXReleaseTexImageEXT");
+		g_openglConfig.bindTexImage = (gpointer)glXGetProcAddress ((GLubyte *) "glXBindTexImageEXT");
+		g_openglConfig.releaseTexImage = (gpointer)glXGetProcAddress ((GLubyte *) "glXReleaseTexImageEXT");
 		g_openglConfig.bTextureFromPixmapAvailable = (g_openglConfig.bindTexImage && g_openglConfig.releaseTexImage);
 	}
 	
@@ -487,6 +486,142 @@ void cairo_dock_end_draw_icon (Icon *pIcon, CairoContainer *pContainer)
 	}
 }
 
+gboolean cairo_dock_begin_draw_image_buffer (CairoDockImageBuffer *pImage, CairoContainer *pContainer, gint iRenderingMode)
+{
+	//g_print ("%s (%s, %d)\n", __func__, pIcon->cName, iRenderingMode);
+	int iWidth, iHeight;
+	/// TODO: test without FBO and dock when iRenderingMode == 2
+	if (CAIRO_DOCK_IS_DESKLET (pContainer))
+	{
+		if (! gldi_glx_make_current (pContainer))
+		{
+			return FALSE;
+		}
+		iWidth = pContainer->iWidth;
+		iHeight = pContainer->iHeight;
+		glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+	}
+	else if (g_openglConfig.iFboId != 0)
+	{
+		// on attache la texture au FBO.
+		if (pContainer->iWidth == 1 && pContainer->iHeight == 1)  // container not yet fully resized
+		{
+			return FALSE;
+		}
+		iWidth = pImage->iWidth, iHeight = pImage->iHeight;
+		if (pContainer == NULL)
+			pContainer = g_pPrimaryContainer;
+		if (! gldi_glx_make_current (pContainer))
+		{
+			cd_warning ("couldn't set the opengl context");
+			return FALSE;
+		}
+		glBindFramebufferEXT (GL_FRAMEBUFFER_EXT, g_openglConfig.iFboId);  // on redirige sur notre FBO.
+		g_openglConfig.bRedirected = (iRenderingMode == 2);
+		glFramebufferTexture2DEXT (GL_FRAMEBUFFER_EXT,
+			GL_COLOR_ATTACHMENT0_EXT,
+			GL_TEXTURE_2D,
+			g_openglConfig.bRedirected ? g_openglConfig.iRedirectedTexture : pImage->iTexture,
+			0);  // attach the texture to FBO color attachment point.
+		
+		GLenum status = glCheckFramebufferStatusEXT (GL_FRAMEBUFFER_EXT);
+		if (status != GL_FRAMEBUFFER_COMPLETE_EXT)
+		{
+			cd_warning ("FBO not ready (tex:%d)", pImage->iTexture);
+			glBindFramebufferEXT(GL_FRAMEBUFFER_EXT, 0);  // switch back to window-system-provided framebuffer
+			glFramebufferTexture2DEXT (GL_FRAMEBUFFER_EXT,
+				GL_COLOR_ATTACHMENT0_EXT,
+				GL_TEXTURE_2D,
+				0,
+				0);
+			return FALSE;
+		}
+		
+		if (iRenderingMode != 1)
+			glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+	}
+	else
+		return FALSE;
+	
+	if (pContainer->bPerspectiveView)
+	{
+		cairo_dock_set_ortho_view (pContainer);
+		g_openglConfig.bSetPerspective = TRUE;
+	}
+	else
+	{
+		cairo_dock_set_ortho_view (pContainer);  // au demarrage, le contexte n'a pas encore de vue.
+		glLoadIdentity ();
+		glTranslatef (iWidth/2, iHeight/2, - iHeight/2);
+	}
+	
+	glColor4f(1., 1., 1., 1.);
+	
+	glScalef (1., -1., 1.);
+	
+	return TRUE;
+}
+
+void cairo_dock_end_draw_image_buffer (CairoDockImageBuffer *pImage, CairoContainer *pContainer)
+{
+	g_return_if_fail (pImage->iTexture != 0);
+	
+	if (CAIRO_DOCK_IS_DESKLET (pContainer))
+	{
+		// copie dans notre texture
+		glEnable (GL_TEXTURE_2D);
+		glBindTexture (GL_TEXTURE_2D, pImage->iTexture);
+		glTexEnvi (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
+		glEnable(GL_BLEND);
+		glBlendFunc (GL_ZERO, GL_ONE);
+		glColor4f(1., 1., 1., 1.);
+		
+		int iWidth, iHeight;  // taille de la texture
+		iWidth = pImage->iWidth, iHeight = pImage->iHeight;
+		int x = (pContainer->iWidth - iWidth)/2;
+		int y = (pContainer->iHeight - iHeight)/2;
+		glCopyTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, x, y, iWidth, iHeight, 0);  // target, num mipmap, format, x,y, w,h, border.
+		
+		glDisable (GL_TEXTURE_2D);
+		glDisable (GL_BLEND);
+	}
+	else if (g_openglConfig.iFboId != 0)
+	{
+		if (g_openglConfig.bRedirected)  // copie dans notre texture
+		{
+			glFramebufferTexture2DEXT (GL_FRAMEBUFFER_EXT,
+				GL_COLOR_ATTACHMENT0_EXT,
+				GL_TEXTURE_2D,
+				pImage->iTexture,
+				0);  // maintenant on dessine dans la texture de l'icone.
+			_cairo_dock_enable_texture ();
+			_cairo_dock_set_blend_source ();
+			
+			int iWidth, iHeight;  // taille de la texture
+			iWidth = pImage->iWidth, iHeight = pImage->iHeight;
+			
+			glLoadIdentity ();
+			glTranslatef (iWidth/2, iHeight/2, - iHeight/2);
+			_cairo_dock_apply_texture_at_size_with_alpha (g_openglConfig.iRedirectedTexture, iWidth, iHeight, 1.);
+			
+			_cairo_dock_disable_texture ();
+			g_openglConfig.bRedirected = FALSE;
+		}
+		glBindFramebufferEXT(GL_FRAMEBUFFER_EXT, 0);  // switch back to window-system-provided framebuffer
+		glFramebufferTexture2DEXT (GL_FRAMEBUFFER_EXT,
+			GL_COLOR_ATTACHMENT0_EXT,
+			GL_TEXTURE_2D,
+			0,
+			0);  // on detache la texture (precaution).
+		//glGenerateMipmapEXT(GL_TEXTURE_2D);  // si on utilise les mipmaps, il faut les generer explicitement avec les FBO.
+	}
+	
+	if (pContainer && g_openglConfig.bSetPerspective)
+	{
+		cairo_dock_set_perspective_view (pContainer);
+		g_openglConfig.bSetPerspective = FALSE;
+	}
+}
 
 
 static inline void _cairo_dock_set_perspective_view (int iWidth, int iHeight)
@@ -520,7 +655,7 @@ void cairo_dock_set_perspective_view (CairoContainer *pContainer)
 	pContainer->bPerspectiveView = TRUE;
 }
 
-void cairo_dock_set_perspective_view_for_icon (Icon *pIcon, CairoContainer *pContainer)
+void cairo_dock_set_perspective_view_for_icon (Icon *pIcon, G_GNUC_UNUSED CairoContainer *pContainer)
 {
 	int w, h;
 	cairo_dock_get_icon_extent (pIcon, &w, &h);
@@ -558,7 +693,7 @@ void cairo_dock_set_ortho_view (CairoContainer *pContainer)
 	pContainer->bPerspectiveView = FALSE;
 }
 
-void cairo_dock_set_ortho_view_for_icon (Icon *pIcon, CairoContainer *pContainer)
+void cairo_dock_set_ortho_view_for_icon (Icon *pIcon, G_GNUC_UNUSED CairoContainer *pContainer)
 {
 	int w, h;
 	cairo_dock_get_icon_extent (pIcon, &w, &h);
@@ -651,7 +786,7 @@ void gldi_glx_end_draw_container (CairoContainer *pContainer)
 	glXSwapBuffers (dpy, Xid);
 }
 
-static void _init_opengl_context (GtkWidget* pWidget, CairoContainer *pContainer)
+static void _init_opengl_context (G_GNUC_UNUSED GtkWidget* pWidget, CairoContainer *pContainer)
 {
 	if (! g_bUseOpenGL)
 		return ;
