@@ -28,6 +28,7 @@
 #include "cairo-dock-draw-opengl.h"
 #include "cairo-dock-image-buffer.h"
 #include "cairo-dock-log.h"
+#include "cairo-dock-notifications.h"
 #include "cairo-dock-overlay.h"
 
 extern gboolean g_bUseOpenGL;
@@ -39,25 +40,28 @@ extern gboolean g_bUseOpenGL;
  /// CREATE / FREE ///
 /////////////////////
 
-CairoOverlay *cairo_dock_create_overlay_from_image (Icon *pIcon, const gchar *cImageFile)
+static inline CairoOverlay *_new_overlay (void)
 {
 	CairoOverlay *pOverlay = g_new0 (CairoOverlay, 1);
+	pOverlay->object.ref = 1;
+	cairo_dock_install_notifications_on_object (pOverlay, NB_NOTIFICATIONS_OBJECT);
+	return pOverlay;
+}
+
+static CairoOverlay *cairo_dock_create_overlay_from_image (Icon *pIcon, const gchar *cImageFile)
+{
+	CairoOverlay *pOverlay = _new_overlay ();
 	pOverlay->fScale = CD_DEFAULT_SCALE;
 	
 	int iWidth, iHeight;
 	cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
 	cairo_dock_load_image_buffer (&pOverlay->image, cImageFile, iWidth * pOverlay->fScale, iHeight * pOverlay->fScale, 0);
-	if (pOverlay->image.pSurface == NULL)
-	{
-		g_free (pOverlay);
-		return NULL;
-	}
 	return pOverlay;
 }
 
-CairoOverlay *cairo_dock_create_overlay_from_surface (Icon *pIcon, cairo_surface_t *pSurface, int iWidth, int iHeight)
+static CairoOverlay *cairo_dock_create_overlay_from_surface (Icon *pIcon, cairo_surface_t *pSurface, int iWidth, int iHeight)
 {
-	CairoOverlay *pOverlay = g_new0 (CairoOverlay, 1);
+	CairoOverlay *pOverlay = _new_overlay ();
 	pOverlay->fScale = CD_DEFAULT_SCALE;
 	
 	int w, h;
@@ -67,9 +71,9 @@ CairoOverlay *cairo_dock_create_overlay_from_surface (Icon *pIcon, cairo_surface
 	return pOverlay;
 }
 
-CairoOverlay *cairo_dock_create_overlay_from_texture (Icon *pIcon, GLuint iTexture, int iWidth, int iHeight)
+static CairoOverlay *cairo_dock_create_overlay_from_texture (GLuint iTexture, int iWidth, int iHeight)
 {
-	CairoOverlay *pOverlay = g_new0 (CairoOverlay, 1);
+	CairoOverlay *pOverlay = _new_overlay ();
 	pOverlay->fScale = CD_DEFAULT_SCALE;
 	
 	cairo_dock_load_image_buffer_from_texture (&pOverlay->image, iTexture);
@@ -79,10 +83,11 @@ CairoOverlay *cairo_dock_create_overlay_from_texture (Icon *pIcon, GLuint iTextu
 	return pOverlay;
 }
 
-void cairo_dock_free_overlay (CairoOverlay *pOverlay)
+static void cairo_dock_free_overlay (CairoOverlay *pOverlay)
 {
 	if (!pOverlay)
 		return;
+	cairo_dock_notify_on_object (pOverlay, NOTIFICATION_DESTROY, pOverlay);
 	cairo_dock_unload_image_buffer (&pOverlay->image);
 	g_free (pOverlay);
 }
@@ -92,75 +97,109 @@ void cairo_dock_free_overlay (CairoOverlay *pOverlay)
  /// ADD / REMOVE ///
 ////////////////////
 
-void cairo_dock_add_overlay_to_icon (Icon *pIcon, CairoOverlay *pOverlay, CairoOverlayPosition iPosition)
+static inline void cairo_dock_add_overlay_to_icon (Icon *pIcon, CairoOverlay *pOverlay, CairoOverlayPosition iPosition, gpointer data)
 {
 	if (! pOverlay)
 		return;
 	
+	// complete the overlay
 	pOverlay->iPosition = iPosition;
+	pOverlay->data = data;
+	pOverlay->pIcon = pIcon;  // overlays are stucked to their icon.
 	
-	cairo_dock_remove_overlay_at_position (pIcon, iPosition);
+	// remove any overlay that matches the couple (position, data).
+	if (data != NULL)
+	{
+		GList* ov = pIcon->pOverlays, *next_ov;
+		CairoOverlay *p;
+		while (ov)
+		{
+			p = ov->data;
+			next_ov = ov->next;  // get the next element now, since this one may be deleted during this iteration.
+			
+			if (p->data == data && p->iPosition == iPosition)  // same position and same origin => remove
+			{
+				pIcon->pOverlays = g_list_delete_link (pIcon->pOverlays, ov);
+				cairo_dock_free_overlay (p);
+			}
+			ov = next_ov;
+		}
+	}
 	
+	// add the new overlay to the icon
 	pIcon->pOverlays = g_list_prepend (pIcon->pOverlays, pOverlay);
 }
 
-gboolean cairo_dock_add_overlay_from_image (Icon *pIcon, const gchar *cImageFile, CairoOverlayPosition iPosition)
+CairoOverlay *cairo_dock_add_overlay_from_image (Icon *pIcon, const gchar *cImageFile, CairoOverlayPosition iPosition, gpointer data)
 {
 	CairoOverlay *pOverlay = cairo_dock_create_overlay_from_image (pIcon, cImageFile);
-	if (! pOverlay)
-		return FALSE;
 	
-	cairo_dock_add_overlay_to_icon (pIcon, pOverlay, iPosition);
+	cairo_dock_add_overlay_to_icon (pIcon, pOverlay, iPosition, data);
 	
-	return TRUE;
+	return pOverlay;
 }
 
-void cairo_dock_add_overlay_from_surface (Icon *pIcon, cairo_surface_t *pSurface, int iWidth, int iHeight, CairoOverlayPosition iPosition)
+CairoOverlay *cairo_dock_add_overlay_from_surface (Icon *pIcon, cairo_surface_t *pSurface, int iWidth, int iHeight, CairoOverlayPosition iPosition, gpointer data)
 {
 	CairoOverlay *pOverlay = cairo_dock_create_overlay_from_surface (pIcon, pSurface, iWidth, iHeight);
 	
-	cairo_dock_add_overlay_to_icon (pIcon, pOverlay, iPosition);
-}
-
-void cairo_dock_add_overlay_from_texture (Icon *pIcon, GLuint iTexture, CairoOverlayPosition iPosition)
-{
-	CairoOverlay *pOverlay = cairo_dock_create_overlay_from_texture (pIcon, iTexture, 0, 0);
+	cairo_dock_add_overlay_to_icon (pIcon, pOverlay, iPosition, data);
 	
-	cairo_dock_add_overlay_to_icon (pIcon, pOverlay, iPosition);
+	return pOverlay;
 }
 
-void cairo_dock_remove_overlay_at_position (Icon *pIcon, CairoOverlayPosition iPosition)
+CairoOverlay *cairo_dock_add_overlay_from_texture (Icon *pIcon, GLuint iTexture, CairoOverlayPosition iPosition, gpointer data)
 {
-	GList* ov;
+	CairoOverlay *pOverlay = cairo_dock_create_overlay_from_texture (iTexture, 0, 0);
+	
+	cairo_dock_add_overlay_to_icon (pIcon, pOverlay, iPosition, data);
+	
+	return pOverlay;
+}
+
+
+void cairo_dock_destroy_overlay (CairoOverlay *pOverlay)
+{
+	if (! pOverlay)
+		return;
+	
+	// detach the overlay from the icon
+	Icon *pIcon = pOverlay->pIcon;
+	if (pIcon)
+	{
+		pIcon->pOverlays = g_list_remove (pIcon->pOverlays, pOverlay);
+	}
+	
+	// free the overlay
+	cairo_dock_free_overlay (pOverlay);
+}
+
+
+void cairo_dock_remove_overlay_at_position (Icon *pIcon, CairoOverlayPosition iPosition, gpointer data)
+{
+	if (! pIcon)
+		return;
+	g_return_if_fail (data != NULL);  // a NULL data can't be used to identify an overlay.
+	
+	GList* ov = pIcon->pOverlays, *next_ov;
 	CairoOverlay *p;
-	for (ov = pIcon->pOverlays; ov != NULL; ov = ov->next)
+	while (ov)
 	{
 		p = ov->data;
-		if (p->iPosition == iPosition)
+		next_ov = ov->next;  // get the next element now, since this one may be deleted during this iteration.
+		
+		if (p->data == data && p->iPosition == iPosition)  // same position and same origin => remove
 		{
-			pIcon->pOverlays = g_list_delete_link (pIcon->pOverlays, ov);  // it's ok to do that since we break from the loop after that.
+			pIcon->pOverlays = g_list_delete_link (pIcon->pOverlays, ov);
 			cairo_dock_free_overlay (p);
-			break;
 		}
+		ov = next_ov;
 	}
 }
 
-
-CairoDockImageBuffer *cairo_dock_get_overlay_buffer_at_position (Icon *pIcon, CairoOverlayPosition iPosition)
-{
-	GList* ov;
-	CairoOverlay *p;
-	for (ov = pIcon->pOverlays; ov != NULL; ov = ov->next)
-	{
-		p = ov->data;
-		if (p->iPosition == iPosition)
-		{
-			return &p->image;
-		}
-	}
-	return NULL;
-}
-
+  /////////////////////
+ /// ICON OVERLAYS ///
+/////////////////////
 
 void cairo_dock_destroy_icon_overlays (Icon *pIcon)
 {
@@ -170,10 +209,6 @@ void cairo_dock_destroy_icon_overlays (Icon *pIcon)
 }
 
 
-  ////////////
- /// DRAW ///
-////////////
-
 static void _get_overlay_position_and_size (CairoOverlay *pOverlay, int w, int h, int *x, int *y, int *wo, int *ho)  // from the center of the icon.
 {
 	if (pOverlay->fScale > 0)
@@ -263,21 +298,22 @@ void cairo_dock_draw_icon_overlays_cairo (Icon *pIcon, double fRatio, cairo_t *p
 		// translate to the overlay top-left corner.
 		cairo_translate (pCairoContext,
 			x - wo/2 - 1,  /// -1 to compensate the round errors; TODO: use double
-			- y - ho/2 + 1);
+			- y - ho/2. + 1);
 		
 		// draw.
 		cairo_scale (pCairoContext,
 			(double) wo / p->image.iWidth,
 			(double) ho / p->image.iHeight);
 		
-		cairo_set_source_surface (pCairoContext,
+		cairo_dock_apply_image_buffer_surface_with_offset (&p->image, pCairoContext, 0., 0., pIcon->fAlpha);
+		/**cairo_set_source_surface (pCairoContext,
 			p->image.pSurface,
 			0,
 			0);
 		if (pIcon->fAlpha == 1)
 			cairo_paint (pCairoContext);
 		else
-			cairo_paint_with_alpha (pCairoContext, pIcon->fAlpha);
+			cairo_paint_with_alpha (pCairoContext, pIcon->fAlpha);*/
 		
 		cairo_restore (pCairoContext);
 	}
@@ -290,7 +326,7 @@ void cairo_dock_draw_icon_overlays_opengl (Icon *pIcon, double fRatio)
 	
 	int w, h;
 	cairo_dock_get_icon_extent (pIcon, &w, &h);
-	double fMaxScale = (pIcon->fHeight != 0 ? (pIcon->pContainer && pIcon->pContainer->bIsHorizontal ? pIcon->iImageHeight : pIcon->iImageWidth) / pIcon->fHeight : 1.);
+	double fMaxScale = cairo_dock_get_icon_max_scale (pIcon);
 	
 	GList* ov;
 	CairoOverlay *p;
@@ -317,10 +353,18 @@ void cairo_dock_draw_icon_overlays_opengl (Icon *pIcon, double fRatio)
 			0.);
 		
 		// draw.
-		cairo_dock_draw_texture_with_alpha (p->image.iTexture,
+		/**cairo_dock_draw_texture_with_alpha (p->image.iTexture,
 			wo,
 			ho,
-			pIcon->fAlpha);
+			pIcon->fAlpha);*/
+		_cairo_dock_enable_texture ();
+		_cairo_dock_set_blend_over ();
+		_cairo_dock_set_alpha (pIcon->fAlpha);
+		glScalef ((double)wo / p->image.iWidth,
+			(double)ho / p->image.iHeight,
+			1.);
+		cairo_dock_apply_image_buffer_texture (&p->image);
+		_cairo_dock_disable_texture ();
 		glPopMatrix ();
 	}
 }
@@ -330,14 +374,14 @@ void cairo_dock_draw_icon_overlays_opengl (Icon *pIcon, double fRatio)
  /// PRINT ///
 /////////////
 
-void cairo_dock_print_overlay_on_icon (Icon *pIcon, CairoContainer *pContainer, CairoOverlay *pOverlay, CairoOverlayPosition iPosition)
+static void cairo_dock_print_overlay_on_icon (Icon *pIcon, CairoContainer *pContainer, CairoOverlay *pOverlay, CairoOverlayPosition iPosition)
 {
 	if (! pOverlay)
 		return;
 	
 	int w, h;
 	cairo_dock_get_icon_extent (pIcon, &w, &h);
-	//g_print ("%s (%dx%d, %p)\n", __func__, w, h, pContainer);
+	//g_print ("%s (%dx%d, %d, %p)\n", __func__, w, h, iPosition, pContainer);
 	
 	int x, y;  // relatively to the icon center.
 	int wo, ho;  // overlay size
@@ -346,17 +390,24 @@ void cairo_dock_print_overlay_on_icon (Icon *pIcon, CairoContainer *pContainer,
 	
 	if (pIcon->iIconTexture != 0 && pOverlay->image.iTexture != 0)  // dessin opengl : on dessine sur la texture de l'icone avec le mecanisme habituel.
 	{
+		/// TODO: handle the case where the drawing is not yet possible (container not yet sized).
 		if (! cairo_dock_begin_draw_icon (pIcon, pContainer, 1))  // 1 = keep current drawing
 			return ;
 		
+		glPushMatrix ();
 		_cairo_dock_enable_texture ();
 		
 		_cairo_dock_set_blend_alpha ();
-		
-		glBindTexture (GL_TEXTURE_2D, pOverlay->image.iTexture);
-		_cairo_dock_apply_current_texture_at_size_with_offset (wo, ho, x, y);
+		///glBindTexture (GL_TEXTURE_2D, pOverlay->image.iTexture);
+		///_cairo_dock_apply_current_texture_at_size_with_offset (wo, ho, x, y);
+		glTranslatef (x, y, 0);
+		glScalef ((double)wo / pOverlay->image.iWidth,
+			(double)ho / pOverlay->image.iHeight,
+			1.);
+		cairo_dock_apply_image_buffer_texture (&pOverlay->image);
 		
 		_cairo_dock_disable_texture ();
+		glPopMatrix ();
 		
 		cairo_dock_end_draw_icon (pIcon, pContainer);
 	}
@@ -373,10 +424,11 @@ void cairo_dock_print_overlay_on_icon (Icon *pIcon, CairoContainer *pContainer,
 			(double) wo / pOverlay->image.iWidth,
 			(double) ho / pOverlay->image.iHeight);
 		
-		cairo_set_source_surface (pCairoContext,
+		cairo_dock_apply_image_buffer_surface_with_offset (&pOverlay->image, pCairoContext, 0., 0., 1);
+		/**cairo_set_source_surface (pCairoContext,
 			pOverlay->image.pSurface,
 			0,
-			0);
+			0);*/
 		cairo_paint (pCairoContext);
 		
 		cairo_destroy (pCairoContext);
@@ -407,7 +459,7 @@ void cairo_dock_print_overlay_on_icon_from_surface (Icon *pIcon, CairoContainer
 
 void cairo_dock_print_overlay_on_icon_from_texture (Icon *pIcon, CairoContainer *pContainer, GLuint iTexture, CairoOverlayPosition iPosition)
 {
-	CairoOverlay *pOverlay = cairo_dock_create_overlay_from_texture (pIcon, iTexture, 0, 0);
+	CairoOverlay *pOverlay = cairo_dock_create_overlay_from_texture (iTexture, 0, 0);
 	
 	cairo_dock_print_overlay_on_icon (pIcon, pContainer, pOverlay, iPosition);
 	
