@@ -69,6 +69,31 @@ extern CairoDock *g_pMainDock;
 #define CAIRO_DOCK_LOCAL_ICONS_DIR "icons"
 #define CAIRO_DOCK_LOCAL_IMAGES_DIR "images"
 
+
+static gchar * _replace_slash_by_underscore (gchar *cName)
+{
+	g_return_val_if_fail (cName != NULL, NULL);
+
+	for (int i = 0; cName[i] != '\0'; i++)
+	{
+		if (cName[i] == '/' || cName[i] == '$')
+			cName[i] = '_';
+	}
+
+	return cName;
+}
+
+/** Escapes the special characters '\b', '\f', '\n', '\r', '\t', '\v', '\' and '"' in the string source by inserting a '\' before them and replaces '/' and '$' by '_'
+ * @param cOldName name of a filename
+ * @return a newly-allocated copy of source with certain characters escaped. See above.
+ */
+static gchar * _escape_string_for_filename (const gchar *cOldName)
+{
+	gchar *cNewName = g_strescape (cOldName, NULL);
+
+	return _replace_slash_by_underscore (cNewName);
+}
+
 void cairo_dock_mark_current_theme_as_modified (gboolean bModified)
 {
 	gchar *cModifiedFile = g_strdup_printf ("%s/%s", g_cCairoDockDataDir, CAIRO_DOCK_MODIFIED_THEME_FILE);
@@ -104,17 +129,22 @@ gboolean cairo_dock_current_theme_need_save (void)
 gboolean cairo_dock_export_current_theme (const gchar *cNewThemeName, gboolean bSaveBehavior, gboolean bSaveLaunchers)
 {
 	g_return_val_if_fail (cNewThemeName != NULL, FALSE);
+
+	gchar *cNewThemeNameWithoutSlashes = _replace_slash_by_underscore (g_strdup (cNewThemeName));
 	
-	cairo_dock_extract_package_type_from_name (cNewThemeName);
-	
-	cd_message ("on sauvegarde dans %s", cNewThemeName);
+	cairo_dock_extract_package_type_from_name (cNewThemeNameWithoutSlashes);
+
+	gchar *cNewThemeNameEscaped = g_strescape (cNewThemeNameWithoutSlashes, NULL);
+
+	cd_message ("we save in %s", cNewThemeNameWithoutSlashes);
 	GString *sCommand = g_string_new ("");
 	gboolean bThemeSaved = FALSE;
 	int r;
-	gchar *cNewThemePath = g_strdup_printf ("%s/%s", g_cThemesDirPath, cNewThemeName);
+	gchar *cNewThemePath = g_strdup_printf ("%s/%s", g_cThemesDirPath, cNewThemeNameWithoutSlashes);
+	gchar *cNewThemePathEscaped = g_strdup_printf ("%s/%s", g_cThemesDirPath, cNewThemeNameEscaped);
 	if (g_file_test (cNewThemePath, G_FILE_TEST_EXISTS))  // on ecrase un theme existant.
 	{
-		cd_debug ("  le theme existant sera mis a jour");
+		cd_debug ("  This theme will be updated");
 		gchar *cQuestion = g_strdup_printf (_("Are you sure you want to overwrite theme %s?"), cNewThemeName);
 		int answer = cairo_dock_ask_general_question_and_wait (cQuestion);
 		g_free (cQuestion);
@@ -125,13 +155,9 @@ gboolean cairo_dock_export_current_theme (const gchar *cNewThemeName, gboolean b
 			if (bSaveBehavior)
 			{
 				cairo_dock_copy_file (g_cConfFile, cNewConfFilePath);
-				/**g_string_printf (sCommand, "/bin/cp \"%s\" \"%s\"", g_cConfFile, cNewConfFilePath);
-				cd_message ("%s", sCommand->str);
-				r = system (sCommand->str);*/
 			}
 			else
 			{
-				///cairo_dock_replace_keys_by_identifier (cNewConfFilePath, g_cConfFile, '+');
 				cairo_dock_merge_conf_files (cNewConfFilePath, g_cConfFile, '+');
 			}
 			g_free (cNewConfFilePath);
@@ -139,40 +165,51 @@ gboolean cairo_dock_export_current_theme (const gchar *cNewThemeName, gboolean b
 			//\___________________ On traite les lanceurs.
 			if (bSaveLaunchers)
 			{
-				g_string_printf (sCommand, "rm -f \"%s/%s\"/*", cNewThemePath, CAIRO_DOCK_LAUNCHERS_DIR);
+				g_string_printf (sCommand, "rm -f \"%s/%s\"/*", cNewThemePathEscaped, CAIRO_DOCK_LAUNCHERS_DIR);
 				cd_message ("%s", sCommand->str);
 				r = system (sCommand->str);
+				if (r < 0)
+					cd_warning ("Not able to launch this command: %s", sCommand->str);
 				
-				g_string_printf (sCommand, "cp \"%s\"/* \"%s/%s\"", g_cCurrentLaunchersPath, cNewThemePath, CAIRO_DOCK_LAUNCHERS_DIR);
+				g_string_printf (sCommand, "cp \"%s\"/* \"%s/%s\"", g_cCurrentLaunchersPath, cNewThemePathEscaped, CAIRO_DOCK_LAUNCHERS_DIR);
 				cd_message ("%s", sCommand->str);
 				r = system (sCommand->str);
+				if (r < 0)
+					cd_warning ("Not able to launch this command: %s", sCommand->str);
 			}
 			
 			//\___________________ On traite tous le reste.
 			/// TODO : traiter les .conf des applets comme celui du dock...
-			g_string_printf (sCommand, "find \"%s\" -mindepth 1 -maxdepth 1  ! -name '%s' ! -name \"%s\" -exec /bin/cp -r '{}' \"%s\" \\;", g_cCurrentThemePath, CAIRO_DOCK_CONF_FILE, CAIRO_DOCK_LAUNCHERS_DIR, cNewThemePath);
+			g_string_printf (sCommand, "find \"%s\" -mindepth 1 -maxdepth 1  ! -name '%s' ! -name \"%s\" -exec /bin/cp -r '{}' \"%s\" \\;", g_cCurrentThemePath, CAIRO_DOCK_CONF_FILE, CAIRO_DOCK_LAUNCHERS_DIR, cNewThemePathEscaped);
 			cd_message ("%s", sCommand->str);
 			r = system (sCommand->str);
+			if (r < 0)
+				cd_warning ("Not able to launch this command: %s", sCommand->str);
 
 			bThemeSaved = TRUE;
 		}
 	}
 	else  // sinon on sauvegarde le repertoire courant tout simplement.
 	{
-		cd_debug ("  creation du nouveau theme (%s)", cNewThemePath);
+		cd_debug ("  creation of the new theme (%s)", cNewThemePath);
 
 		if (g_mkdir (cNewThemePath, 7*8*8+7*8+5) == 0)
 		{
-			g_string_printf (sCommand, "cp -r \"%s\"/* \"%s\"", g_cCurrentThemePath, cNewThemePath);
+			g_string_printf (sCommand, "cp -r \"%s\"/* \"%s\"", g_cCurrentThemePath, cNewThemePathEscaped);
 			cd_message ("%s", sCommand->str);
 			r = system (sCommand->str);
+			if (r < 0)
+				cd_warning ("Not able to launch this command: %s", sCommand->str);
 
 			bThemeSaved = TRUE;
 		}
 		else
 			cd_warning ("couldn't create %s", cNewThemePath);
 	}
-	
+
+	g_free (cNewThemeNameEscaped);
+	g_free (cNewThemeNameWithoutSlashes);
+
 	//\___________________ On conserve la date de derniere modif.
 	time_t epoch = (time_t) time (NULL);
 	struct tm currentTime;
@@ -188,7 +225,7 @@ gboolean cairo_dock_export_current_theme (const gchar *cNewThemeName, gboolean b
 	g_free (cReadmeFile);
 	g_free (cMessage);
 	
-	g_string_printf (sCommand, "rm -f \"%s/last-modif\"", cNewThemePath);
+	g_string_printf (sCommand, "rm -f \"%s/last-modif\"", cNewThemePathEscaped);
 	r = system (sCommand->str);
 	
 	//\___________________ make a preview of the current main dock.
@@ -198,6 +235,7 @@ gboolean cairo_dock_export_current_theme (const gchar *cNewThemeName, gboolean b
 	
 	//\___________________ Le theme n'est plus en etat 'modifie'.
 	g_free (cNewThemePath);
+	g_free (cNewThemePathEscaped);
 	if (bThemeSaved)
 	{
 		cairo_dock_mark_current_theme_as_modified (FALSE);
@@ -211,26 +249,32 @@ gboolean cairo_dock_export_current_theme (const gchar *cNewThemeName, gboolean b
 gboolean cairo_dock_package_current_theme (const gchar *cThemeName)
 {
 	g_return_val_if_fail (cThemeName != NULL, FALSE);
+
+	gchar *cNewThemeName = _escape_string_for_filename (cThemeName);
 	
-	cairo_dock_extract_package_type_from_name (cThemeName);
+	cairo_dock_extract_package_type_from_name (cNewThemeName);
 	
 	cd_message ("building theme package ...");
 	int r;
-	if (g_file_test (GLDI_BIN_DIR"/cairo-dock-package-theme", G_FILE_TEST_EXISTS))
+	if (g_file_test (GLDI_SHARE_DATA_DIR"/scripts/cairo-dock-package-theme.sh", G_FILE_TEST_EXISTS))
 	{
 		gchar *cCommand;
 		const gchar *cTerm = g_getenv ("TERM");
 		if (cTerm == NULL || *cTerm == '\0')
-			cCommand = g_strdup_printf ("xterm -e %s \"%s\"", "cairo-dock-package-theme", cThemeName);
+			cCommand = g_strdup_printf ("xterm -e %s \"%s\"", GLDI_SHARE_DATA_DIR"/scripts/cairo-dock-package-theme.sh", cNewThemeName);
 		else
-			cCommand = g_strdup_printf ("$TERM -e '%s \"%s\"'", "cairo-dock-package-theme", cThemeName);
+			cCommand = g_strdup_printf ("$TERM -e '%s \"%s\"'", GLDI_SHARE_DATA_DIR"/scripts/cairo-dock-package-theme.sh", cNewThemeName);
 		r = system (cCommand);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", cCommand);
 		g_free (cCommand);
+		g_free (cNewThemeName);
 		return TRUE;
 	}
 	else
 	{
 		cd_warning ("the package builder script was not found !");
+		g_free (cNewThemeName);
 		return FALSE;
 	}
 }
@@ -274,14 +318,20 @@ gboolean cairo_dock_delete_themes (gchar **cThemesList)
 		int i, r;
 		for (i = 0; cThemesList[i] != NULL; i ++)
 		{
-			cThemeName = cThemesList[i];
+			cThemeName = _escape_string_for_filename (cThemesList[i]);
 			if (*cThemeName == '\0')
+			{
+				g_free (cThemeName);
 				continue;
+			}
 			cairo_dock_extract_package_type_from_name (cThemeName);
 			
 			bThemeDeleted = TRUE;
 			g_string_printf (sCommand, "rm -rf \"%s/%s\"", g_cThemesDirPath, cThemeName);
-			r = system (sCommand->str);  // g_rmdir n'efface qu'un repertoire vide.
+			r = system (sCommand->str);  // g_rmdir only delete an empty dir...
+			if (r < 0)
+				cd_warning ("Not able to launch this command: %s", sCommand->str);
+			g_free (cThemeName);
 		}
 	}
 	
@@ -289,15 +339,15 @@ gboolean cairo_dock_delete_themes (gchar **cThemesList)
 	return bThemeDeleted;
 }
 
-static gboolean _find_module_from_user_data_dir (gchar *cModuleName, CairoDockModule *pModule, const gchar *cUserDataDirName)
+static gboolean _find_module_from_user_data_dir (G_GNUC_UNUSED gchar *cModuleName, CairoDockModule *pModule, const gchar *cUserDataDirName)
 {
 	if (pModule->pVisitCard->cUserDataDir && strcmp (cUserDataDirName, pModule->pVisitCard->cUserDataDir) == 0)
 		return TRUE;
 	return FALSE;
 }
-gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavior, gboolean bLoadLaunchers)
+
+static gchar *_cairo_dock_get_theme_path (const gchar *cThemeName)  // a theme name or a package URL, both distant or local
 {
-	//\___________________ On obtient le chemin du nouveau theme (telecharge ou decompresse si necessaire).
 	gchar *cNewThemeName = g_strdup (cThemeName);
 	gchar *cNewThemePath = NULL;
 	
@@ -310,50 +360,33 @@ gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavio
 	
 	if (g_str_has_suffix (cNewThemeName, ".tar.gz") || g_str_has_suffix (cNewThemeName, ".tar.bz2") || g_str_has_suffix (cNewThemeName, ".tgz"))  // c'est un paquet.
 	{
-		cd_debug ("c'est un paquet");
+		cd_debug ("it's a tarball");
 		cNewThemePath = cairo_dock_depackage_theme (cNewThemeName);
-		
-		g_return_val_if_fail (cNewThemePath != NULL, FALSE);
-		gchar *tmp = cNewThemeName;
-		cNewThemeName = g_path_get_basename (cNewThemePath);
-		g_free (tmp);
 	}
 	else  // c'est un theme officiel.
 	{
-		cd_debug ("c'est un theme officiel");
+		cd_debug ("it's an official theme");
 		cNewThemePath = cairo_dock_get_package_path (cNewThemeName, s_cLocalThemeDirPath, g_cThemesDirPath, s_cDistantThemeDirName, CAIRO_DOCK_ANY_PACKAGE);
 	}
+	g_free (cNewThemeName);
+	return cNewThemePath;
+}
+
+static gboolean _cairo_dock_import_local_theme (const gchar *cNewThemePath, gboolean bLoadBehavior, gboolean bLoadLaunchers)
+{
 	g_return_val_if_fail (cNewThemePath != NULL && g_file_test (cNewThemePath, G_FILE_TEST_EXISTS), FALSE);
-	//g_print ("cNewThemePath : %s ; cNewThemeName : %s\n", cNewThemePath, cNewThemeName);
 	
 	//\___________________ On charge les parametres de comportement globaux et de chaque dock.
 	GString *sCommand = g_string_new ("");
 	int r;
-	/**cd_message ("Applying changes ...");
-	if (g_pMainDock == NULL || bLoadBehavior)
-	{
-		g_string_printf (sCommand, "/bin/cp \"%s\"/%s \"%s\"", cNewThemePath, CAIRO_DOCK_CONF_FILE, g_cCurrentThemePath);
-		cd_message ("%s", sCommand->str);
-		r = system (sCommand->str);
-	}
-	else
-	{
-		gchar *cNewConfFilePath = g_strdup_printf ("%s/%s", cNewThemePath, CAIRO_DOCK_CONF_FILE);
-		///cairo_dock_replace_keys_by_identifier (g_cConfFile, cNewConfFilePath, '+');
-		cairo_dock_merge_conf_files (g_cConfFile, cNewConfFilePath, '+');
-		g_free (cNewConfFilePath);
-	}
-	
-	g_string_printf (sCommand, "find \"%s\" -mindepth 1 -maxdepth 1 -name '*.conf' ! -name '%s' -exec /bin/cp '{}' \"%s\" \\;", cNewThemePath, CAIRO_DOCK_CONF_FILE, g_cCurrentThemePath);
-	cd_debug ("%s", sCommand->str);
-	r = system (sCommand->str);*/
-	
 	cd_message ("Applying changes ...");
 	if (g_pMainDock == NULL || bLoadBehavior)
 	{
 		g_string_printf (sCommand, "cp \"%s\"/*.conf \"%s\"", cNewThemePath, g_cCurrentThemePath);
 		cd_debug ("%s", sCommand->str);
 		r = system (sCommand->str);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", sCommand->str);
 	}
 	else
 	{
@@ -387,16 +420,24 @@ gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavio
 		g_string_printf (sCommand, "rm -f \"%s\"/*", g_cCurrentIconsPath);
 		cd_debug ("%s", sCommand->str);
 		r = system (sCommand->str);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", sCommand->str);
 		g_string_printf (sCommand, "rm -f \"%s\"/.*", g_cCurrentIconsPath);
 		cd_debug ("%s", sCommand->str);
 		r = system (sCommand->str);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", sCommand->str);
 		
 		g_string_printf (sCommand, "rm -f \"%s\"/*", g_cCurrentImagesPath);
 		cd_debug ("%s", sCommand->str);
 		r = system (sCommand->str);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", sCommand->str);
 		g_string_printf (sCommand, "rm -f \"%s\"/.*", g_cCurrentImagesPath);
 		cd_debug ("%s", sCommand->str);
 		r = system (sCommand->str);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", sCommand->str);
 	}
 	gchar *cNewLocalIconsPath = g_strdup_printf ("%s/%s", cNewThemePath, CAIRO_DOCK_LOCAL_ICONS_DIR);
 	if (! g_file_test (cNewLocalIconsPath, G_FILE_TEST_IS_DIR))  // c'est un ancien theme, on deplace les icones vers le repertoire 'icons'.
@@ -408,11 +449,15 @@ gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavio
 		g_string_printf (sCommand, "for f in \"%s\"/* ; do rm -f \"%s/`basename \"${f%%.*}\"`\"*; done;", cNewLocalIconsPath, g_cCurrentIconsPath);  // on efface les doublons car sinon on pourrait avoir x.png et x.svg ensemble et le dock ne saurait pas lequel choisir.
 		cd_debug ("%s", sCommand->str);
 		r = system (sCommand->str);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", sCommand->str);
 		
 		g_string_printf (sCommand, "cp \"%s\"/* \"%s\"", cNewLocalIconsPath, g_cCurrentIconsPath);
 	}
 	cd_debug ("%s", sCommand->str);
 	r = system (sCommand->str);
+	if (r < 0)
+		cd_warning ("Not able to launch this command: %s", sCommand->str);
 	g_free (cNewLocalIconsPath);
 	
 	//\___________________ On charge les extras.
@@ -422,6 +467,8 @@ gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavio
 		g_string_printf (sCommand, "cp -r \"%s/%s\"/* \"%s\"", cNewThemePath, CAIRO_DOCK_LOCAL_EXTRAS_DIR, g_cExtrasDirPath);
 		cd_debug ("%s", sCommand->str);
 		r = system (sCommand->str);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", sCommand->str);
 	}
 	
 	//\___________________ On charge les lanceurs si necessaire, en effacant ceux existants.
@@ -429,6 +476,8 @@ gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavio
 	{
 		gchar *command = g_strdup_printf ("mkdir -p \"%s\"", g_cCurrentLaunchersPath);
 		r = system (command);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", command);
 		g_free (command);
 	}
 	if (g_pMainDock == NULL || bLoadLaunchers)
@@ -436,22 +485,30 @@ gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavio
 		g_string_printf (sCommand, "rm -f \"%s\"/*.desktop", g_cCurrentLaunchersPath);
 		cd_debug ("%s", sCommand->str);
 		r = system (sCommand->str);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", sCommand->str);
 
 		g_string_printf (sCommand, "cp \"%s/%s\"/*.desktop \"%s\"", cNewThemePath, CAIRO_DOCK_LAUNCHERS_DIR, g_cCurrentLaunchersPath);
 		cd_debug ("%s", sCommand->str);
 		r = system (sCommand->str);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", sCommand->str);
 	}
 	
 	//\___________________ On remplace tous les autres fichiers par les nouveaux.
 	g_string_printf (sCommand, "find \"%s\" -mindepth 1 -maxdepth 1  ! -name '*.conf' -type f -exec rm -f '{}' \\;", g_cCurrentThemePath);  // efface tous les fichiers du theme mais sans toucher aux lanceurs et aux plug-ins.
 	cd_debug ("%s", sCommand->str);
 	r = system (sCommand->str);
+	if (r < 0)
+		cd_warning ("Not able to launch this command: %s", sCommand->str);
 
 	if (g_pMainDock == NULL || bLoadBehavior)
 	{
 		g_string_printf (sCommand, "find \"%s\"/* -prune ! -name '*.conf' ! -name %s -exec /bin/cp -r '{}' \"%s\" \\;", cNewThemePath, CAIRO_DOCK_LAUNCHERS_DIR, g_cCurrentThemePath);  // copie tous les fichiers du nouveau theme sauf les lanceurs et le .conf, dans le repertoire du theme courant. Ecrase les fichiers de memes noms.
 		cd_debug ("%s", sCommand->str);
 		r = system (sCommand->str);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", sCommand->str);
 	}
 	else
 	{
@@ -459,6 +516,8 @@ gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavio
 		g_string_printf (sCommand, "find \"%s\" -mindepth 1 ! -name '*.conf' ! -path '%s/%s*' ! -type d -exec cp -p {} \"%s\" \\;", cNewThemePath, cNewThemePath, CAIRO_DOCK_LAUNCHERS_DIR, g_cCurrentThemePath);
 		cd_debug ("%s", sCommand->str);
 		r = system (sCommand->str);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", sCommand->str);
 		
 		// on parcours les .conf des plug-ins, on les met a jour, et on fusionne avec le theme courant.
 		gchar *cNewPlugInsDir = g_strdup_printf ("%s/%s", cNewThemePath, CAIRO_DOCK_PLUG_INS_DIR);  // repertoire des plug-ins du nouveau theme.
@@ -480,6 +539,8 @@ gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavio
 				
 				g_string_printf (sCommand, "mkdir -p \"%s\"", cUserDataDirPath);
 				r = system (sCommand->str);
+				if (r < 0)
+					cd_warning ("Not able to launch this command: %s", sCommand->str);
 			}
 			
 			// on recupere le nom et le chemin du .conf du plug-in dans le nouveau theme.
@@ -505,12 +566,9 @@ gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavio
 			{
 				cd_debug ("    no conf file %s, we will take the theme's one", cConfFilePath);
 				cairo_dock_copy_file (cNewConfFilePath, cConfFilePath);
-				/**g_string_printf (sCommand, "cp \"%s\" \"%s\"", cNewConfFilePath, cConfFilePath);
-				r = system (sCommand->str);*/
 			}
 			else
 			{
-				///cairo_dock_replace_keys_by_identifier (cConfFilePath, cNewConfFilePath, '+');
 				cairo_dock_merge_conf_files (cConfFilePath, cNewConfFilePath, '+');
 			}
 			g_free (cNewConfFilePath);
@@ -525,59 +583,41 @@ gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavio
 	
 	g_string_printf (sCommand, "rm -f \"%s/last-modif\"", g_cCurrentThemePath);
 	r = system (sCommand->str);
+	if (r < 0)
+		cd_warning ("Not able to launch this command: %s", sCommand->str);
 	
 	// precaution probablement inutile.
-	g_string_printf (sCommand, "chmod -R 777 \"%s\"", g_cCurrentThemePath);
+	g_string_printf (sCommand, "chmod -R 775 \"%s\"", g_cCurrentThemePath);
 	r = system (sCommand->str);
+	if (r < 0)
+		cd_warning ("Not able to launch this command: %s", sCommand->str);
 	
 	g_string_free (sCommand, TRUE);
 	return TRUE;
 }
 
+gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavior, gboolean bLoadLaunchers)
+{
+	//\___________________ Get the local path of the theme (if necessary, it is downloaded and/or unzipped).
+	gchar *cNewThemePath = _cairo_dock_get_theme_path (cThemeName);
+	g_return_val_if_fail (cNewThemePath != NULL && g_file_test (cNewThemePath, G_FILE_TEST_EXISTS), FALSE);
+	
+	//\___________________ import the theme in the current theme.
+	gboolean bSuccess = _cairo_dock_import_local_theme (cNewThemePath, bLoadBehavior, bLoadLaunchers);
+	g_free (cNewThemePath);
+	return bSuccess;
+}
 
-static void _import_theme (gpointer *pSharedMemory)
+
+static void _import_theme (gpointer *pSharedMemory)  // import the theme on the disk; the actual copy of the files is not done here, because we want to be able to cancel the task.
 {
 	cd_debug ("dl start");
-	
-	gchar *cNewThemeName = g_strdup (pSharedMemory[0]);
-	gchar *cNewThemePath = NULL;
-	
-	int length = strlen (cNewThemeName);
-	if (cNewThemeName[length-1] == '\n')
-		cNewThemeName[--length] = '\0';  // on vire le retour chariot final.
-	if (cNewThemeName[length-1] == '\r')
-		cNewThemeName[--length] = '\0';
-	cd_debug ("cNewThemeName : '%s'", cNewThemeName);
-	
-	// on recupere le theme en local, mais sans faire l'import dans le theme courant.
-	if (g_str_has_suffix (cNewThemeName, ".tar.gz") || g_str_has_suffix (cNewThemeName, ".tar.bz2") || g_str_has_suffix (cNewThemeName, ".tgz"))  // c'est l'URL d'un paquet.
-	{
-		cd_debug ("c'est un paquet");
-		cNewThemePath = cairo_dock_depackage_theme (cNewThemeName);
-		
-		if (cNewThemePath != NULL)
-		{
-			gchar *tmp = cNewThemeName;
-			cNewThemeName = g_path_get_basename (cNewThemePath);
-			g_free (tmp);
-		}
-		else
-		{
-			g_free (cNewThemeName);
-			cNewThemeName = NULL;
-		}
-		g_free (pSharedMemory[0]);
-		pSharedMemory[0] = cNewThemeName;
-	}
-	else  // c'est le nom d'un theme officiel.
-	{
-		cd_debug ("c'est un theme officiel");
-		cNewThemePath = cairo_dock_get_package_path (cNewThemeName, s_cLocalThemeDirPath, g_cThemesDirPath, s_cDistantThemeDirName, CAIRO_DOCK_ANY_PACKAGE);
-	}
-	
+	gchar *cNewThemePath = _cairo_dock_get_theme_path (pSharedMemory[0]);
+	g_free (pSharedMemory[0]);
+	pSharedMemory[0] = cNewThemePath;
 	cd_debug ("dl over");
 }
-static gboolean _finish_import (gpointer *pSharedMemory)
+static gboolean _finish_import (gpointer *pSharedMemory)  // once the theme is local, we can import it in the current theme.
 {
 	gboolean bSuccess;
 	if (! pSharedMemory[0])
@@ -587,10 +627,7 @@ static gboolean _finish_import (gpointer *pSharedMemory)
 	}
 	else
 	{
-		// maintenant que le theme est sur le disque, on l'importe dans le theme courant.
-		bSuccess = cairo_dock_import_theme (pSharedMemory[0], GPOINTER_TO_INT (pSharedMemory[1]), GPOINTER_TO_INT (pSharedMemory[2]));
-		if (! bSuccess)
-			cd_warning ("Couldn't import the theme %s.", pSharedMemory[0]);
+		bSuccess = _cairo_dock_import_local_theme (pSharedMemory[0], GPOINTER_TO_INT (pSharedMemory[1]), GPOINTER_TO_INT (pSharedMemory[2]));
 	}
 	
 	GFunc pCallback = pSharedMemory[3];
